/*******************************************************************************
* File Name: CapSense_1_MBX.h
* Version 2.10
*
* Description:
*  This file provides constants and structure declarations for the tuner 
*  communication the for CapSense CSD component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CAPSENSE_CSD_MBX_CapSense_1_H)
#define CY_CAPSENSE_CSD_MBX_CapSense_1_H

#include "CapSense_1.h"
#include "CapSense_1_CSHL.h"


/***************************************
*   Condition compilation parameters
***************************************/

/* Check Sum to identify data */
#define CapSense_1_CHECK_SUM      (41u)

#define CapSense_1_TOTAL_SENSOR_MASK_COUNT     (((CapSense_1_TOTAL_SENSOR_COUNT - 1u) / 8u) + 1u)

/* Do nothing from big endian compilers (__C51__), for ARM compilers need to swap bytes */
#if defined(__C51__) || defined(__CX51__)
    #define CapSense_1_SWAP_ENDIAN16(x) (x)
    #define CYPACKED
#else
    #define CapSense_1_SWAP_ENDIAN16(x) ((uint16)(((x) << 8) | ((x) >> 8)))
    #define CYPACKED __attribute__ ((packed))
#endif  /* End (defined(__C51__)) */

#define CapSense_1_WIDGET_CSHL_PARAMETERS_COUNT           (CapSense_1_TOTAL_WIDGET_COUNT + \
                                                                 CapSense_1_TOTAL_TOUCH_PADS_COUNT + \
                                                                 CapSense_1_TOTAL_MATRIX_BUTTONS_COUNT)

#define CapSense_1_WIDGET_RESOLUTION_PARAMETERS_COUNT     (CapSense_1_WIDGET_CSHL_PARAMETERS_COUNT + \
                                                                 CapSense_1_TOTAL_GENERICS_COUNT)


/***************************************
*      Type defines for mailboxes
***************************************/

/* Outbox structure definition */
typedef struct _CapSense_1_outbox
{       
    #if (CapSense_1_TOTAL_CENTROIDS_COUNT)
        uint16   position[CapSense_1_TOTAL_CENTROIDS_COUNT];
    #endif  /* End (CapSense_1_TOTAL_CENTROIDS_COUNT) */
    
    uint16   rawData[CapSense_1_TOTAL_SENSOR_COUNT];
    uint16   baseLine[CapSense_1_TOTAL_SENSOR_COUNT];
    uint8    signal[CapSense_1_TOTAL_SENSOR_COUNT];
    uint8    onMask[CapSense_1_TOTAL_SENSOR_MASK_COUNT];
    
    #if (CapSense_1_TUNING_METHOD == CapSense_1_AUTO_TUNING)
        uint8   fingerThreshold[CapSense_1_WIDGET_CSHL_PARAMETERS_COUNT];
        uint8   noiseThreshold[CapSense_1_WIDGET_CSHL_PARAMETERS_COUNT];
        uint8   scanResolution[CapSense_1_WIDGET_RESOLUTION_PARAMETERS_COUNT];
        uint8   idacValue[CapSense_1_TOTAL_SENSOR_COUNT];
        uint8   prescaler;
    #endif  /* End (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING) */
    
    #if(CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING)
        uint8   noReadMsg;
    #endif  /* End (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING) */
    uint16  checkSum;
    
} CYPACKED CapSense_1_OUTBOX;

/* Inbox structure definition */
#if (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING)
    typedef struct _CapSense_1_inbox
    {
        uint8   sensorIndex;
        #if (CapSense_1_CURRENT_SOURCE)
            uint8   idacSettings;
        #endif /* End CapSense_1_CURRENT_SOURCE */
        uint8   resolution;
        uint8   fingerThreshold;
        uint8   noiseThreshold;
        uint8   hysteresis;
        uint8   debounce;
        
    } CYPACKED CapSense_1_INBOX;
    
#endif  /* End (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING) */

/* Mailbox structure definition */
typedef struct _CapSense_1_mailBox
{
    uint8   type;               /* Must be the first byte with values ranging from 0-119 */
    uint16  size;               /* Must be the size of this data structure. Range between 0-127 */
    CapSense_1_OUTBOX  outbox;
    #if (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING)
        CapSense_1_INBOX inbox;
    #endif  /* End (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING) */
    
} CYPACKED CapSense_1_MAILBOX;


/* Mailboxes structure definition */
typedef struct _CapSense_1_mailboxes
{
    uint8   numMailBoxes;       /* This must always be the first. Represents # of mailboxes */
    CapSense_1_MAILBOX    csdMailbox;
    
} CYPACKED CapSense_1_MAILBOXES;


/***************************************
*        Function Prototypes
***************************************/

void CapSense_1_InitMailbox(volatile CapSense_1_MAILBOX *mbx);
void CapSense_1_PostMessage(volatile CapSense_1_MAILBOX *mbx);
#if (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING)
    void CapSense_1_ReadMessage(volatile CapSense_1_MAILBOX *mbx);
#endif  /* End (CapSense_1_TUNING_METHOD == CapSense_1_MANUAL_TUNING) */


/***************************************
*           API Constants        
***************************************/

/* The selected ID for this version of Tuner */
#define CapSense_1_TYPE_ID        (0x04u)

#define CapSense_1_BUSY_FLAG      (CapSense_1_TYPE_ID | 0x80u)
#define CapSense_1_HAVE_MSG       (sizeof(CapSense_1_MAILBOX) | 0x8000u)


#endif  /* End (CY_CAPSENSE_CSD_MBX_CapSense_1_H) */


/* [] END OF FILE */
