/*******************************************************************************
* File Name: can.h
* Version 1.50
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the CAN Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CAN_can_H)
#define CY_CAN_can_H

#include "cyfitter.h"
#include "CyLib.h"


/* PSoC3 ES2 or early */
#define can_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
                                     
#if(can_PSOC3_ES2 && (can_isr__ES2_PATCH))
    #include <intrins.h>
    #define can_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
#endif /* End PSOC3_ES2 */


/***************************************
*       Memory Type Definitions
***************************************/

#if defined(__C51__) || defined(__CX51__)
    #ifndef CYCODE
        #define CYCODE code
    #endif /* End CYCODE */    
#else
    #ifndef CYCODE
        #define CYCODE
    #endif /* End CYCODE */    
#endif /* End __C51__ */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define can_ARB_LOST          (0u)
#define can_OVERLOAD          (0u)
#define can_BIT_ERR           (0u)
#define can_STUFF_ERR         (0u)
#define can_ACK_ERR           (0u)
#define can_FORM_ERR          (0u)
#define can_CRC_ERR           (0u)
#define can_BUS_OFF           (1u)
#define can_RX_MSG_LOST       (0u)
#define can_TX_MESSAGE        (0u)
#define can_RX_MESSAGE        (1u)

/* TX/RX Function Enable */
#define can_TX0_FUNC_ENABLE 0u
#define can_TX1_FUNC_ENABLE 0u
#define can_TX2_FUNC_ENABLE 0u
#define can_TX3_FUNC_ENABLE 0u
#define can_TX4_FUNC_ENABLE 0u
#define can_TX5_FUNC_ENABLE 0u
#define can_TX6_FUNC_ENABLE 0u
#define can_TX7_FUNC_ENABLE 0u
#define can_RX0_FUNC_ENABLE 0u
#define can_RX1_FUNC_ENABLE 0u
#define can_RX2_FUNC_ENABLE 0u
#define can_RX3_FUNC_ENABLE 0u
#define can_RX4_FUNC_ENABLE 0u
#define can_RX5_FUNC_ENABLE 0u
#define can_RX6_FUNC_ENABLE 0u
#define can_RX7_FUNC_ENABLE 0u
#define can_RX8_FUNC_ENABLE 0u
#define can_RX9_FUNC_ENABLE 0u
#define can_RX10_FUNC_ENABLE 0u
#define can_RX11_FUNC_ENABLE 0u
#define can_RX12_FUNC_ENABLE 0u
#define can_RX13_FUNC_ENABLE 0u
#define can_RX14_FUNC_ENABLE 0u
#define can_RX15_FUNC_ENABLE 0u
#define can_RX_MAILBOX_TYPE	0x0u
#define can_TX_MAILBOX_TYPE	0x0u



/***************************************
*        Data Struct Definition
***************************************/

/* Stuct for DATA of BASIC CAN */
typedef struct _can_dataBytesMsg
{
    uint8 byte[8u];
} can_DATA_BYTES_MSG;

/* Stuct for DATA of CAN RX register */
typedef struct _can_dataBytes
{
    reg8 byte[8u];
} can_DATA_BYTES;

/* Stuct for 32-bit CAN register */
typedef struct _can_reg32
{
    reg8 byte[4u];
} can_REG_32;

/* Stuct for BASIC CAN to send messages */
typedef struct _can_txMsg
{
    uint32 id;
    uint8 rtr;
    uint8 ide;
    uint8 dlc;
    uint8 irq;
    can_DATA_BYTES_MSG *msg;
} can_TX_MSG;

/* Constant configutaion of CAN RX */
typedef struct _can_rxCfg
{
    uint8 rxmailbox;
    uint32 rxcmd;
    uint32 rxamr;
    uint32 rxacr;
} can_RX_CFG;

/* Constant configutaion of CAN TX */
typedef struct _can_txCfg
{
    uint8 txmailbox;
    uint32 txcmd;
    uint32 txid;
} can_TX_CFG;

/* CAN RX registers */
typedef struct _can_rxStruct
{
    can_REG_32 rxcmd;
    can_REG_32 rxid;
    can_DATA_BYTES rxdata;
    can_REG_32 rxamr;
    can_REG_32 rxacr;
    can_REG_32 rxamrd;
    can_REG_32 rxacrd;
} can_RX_STRUCT;

/* CAN TX registers */
typedef struct _can_txStruct
{
    can_REG_32 txcmd;
    can_REG_32 txid;
    can_DATA_BYTES txdata;
} can_TX_STRUCT;

/* Sleep Mode API Support */
typedef struct _can_backupStruct
{
    uint8  enableState;
	uint32 intSr;
    uint32 intEn;
    uint32 cmd;
    uint32 cfg;    
} can_BACKUP_STRUCT;

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects
*/
#define CAN_reg32      can_REG_32
#define CANTXMsg       can_TX_MSG
#define CANRXcfg       can_RX_CFG
#define CANTXcfg       can_TX_CFG
#define CANRXstruct    can_RX_STRUCT
#define CANTXstruct    can_TX_STRUCT
#define DATA_BYTES     can_DATA_BYTES
#define DATA_BYTES_MSG can_DATA_BYTES_MSG


/***************************************
*        Function Prototypes
***************************************/

uint8 can_Init(void) ;
uint8 can_Start(void);
uint8 can_Stop(void) ;
uint8 can_Enable(void) ;
uint8 can_GlobalIntEnable(void) ;
uint8 can_GlobalIntDisable(void) ;
uint8 can_SetPreScaler(uint16 bitrate) ;
uint8 can_SetArbiter(uint8 arbiter) ;
uint8 can_SetTsegSample(uint8 cfgTseg1, uint8 cfgTseg2, uint8 sjw, uint8 sm)
                                                ;
uint8 can_SetRestartType(uint8 reset) ;
uint8 can_SetEdgeMode(uint8 edge) ;
uint8 can_SetOpMode(uint8 opMode) ;
uint8 can_RXRegisterInit(reg32 *regAddr, uint32 config)
                                            ;
uint8 can_SetIrqMask(uint16 mask) ;
uint8 can_GetTXErrorFlag(void) ;
uint8 can_GetRXErrorFlag(void) ;
uint8 can_GetTXErrorCount(void) ;
uint8 can_GetRXErrorCount(void) ;
uint8 can_GetErrorState(void) ;
void  can_Sleep(void);
void  can_Wakeup(void) ;
void  can_SaveConfig(void);
void  can_RestoreConfig(void) ;

#if (can_ARB_LOST)
    void can_ArbLostIsr(void) ;
#endif /* can_ARB_LOST */

#if (can_OVERLOAD)
    void can_OvrLdErrorIsr(void) ;
#endif /* can_OVERLOAD */

#if (can_BIT_ERR)
    void can_BitErrorIsr(void) ;
#endif /* can_BIT_ERR */

#if (can_STUFF_ERR)
    void can_BitStuffErrorIsr(void) ;
#endif /* can_STUFF_ERR */

#if (can_ACK_ERR)
    void can_AckErrorIsr(void) ;
#endif /* can_ACK_ERR */

#if (can_FORM_ERR)
    void can_MsgErrorIsr(void) ;
#endif /* can_FORM_ERR */

#if (can_CRC_ERR)
    void can_CrcErrorIsr(void) ;
#endif /* can_CRC_ERR */

#if (can_BUS_OFF)
    void can_BusOffIsr(void) ;
#endif /* can_BUS_OFF */

#if (can_RX_MSG_LOST)
    void can_MsgLostIsr(void) ;
#endif /* can_RX_MSG_LOST */

#if (can_TX_MESSAGE)
   void can_MsgTXIsr(void) ;
#endif /* can_TX_MESSAGE */

#if (can_RX_MESSAGE)
    void can_MsgRXIsr(void) ;
#endif /* can_RX_MESSAGE */

uint8 can_RxBufConfig(can_RX_CFG *rxConfig) ;
uint8 can_TxBufConfig(can_TX_CFG *txConfig) ;
uint8 can_SendMsg(can_TX_MSG *message) ;
void  can_TxCancel(uint8 bufferId) ;
void  can_ReceiveMsg(uint8 rxMailbox) ;

#if (can_TX0_FUNC_ENABLE)
    uint8 can_SendMsg0(void) ;
#endif /* can_TX0_FUNC_ENABLE */

#if (can_TX1_FUNC_ENABLE)
    uint8 can_SendMsg1(void) ;
#endif /* can_TX1_FUNC_ENABLE */

#if (can_TX2_FUNC_ENABLE)
    uint8 can_SendMsg2(void) ;
#endif /* can_TX2_FUNC_ENABLE */

#if (can_TX3_FUNC_ENABLE)
    uint8 can_SendMsg3(void) ;
#endif /* can_TX3_FUNC_ENABLE */

#if (can_TX4_FUNC_ENABLE)
    uint8 can_SendMsg4(void) ;
#endif /* can_TX4_FUNC_ENABLE */

#if (can_TX5_FUNC_ENABLE)
    uint8 can_SendMsg5(void) ;
#endif /* can_TX5_FUNC_ENABLE */

#if (can_TX6_FUNC_ENABLE)
    uint8 can_SendMsg6(void) ;
#endif /* can_TX6_FUNC_ENABLE */

#if (can_TX7_FUNC_ENABLE)
    uint8 can_SendMsg7(void) ;
#endif /* can_TX7_FUNC_ENABLE */

#if (can_RX0_FUNC_ENABLE)
    void can_ReceiveMsg0(void) ;
#endif /* can_RX0_FUNC_ENABLE */

#if (can_RX1_FUNC_ENABLE)
    void can_ReceiveMsg1(void) ;
#endif /* can_RX1_FUNC_ENABLE */

#if (can_RX2_FUNC_ENABLE)
    void can_ReceiveMsg2(void) ;
#endif /* can_RX2_FUNC_ENABLE */

#if (can_RX3_FUNC_ENABLE)
    void can_ReceiveMsg3(void) ;
#endif /* can_RX3_FUNC_ENABLE */

#if (can_RX4_FUNC_ENABLE)
    void can_ReceiveMsg4(void) ;
#endif /* can_RX4_FUNC_ENABLE */

#if (can_RX5_FUNC_ENABLE)
    void can_ReceiveMsg5(void) ;
#endif /* can_RX5_FUNC_ENABLE */

#if (can_RX6_FUNC_ENABLE)
    void can_ReceiveMsg6(void) ;
#endif /* can_RX6_FUNC_ENABLE */

#if (can_RX7_FUNC_ENABLE)
    void can_ReceiveMsg7(void) ;
#endif /* can_RX7_FUNC_ENABLE */

#if (can_RX8_FUNC_ENABLE)
    void can_ReceiveMsg8(void) ;
#endif /* can_RX8_FUNC_ENABLE */

#if (can_RX9_FUNC_ENABLE)
    void can_ReceiveMsg9(void) ;
#endif /* can_RX9_FUNC_ENABLE */

#if (can_RX10_FUNC_ENABLE)
    void can_ReceiveMsg10(void) ;
#endif /* can_RX10_FUNC_ENABLE */

#if (can_RX11_FUNC_ENABLE)
    void can_ReceiveMsg11(void) ;
#endif /* can_RX11_FUNC_ENABLE */

#if (can_RX12_FUNC_ENABLE)
    void can_ReceiveMsg12(void) ;
#endif /* can_RX12_FUNC_ENABLE */

#if (can_RX13_FUNC_ENABLE)
    void can_ReceiveMsg13(void) ;
#endif /* can_RX13_FUNC_ENABLE */

#if (can_RX14_FUNC_ENABLE)
    void can_ReceiveMsg14(void) ;
#endif /* can_RX14_FUNC_ENABLE */

#if (can_RX15_FUNC_ENABLE)
    void can_ReceiveMsg15(void) ;
#endif /* can_RX15_FUNC_ENABLE */

/* Interrupt handler */
CY_ISR_PROTO(can_ISR);


/***************************************
*           API Constants
***************************************/

/* Number of the can_isr interrupt */
#define can_ISR_NUMBER                 (can_isr__INTC_NUMBER)

/* Priority of the can_isr interrupt */
#define can_ISR_PRIORITY               (can_isr__INTC_PRIOR_NUM)

/* One or more parameters to the function were invalid. */
#define can_FAIL                       (0x01u)
#define can_OUT_OF_RANGE               (0x02u)

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects
*/
#define FAIL                                        can_FAIL
#define OUT_OF_RANGE                                can_OUT_OF_RANGE

/* PM_ACT_CFG (Active Power Mode CFG Register) */
#define can_ACT_PWR_EN                 can_CanIP__PM_ACT_MSK    /* Power enable mask */

/* PM_STBY_CFG (Alternate Active (Standby) Power Mode CFG Register) */
#define can_STBY_PWR_EN                can_CanIP__PM_STBY_MSK   /* Power enable mask */

/* Number of TX and RX mailboxes */
#define can_NUMBER_OF_TX_MAILBOXES     (8u)
#define can_NUMBER_OF_RX_MAILBOXES     (16u) 

/* Error status of CAN */
#define can_ERROR_ACTIVE               (0x00u)
#define can_ERROR_PASIVE               (0x01u)
#define can_ERROR_BUS_OFF              (0x10u)


/***************************************
*    Enumerated Types and Parameters
***************************************/


/***************************************
*    Initial Parameter Constants
***************************************/

/* General */
#define can_BITRATE           (5u)
#define can_CFG_REG_TSEG1     (13u - 1u)
#define can_CFG_REG_TSEG2     (2u - 1u)
#define can_CFG_REG_SJW       (1u - 1u)
#define can_SAMPLING_MODE     (0u)

#define can_ARBITER           (0u)
#define can_RESET_TYPE        (0u)
#define can_SYNC_EDGE         (0u)

/* Interrupts */
#define can_INT_ENABLE        (1u)
#define can_INIT_INTERRUPT_MASK ((can_INT_ENABLE) | \
                                              (can_ARB_LOST << can_ARBITRATION_LOST_SHIFT) | \
                                              (can_OVERLOAD << can_OVERLOAD_ERROR_SHIFT) | \
                                              (can_BIT_ERR  << can_BIT_ERROR_SHIFT) | \
                                              (can_STUFF_ERR << can_STUFF_ERROR_SHIFT) | \
                                              (can_ACK_ERR   << can_ACK_ERROR_SHIFT) | \
                                              (can_FORM_ERR  << can_FORM_ERROR_SHIFT) | \
                                              (can_CRC_ERR   << (can_ONE_BYTE_OFFSET + \
                                                                            can_CRC_ERROR_SHIFT)) | \
                                              (can_BUS_OFF   << (can_ONE_BYTE_OFFSET + \
                                                                            can_BUS_OFF_SHIFT)) | \
                                              (can_RX_MSG_LOST << (can_ONE_BYTE_OFFSET + \
                                                                                can_RX_MSG_LOST_SHIFT)) | \
                                              (can_TX_MESSAGE  << (can_ONE_BYTE_OFFSET + \
                                                                           can_TX_MESSAGE_SHIFT)) | \
                                              (can_RX_MESSAGE  << (can_ONE_BYTE_OFFSET + \
                                                                           can_RX_MESSAGE_SHIFT)))


/***************************************
*             Registers
***************************************/

#define can_TX         ( (volatile can_TX_STRUCT XDATA *) can_CanIP__TX0_CMD )
#define can_RX         ( (volatile can_RX_STRUCT XDATA *) can_CanIP__RX0_CMD )
#define can_INT_SR_REG ( *(volatile can_REG_32 XDATA *) can_CanIP__CSR_INT_SR )
#define can_INT_SR_PTR (  (reg32 *) can_CanIP__CSR_INT_SR )
#define can_INT_EN_REG ( *(volatile can_REG_32 XDATA *) can_CanIP__CSR_INT_EN )
#define can_INT_EN_PTR (  (reg32 *) can_CanIP__CSR_INT_EN )
#define can_BUF_SR_REG ( *(volatile can_REG_32 XDATA *) can_CanIP__CSR_BUF_SR )
#define can_BUF_SR_PTR (  (reg32 *) can_CanIP__CSR_BUF_SR )
#define can_ERR_SR_REG ( *(volatile can_REG_32 XDATA *) can_CanIP__CSR_ERR_SR )
#define can_ERR_SR_PTR (  (reg32 *) can_CanIP__CSR_ERR_SR )
#define can_CMD_REG    ( *(volatile can_REG_32 XDATA *) can_CanIP__CSR_CMD )
#define can_CMD_PTR    (  (reg32 *) can_CanIP__CSR_CMD )
#define can_CFG_REG    ( *(volatile can_REG_32 XDATA *) can_CanIP__CSR_CFG )
#define can_CFG_PTR    (  (reg32 *) can_CanIP__CSR_CFG )
#define can_PM_ACT_CFG_REG  ( *(reg8 *) can_CanIP__PM_ACT_CFG )    /* Power manager */
#define can_PM_ACT_CFG_PTR  (  (reg8 *) can_CanIP__PM_ACT_CFG )    /* Power manager */
#define can_PM_STBY_CFG_REG ( *(reg8 *) can_CanIP__PM_STBY_CFG )   /* Power manager */
#define can_PM_STBY_CFG_PTR (  (reg8 *) can_CanIP__PM_STBY_CFG )   /* Power manager */

#define can_RX_FIRST_REGISTER_PTR    ( (reg32 *) can_CanIP__RX0_CMD)
#define can_RX_LAST_REGISTER_PTR     ( (reg32 *) can_CanIP__RX15_ACRD)

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects 
*/
#define can_INT_SR can_INT_SR_REG
#define can_INT_EN can_INT_EN_REG
#define can_BUF_SR can_BUF_SR_REG
#define can_ERR_SR can_ERR_SR_REG
#define can_PWRMGR can_PM_ACT_CFG_REG
#define can_CMD can_CMD_REG
#define can_CFG can_CFG_REG


/***************************************
*        Register Constants
***************************************/

/* Operation mode */
#define can_ACTIVE_MODE              (0x00u)
#define can_LISTEN_ONLY              (0x01u)

/* Run/Stop mode */
#define can_MODE_STOP                (0x00u)
#define can_MODE_START               (0x01u)

/* Transmit buffer arbiter */
#define can_ROUND_ROBIN              (0x00u)
#define can_FIXED_PRIORITY           (0x01u)

/* Restart type */
#define can_RESTART_BY_HAND          (0x00u)
#define can_AUTO_RESTART             (0x01u)

/* Sampling mode */
#define can_ONE_SAMPLE_POINT         (0x00u)
#define can_THREE_SAMPLE_POINTS      (0x01u)

/* Edge mode */
#define can_EDGE_R_TO_D              (0x00u)
#define can_BOTH_EDGES               (0x01u)

/* Extended identifier */
#define can_STANDARD_MESSAGE         (0x00u)
#define can_EXTENDED_MESSAGE         (0x01u)

/* Write Protect Mask for Basic and Full mailboxes */

#define can_TX_WPN_SET               (((uint32)0x00000001u << can_TX_WPNL_SHIFT) | \
                                                   ((uint32)0x00000001u << (can_TWO_BYTE_OFFSET + \
                                                    can_TX_WPNH_SHIFT)))

#define can_TX_WPN_CLEAR             (~can_TX_WPN_SET)

#define can_RX_WPN_SET               (((uint32)0x00000001u << can_RX_WPNL_SHIFT) | \
                                                   ((uint32)0x00000001u << (can_TWO_BYTE_OFFSET + \
                                                    can_RX_WPNH_SHIFT)))

#define can_RX_WPN_CLEAR             (~can_RX_WPN_SET)

#define can_TX_RSVD_MASK             (0x00FF00FFu)

#define can_TX_READ_BACK_MASK        (can_TX_WPN_CLEAR & can_TX_RSVD_MASK)

#define can_RX_READ_BACK_MASK        (can_RX_WPN_CLEAR & can_TX_RSVD_MASK)

#define can_RX_CMD_REG_WIDTH         (0x20u)

/* TX send message */
#define can_TX_REQUEST_PENDING       (0x01u)
#define can_RETRY_NUMBER             (0x03u)
#define can_SEND_MESSAGE_SHIFT       (0u)
#define can_SEND_MESSAGE             ((uint32)0x00000001u << can_SEND_MESSAGE_SHIFT)

/* Offsets to maintain bytes within uint32 */
#define can_ONE_BYTE_OFFSET          (8u)
#define can_TWO_BYTE_OFFSET          (16u)
#define can_TREE_BYTE_OFFSET         (24u)

/* Set/Clear bits macro for can_RX maibox(i) */
/* bit 0 within RX_CMD[i] */
#define can_RX_ACK_MSG_SHIFT         (0u)
#define can_RX_ACK_MSG               (0x01u << can_RX_ACK_MSG_SHIFT)
#define can_RX_ACK_MESSAGE(i)        can_RX[i].rxcmd.byte[0u] |= can_RX_ACK_MSG
/* bit 2 within RX_CMD[i] */
#define can_RX_RTR_ABORT_SHIFT       (2u)
#define can_RX_RTR_ABORT_MASK        (0x01u << can_RX_RTR_ABORT_SHIFT)
#define can_RX_RTR_ABORT_MESSAGE(i)  can_RX[i].rxcmd.byte[0u] |= \
                                                    can_RX_RTR_ABORT_MASK
/* bit 3 within RX_CMD[i] */
#define can_RX_BUF_ENABLE_SHIFT      (3u)
#define can_RX_BUF_ENABLE_MASK       (0x01u << can_RX_BUF_ENABLE_SHIFT)
#define can_SET_RX_BUF_ENABLE(i)     can_RX[i].rxcmd.byte[0u] |= \
                                                    can_RX_BUF_ENABLE_MASK
#define can_CLEAR_RX_BUF_DISABLE(i)  can_RX[i].rxcmd.byte[0u] &= \
                                                    ~can_RX_BUF_ENABLE_MASK
/* bit 4 within RX_CMD[i] */
#define can_RX_RTRREPLY_SHIFT         (4u)
#define can_RX_RTRREPLY_MASK          (0x01u << can_RX_RTRREPLY_SHIFT)
#define can_SET_RX_RTRREPLY(i)        can_RX[i].rxcmd.byte[0u] |= \
                                                    can_RX_RTRREPLY_MASK
#define can_CLEAR_RX_RTRREPLY(i)      can_RX[i].rxcmd.byte[0u] &= \
                                                    ~can_RX_RTRREPLY_MASK
/* bit 5 within RX_CMD[i] */
#define can_RX_INT_ENABLE_SHIFT      (5u)
#define can_RX_INT_ENABLE_MASK       (0x01u << can_RX_INT_ENABLE_SHIFT)
#define can_RX_INT_ENABLE(i)         can_RX[i].rxcmd.byte[0u] |= \
                                                    can_RX_INT_ENABLE_MASK
#define can_RX_INT_DISABLE(i)        can_RX[i].rxcmd.byte[0u] &= \
                                                    ~can_RX_INT_ENABLE_MASK
/* bit 6 within RX_CMD[i] */
#define can_RX_LINKING_SHIFT         (6u)
#define can_RX_LINKING_MASK          (0x01u << can_RX_LINKING_SHIFT)
#define can_SET_RX_LINKING(i)        can_RX[i].rxcmd.byte[0u] |= \
                                                    can_RX_LINKING_MASK
#define can_CLEAR_RX_LINKING(i)      can_RX[i].rxcmd.byte[0u] &= \
                                                    ~can_RX_LINKING_MASK
/* bit 7 within RX_CMD[i] */
#define can_RX_WPNL_SHIFT           (7u)
#define can_RX_WPNL_MASK            (0x01u << can_RX_WPNL_SHIFT)
#define can_SET_RX_WNPL(i)          can_RX[i].rxcmd.byte[0u] |= can_RX_WPNL_MASK
#define can_CLEAR_RX_WNPL(i)        can_RX[i].rxcmd.byte[0u] &= ~can_RX_WPNL_MASK
/* bit 23 within RX_CMD[i] */
#define can_RX_WPNH_SHIFT           (7u)
#define can_RX_WPNH_MASK            (0x01u << can_RX_WPNH_SHIFT)
#define can_SET_RX_WNPH(i)          can_RX[i].rxcmd.byte[2u] |= can_RX_WPNH_MASK
#define can_CLEAR_RX_WNPH(i)        can_RX[i].rxcmd.byte[2u] &= ~can_RX_WPNH_MASK

/* bits 19-16 within TX_CMD[i] */
#define can_RX_DLC_VALUE_SHIFT      (0u)
#define can_RX_DLC_VALUE_MASK       (0x0Fu << can_RX_DLC_VALUE_SHIFT)
#define can_GET_DLC(mailbox)        (can_RX[mailbox].rxcmd.byte[2u] & \
                                                  can_RX_DLC_VALUE_MASK)

/* Set/Clear bits macro for can_TX mailbox(i) */
/* bit 0 within TX_CMD[i] */
#define can_TX_TRANSMIT_REQUEST_SHIFT (0u)
#define can_TX_TRANSMIT_REQUEST       (0x01u << can_TX_TRANSMIT_REQUEST_SHIFT)
#define can_TX_TRANSMIT_MESSAGE(i)    can_TX[i].txcmd.byte[0u] |= \
                                                    can_TX_TRANSMIT_REQUEST
/* bit 1 within TX_CMD[i] */
#define can_TX_ABORT_SHIFT          (1u)
#define can_TX_ABORT_MASK           (0x01u << can_TX_ABORT_SHIFT)
#define can_TX_ABORT_MESSAGE(i)     can_TX[i].txcmd.byte[0u] |= can_TX_ABORT_MASK
/* bit 2 within TX_CMD[i] */
#define can_TRANSMIT_INT_ENABLE     (0x01u)
#define can_TRANSMIT_INT_DISABLE    (0x00u)
#define can_TX_INT_ENABLE_SHIFT     (2u)
#define can_TX_INT_ENABLE_MASK      ((uint32)0x00000001u << can_TX_INT_ENABLE_SHIFT)
#define can_TX_INT_ENABLE(i)        can_TX[i].txcmd.byte[0u] |= \
                                                  can_TX_INT_ENABLE_MASK
#define can_TX_INT_DISABLE(i)       can_TX[i].txcmd.byte[0u] &= \
                                                  ~can_TX_INT_ENABLE_MASK
/* bit 3 within TX_CMD[i] */
#define can_TX_WPNL_SHIFT           (3u)
#define can_TX_WPNL_MASK            (0x01u << can_TX_WPNL_SHIFT)
#define can_SET_TX_WNPL(i)          can_TX[i].txcmd.byte[0u] |= can_TX_WPNL_MASK
#define can_CLEAR_TX_WNPL(i)        can_TX[i].txcmd.byte[0u] &= ~can_TX_WPNL_MASK
/* bits 19-16 within TX_CMD[i] */
#define can_TX_DLC_VALUE_SHIFT        (0u)
#define can_TX_DLC_UPPER_VALUE_SHIFT  (19u)
#define can_TX_DLC_UPPER_VALUE        ((uint32)0x00000001u << can_TX_DLC_UPPER_VALUE_SHIFT)
#define can_TX_DLC_VALUE_MASK         (0x0Fu << can_TX_DLC_VALUE_SHIFT)
#define can_TX_DLC_MAX_VALUE          (8u)
/* bit 20 within TX_CMD[i] */
#define can_TX_IDE_SHIFT             (20u)
#define can_TX_IDE_MASK              ((uint32)0x00000001u << can_TX_IDE_SHIFT)
#define can_SET_TX_IDE(i)            can_TX[i].txcmd.byte[2u] |= can_TX_IDE_MASK
#define can_CLEAR_TX_IDE(i)          can_TX[i].txcmd.byte[2u] &= ~can_TX_IDE_MASK
/* bit 21 within TX_CMD[i] */
#define can_TX_RTR_SHIFT             (21u)
#define can_TX_RTR_MASK              ((uint32)0x00000001u <<  can_TX_RTR_SHIFT)
#define can_SET_TX_RTR(i)            can_TX[i].txcmd.byte[2u] |= can_TX_RTR_MASK
#define can_CLEAR_TX_RTR(i)          can_TX[i].txcmd.byte[2u] &= ~can_TX_RTR_MASK
/* bit 23 within TX_CMD[i] */
#define can_TX_WPNH_SHIFT            (7u)
#define can_TX_WPNH_MASK             (0x01u << can_TX_WPNH_SHIFT)
#define can_SET_TX_WNPH(i)           can_TX[i].txcmd.byte[2u] |= can_TX_WPN_MASK
#define can_CLEAR_TX_WNPH(i)         can_TX[i].txcmd.byte[2u] &= ~can_TX_WPN_MASK
/* bit 4 within RX_CMD[i].byte[2] */
#define can_RX_IDE_SHIFT             (4u)
#define can_RX_IDE_MASK              (0x01u << can_RX_IDE_SHIFT)
#define can_GET_RX_IDE(i)            (can_RX[i].rxcmd.byte[2u] & can_RX_IDE_MASK)
#define can_GET_RX_ID(i)             ((can_GET_RX_IDE(i)) ? ((CY_GET_REG32((reg32 *) & \
                                                    can_RX[i].rxid)) >> 3u) : ((CY_GET_REG32((reg32 *) & \
                                                    can_RX[i].rxid)) >> 21u))

#define can_RX_DATA_BYTE(mailbox, i) can_RX[mailbox].rxdata.byte[((i) > 3u) ? \
                                                                                         (7u - ((i) - 4u)) : (3u - (i))]
#define can_TX_DATA_BYTE(mailbox, i) can_TX[mailbox].txdata.byte[((i) > 3u) ? \
                                                                                         (7u - ((i) - 4u)) : (3u - (i))]

/* Macros for access to RX DATA for mailbox(i) */
#define can_RX_DATA_BYTE1(i)          can_RX[i].rxdata.byte[3u]
#define can_RX_DATA_BYTE2(i)          can_RX[i].rxdata.byte[2u]
#define can_RX_DATA_BYTE3(i)          can_RX[i].rxdata.byte[1u]
#define can_RX_DATA_BYTE4(i)          can_RX[i].rxdata.byte[0u]
#define can_RX_DATA_BYTE5(i)          can_RX[i].rxdata.byte[7u]
#define can_RX_DATA_BYTE6(i)          can_RX[i].rxdata.byte[6u]
#define can_RX_DATA_BYTE7(i)          can_RX[i].rxdata.byte[5u]
#define can_RX_DATA_BYTE8(i)          can_RX[i].rxdata.byte[4u]

/* Macros for access to TX DATA for mailbox(i) */
#define can_TX_DATA_BYTE1(i)          can_TX[i].txdata.byte[3u]
#define can_TX_DATA_BYTE2(i)          can_TX[i].txdata.byte[2u]
#define can_TX_DATA_BYTE3(i)          can_TX[i].txdata.byte[1u]
#define can_TX_DATA_BYTE4(i)          can_TX[i].txdata.byte[0u]
#define can_TX_DATA_BYTE5(i)          can_TX[i].txdata.byte[7u]
#define can_TX_DATA_BYTE6(i)          can_TX[i].txdata.byte[6u]
#define can_TX_DATA_BYTE7(i)          can_TX[i].txdata.byte[5u]
#define can_TX_DATA_BYTE8(i)          can_TX[i].txdata.byte[4u]

/* Macros for set Tx Msg Indentifier in can_TX_ID register */
#define can_SET_TX_ID_STANDARD_MSG_SHIFT   (21u)
#define can_SET_TX_ID_EXTENDED_MSG_SHIFT   (3u)
#define can_SET_TX_ID_STANDARD_MSG(i, id)  CY_SET_REG32( (reg32 *) &can_TX[i].txid, (id << \
                                                        can_SET_TX_ID_STANDARD_MSG_SHIFT) );
#define can_SET_TX_ID_EXTENDED_MSG(i, id)  CY_SET_REG32( (reg32 *) &can_TX[i].txid, (id << \
                                                        can_SET_TX_ID_EXTENDED_MSG_SHIFT) );

/* Mask for bits within can_CSR_CFG */
#define can_EDGE_MODE_SHIFT           (0u)
/* bit 0 within CSR_CFG */
#define can_EDGE_MODE_MASK            (0x01u << can_EDGE_MODE_SHIFT)
#define can_SAMPLE_MODE_SHIFT         (1u)
/* bit 1 within CSR_CFG */
#define can_SAMPLE_MODE_MASK          (0x01u << can_SAMPLE_MODE_SHIFT)
#define can_CFG_REG_SJW_SHIFT         (2u)
/* bits 3-2 within CSR_CFG */
#define can_CFG_REG_SJW_MASK          (0x03u << can_CFG_REG_SJW_SHIFT)
#define can_CFG_REG_SJW_LOWER_LIMIT   (0x03u)  /* the lowest allowed value of cfg_sjw */
#define can_RESET_SHIFT               (4u)
/* bit 4 within CSR_CFG    */
#define can_RESET_MASK                (0x01u << can_RESET_SHIFT)
#define can_CFG_REG_TSEG2_SHIFT       (5u)
/* bits 7-5 within CSR_CFG */
#define can_CFG_REG_TSEG2_MASK        (0x07u << can_CFG_REG_TSEG2_SHIFT)
/* the highest allowed value of cfg_tseg2 */
#define can_CFG_REG_TSEG2_UPPER_LIMIT     (0x07u)
/* the lowest allowed value of cfg_tseg2 */
#define can_CFG_REG_TSEG2_LOWER_LIMIT     (0x02u)
 /* the lowest allowed value of cfg_tseg2 if sample point is one point */
#define can_CFG_REG_TSEG2_EXCEPTION       (0x01u)  
/* bits 11-8 within CSR_CFG */
#define can_CFG_REG_TSEG1_MASK            (0x0Fu)
/* the highest allowed value of cfg_tseg1 */
#define can_CFG_REG_TSEG1_UPPER_LIMIT     (0x0Fu)
/* the lowest allowed value of cfg_tseg1 */
#define can_CFG_REG_TSEG1_LOWER_LIMIT     (0x02u)
#define can_ARBITRATION_SHIFT             (4u)
/* bit 12 within CSR_CFG */
#define can_ARBITRATION_MASK              (0x01u << can_ARBITRATION_SHIFT)
/* bits 23-16 within CSR_CFG */
#define can_BITRATE_MASK                  (0x7FFFu)

/* Mask for bits within can_CSR_CMD */
#define can_MODE_SHIFT                    (0u)
/* bit 0 within CSR_CMD */
#define can_MODE_MASK                     (0x01u << can_MODE_SHIFT)
#define can_OPMODE_MASK_SHIFT             (1u)
/* bit 1 within CSR_CMD */
#define can_OPMODE_MASK                   (0x01u << can_OPMODE_MASK_SHIFT)

/* Mask for bits within can_CSR_CMD */
#define can_ERROR_STATE_SHIFT             (0u)
/* bit 17-16 within ERR_SR */
#define can_ERROR_STATE_MASK              (0x03u << can_ERROR_STATE_SHIFT)
#define can_TX_ERROR_FLAG_SHIFT           (2u)
/* bit 18 within ERR_SR */
#define can_TX_ERROR_FLAG_MASK            (0x01u << can_TX_ERROR_FLAG_SHIFT)
#define can_RX_ERROR_FLAG_SHIFT           (3u)
/* bit 19 within ERR_SR */
#define can_RX_ERROR_FLAG_MASK            (0x01u << can_RX_ERROR_FLAG_SHIFT)


/* Mask and Macros for bits within can_INT_EN_REG */
#define can_GLOBAL_INT_SHIFT              (0u)
/* bit 0 within INT_EN */
#define can_GLOBAL_INT_MASK               (0x01u << can_GLOBAL_INT_SHIFT)
#define can_ARBITRATION_LOST_SHIFT        (2u)
/* bit 2 within INT_EN and INT_SR */
#define can_ARBITRATION_LOST_MASK         (0x01u << can_ARBITRATION_LOST_SHIFT)
#define can_ARBITRATION_LOST_INT_ENABLE   can_INT_EN_REG.byte[0u] |= \
                                                        can_ARBITRATION_LOST_MASK
#define can_ARBITRATION_LOST_INT_DISABLE  can_INT_EN_REG.byte[0u] &= \
                                                        ~can_ARBITRATION_LOST_MASK
#define can_OVERLOAD_ERROR_SHIFT          (3u)
/* bit 3 within INT_EN and INT_SR */
#define can_OVERLOAD_ERROR_MASK           (0x01u << can_OVERLOAD_ERROR_SHIFT)
#define can_OVERLOAD_ERROR_INT_ENABLE     can_INT_EN_REG.byte[0u] |= \
                                                        can_OVERLOAD_ERROR_MASK
#define can_OVERLOAD_ERROR_INT_DISABLE    can_INT_EN_REG.byte[0u] &= \
                                                        ~can_OVERLOAD_ERROR_MASK
#define can_BIT_ERROR_SHIFT               (4u)
/* bit 4 within INT_EN and INT_SR */
#define can_BIT_ERROR_MASK                (0x01u << can_BIT_ERROR_SHIFT)
#define can_BIT_ERROR_LOST_INT_ENABLE     can_INT_EN_REG.byte[0u] |= \
                                                        can_BIT_ERROR_MASK
#define can_BIT_ERROR_LOST_INT_DISABLE    can_INT_EN_REG.byte[0u] &= \
                                                        ~can_BIT_ERROR_MASK
#define can_STUFF_ERROR_SHIFT             (5u)
/* bit 5 within INT_EN and INT_SR */
#define can_STUFF_ERROR_MASK              (0x01u << can_STUFF_ERROR_SHIFT)
#define can_STUFF_ERROR_INT_ENABLE        can_INT_EN_REG.byte[0u] |= \
                                                        can_STUFF_ERROR_MASK
#define can_STUFF_ERROR_INT_DISABLE       can_INT_EN_REG.byte[0u] &= \
                                                        ~can_STUFF_ERROR_MASK
#define can_ACK_ERROR_SHIFT               (6u)
/* bit 6 within INT_EN and INT_SR */
#define can_ACK_ERROR_MASK                (0x01u << can_ACK_ERROR_SHIFT)
#define can_ACK_ERROR_INT_ENABLE          can_INT_EN_REG.byte[0u] |= \
                                                        can_ACK_ERROR_MASK
#define can_ACK_ERROR_INT_DISABLE         can_INT_EN_REG.byte[0u] &= \
                                                        ~can_ACK_ERROR_MASK
#define can_FORM_ERROR_SHIFT              (7u)
/* bit 7 within INT_EN and INT_SR */
#define can_FORM_ERROR_MASK               (0x01u << can_FORM_ERROR_SHIFT)
#define can_FORM_ERROR_INT_ENABLE         can_INT_EN_REG.byte[0u] |= \
                                                        can_FORM_ERROR_MASK
#define can_FORM_ERROR_INT_DISABLE        can_INT_EN_REG.byte[0u] &= \
                                                        ~can_FORM_ERROR_MASK
#define can_CRC_ERROR_SHIFT               (0u)
/* bit 8 within INT_EN and INT_SR */
#define can_CRC_ERROR_MASK                (0x01u << can_CRC_ERROR_SHIFT)
#define can_CRC_ERROR_INT_ENABLE          can_INT_EN_REG.byte[1u] |= \
                                                        can_CRC_ERROR_MASK
#define can_CRC_ERROR_INT_DISABLE         can_INT_EN_REG.byte[1u] &= \
                                                        ~can_CRC_ERROR_MASK
#define can_BUS_OFF_SHIFT                 (1u)
/* bit 9 within INT_EN and INT_SR */
#define can_BUS_OFF_MASK                  (0x01u << can_BUS_OFF_SHIFT)
#define can_BUS_OFF_INT_ENABLE            can_INT_EN_REG.byte[1u] |= \
                                                        can_BUS_OFF_MASK
#define can_BUS_OFF_INT_DISABLE           can_INT_EN_REG.byte[1u] &= \
                                                        ~can_BUS_OFF_MASK
#define can_RX_MSG_LOST_SHIFT             (2u)
/* bit 10 within INT_EN and INT_SR */
#define can_RX_MSG_LOST_MASK              (0x01u << can_RX_MSG_LOST_SHIFT)
#define can_RX_MSG_LOST_INT_ENABLE        can_INT_EN_REG.byte[1u] |= \
                                                        can_RX_MSG_LOST_MASK
#define can_RX_MSG_LOST_INT_DISABLE       can_INT_EN_REG.byte[1u] &= \
                                                        ~can_RX_MSG_LOST_MASK
#define can_TX_MESSAGE_SHIFT              (3u)
/* bit 11 within INT_EN and INT_SR */
#define can_TX_MESSAGE_MASK               (0x01u << can_TX_MESSAGE_SHIFT)
#define can_TX_MSG_INT_ENABLE             can_INT_EN_REG.byte[1u] |= \
                                                        can_TX_MESSAGE_MASK
#define can_TX_MSG_INT_DISABLE            can_INT_EN_REG.byte[1u] &= \
                                                        ~can_TX_MESSAGE_MASK
#define can_RX_MESSAGE_SHIFT              (4u)
/* bit 12 within INT_EN and INT_SR */
#define can_RX_MESSAGE_MASK               (0x01u << can_RX_MESSAGE_SHIFT)
#define can_RX_MSG_INT_ENABLE             can_INT_EN_REG.byte[1u] |= \
                                                        can_RX_MESSAGE_MASK
#define can_RX_MSG_INT_DISABLE            can_INT_EN_REG.byte[1u] &= \
                                                        ~can_RX_MESSAGE_MASK

#endif /* CY_CAN_can_H */


/* [] END OF FILE */
