/*******************************************************************************
* File Name: can_INT.c
* Version 1.50
*
* Description:
*  This file contains the Interrupt Service Routine (ISR) for the CAN
*  Component. Interrupt handlers functions generate accordingly to PSoC Creator 
*  Customizer inputs.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "can.h"

/* `#START CAN_INT_C_CODE_DEFINITION` */

/* `#END` */


#if (can_ARB_LOST)

    /*******************************************************************************
    * FUNCTION NAME:   can_ArbLost
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Arbitration Lost Interrupt. Clears
    *  Arbitration Lost interrupt flag. Only generated if Arbitration Lost
    *  Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    * 
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_ArbLostIsr(void) 
    {
        /* `#START ARBITRATION_LOST_ISR` */

        /* `#END` */
    
        /* Clear Arbitration Lost flag */
        can_INT_SR_REG.byte[0u] |= can_ARBITRATION_LOST_MASK;
    }
    
#endif /* can_ARB_LOST */


#if (can_OVERLOAD)

    /*******************************************************************************
    * FUNCTION NAME:   can_OvrLdErrror
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Overload Error Interrupt. Clears Overload
    *  Error interrupt flag. Only generated if Overload Error Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.        
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_OvrLdErrorIsr(void) 
    {
        /* `#START OVER_LOAD_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Overload Error flag */
        can_INT_SR_REG.byte[0u] |= can_OVERLOAD_ERROR_MASK;
    }
    
#endif /* can_OVERLOAD */


#if (can_BIT_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   can_BitError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bit Error Interrupt. Clears Bit Error
    *  interrupt flag. Only generated if Bit Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_BitErrorIsr(void) 
    {
        /* `#START BIT_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Bit Error flag */
        can_INT_SR_REG.byte[0u] |= can_BIT_ERROR_MASK;
    }
    
#endif /* can_BIT_ERR */


#if (can_STUFF_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   can_BitStuffError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bit Stuff Error Interrupt. Clears Bit Stuff
    *  Error interrupt flag. Only generated if Bit Stuff Error Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_BitStuffErrorIsr(void) 
    {
        /* `#START BIT_STUFF_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Stuff Error flag */
        can_INT_SR_REG.byte[0u] |= can_STUFF_ERROR_MASK;
    }
    
#endif /* can_STUFF_ERR */


#if (can_ACK_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   can_AckErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Acknowledge Error Interrupt. Clears
    *  Acknowledge Error interrupt flag. Only generated if Acknowledge Error
    *  Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_AckErrorIsr(void) 
    {
        /* `#START ACKNOWLEDGE_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Acknoledge Error flag */
        can_INT_SR_REG.byte[0u] |= can_ACK_ERROR_MASK;
    }
    
#endif /* can_ACK_ERR */


#if (can_FORM_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   can_MsgError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Form Error Interrupt. Clears Form Error
    *  interrupt flag. Only generated if Form Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_MsgErrorIsr(void) 
    {
        /* `#START MESSAGE_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Form Error flag */
        can_INT_SR_REG.byte[0u] |= can_FORM_ERROR_MASK;
    }
    
#endif /* can_FORM_ERR */


#if (can_CRC_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   can_CrcError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to CRC Error Interrupt. Clears CRC Error
    *  interrupt flag. Only generated if CRC Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_CrcErrorIsr(void) 
    {
        /* `#START CRC_ERROR_ISR` */

        /* `#END` */
    
        /* Clear CRC Error flag */
        can_INT_SR_REG.byte[1u] |= can_CRC_ERROR_MASK;
    }
    
#endif /* can_CRC_ERR */


#if (can_BUS_OFF)

    /*******************************************************************************
    * FUNCTION NAME:   can_BusOff
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bus Off Interrupt. Places CAN Component
    *  to Stop mode. Only generated if Bus Off Interrupt enable in Customizer.
    *  Recommended setting to enable this interrupt.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Side Effects:
    *  Disable power to the CAN Core.
    *
    *******************************************************************************/
    void can_BusOffIsr(void) 
    {
        /* `#START BUS_OFF_ISR` */

        /* `#END` */
    
        /* Clear Bus Off flag */
        can_INT_SR_REG.byte[1u] |= can_BUS_OFF_MASK;
        can_Stop();
    }
    
#endif /* can_BUS_OFF */


#if (can_RX_MSG_LOST)

    /*******************************************************************************
    * FUNCTION NAME:   can_MsgLost
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Message Lost Interrupt. Clears Message Lost
    *  interrupt flag. Only generated if Message Lost Interrupt enable in Customizer
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_MsgLostIsr(void) 
    {
        /* `#START MESSAGE_LOST_ISR` */

        /* `#END` */
    
        /* Clear Receive Message Lost flag */
        can_INT_SR_REG.byte[1u] |= can_RX_MSG_LOST_MASK;
    }
    
#endif /* can_RX_MSG_LOST */


#if (can_TX_MESSAGE)

    /*******************************************************************************
    * FUNCTION NAME:   can_MsgTXIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Transmit Message Interrupt. Clears Transmit
    *  Message interrupt flag. Only generated if Transmit Message Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.    
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void can_MsgTXIsr(void) 
    {
        /* Clear Transmit Message flag */
        can_INT_SR_REG.byte[1u] |= can_TX_MESSAGE_MASK;
        
        /* `#START MESSAGE_TRANSMITTED_ISR` */

        /* `#END` */
    }
    
#endif /* can_TX_MESSAGE */


#if (can_RX_MESSAGE)

    /*******************************************************************************
    * FUNCTION NAME:   can_MsgRXIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Receive Message Interrupt. Clears Receive
    *  Message interrupt flag and call appropriate handlers for Basic and Full
    *  interrupt based mailboxes. Only generated if Receive Message Interrupt
    *  enable in Customizer. Recommended setting to enable this interrupt.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void can_MsgRXIsr(void) 
    {
        uint8 i;
        uint16 shift = 0x01;
    
        /* Clear Receive Message flag */
        can_INT_SR_REG.byte[1u] |= can_RX_MESSAGE_MASK;
        
        /* `#START MESSAGE_RECEIVE_ISR` */

        /* `#END` */
    
        for (i = 0u; i < can_NUMBER_OF_RX_MAILBOXES; i++)
        {
            if ((CY_GET_REG16((reg16 *) &can_BUF_SR_REG.byte[0u]) & shift) == shift)
            {
                if ((can_RX[i].rxcmd.byte[0u] & can_RX_INT_ENABLE_MASK) ==
                    can_RX_INT_ENABLE_MASK)
                {
                    if ((can_RX_MAILBOX_TYPE & shift) == shift)
                    {
                        /* RX Full mailboxes handler */
                        switch(i)
                        {
     
                            default:
                                break;
                        }
    
                    }
                    else
                    {
                        /* RX Basic mailbox handler */
                        can_ReceiveMsg(i);
                    }
                }
            }
            shift <<= 1u;
        }            
    }
    
#endif /* can_RX_MESSAGE */


/*******************************************************************************
* Function Name: can_ISR
********************************************************************************
*
* Summary:
*  This ISR is executed when CAN core generate interrupt on one of events:
*  Arb_lost, Overload, Bit_err, Stuff_err, Ack_err, Form_err, Crc_err,
*  Buss_off, Rx_msg_lost, Tx_msg or Rx_msg. The interrupt sources depends
*  on Customizer inputs.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
CY_ISR(can_ISR)
{
    /* Arbitration */
    #if (can_ARB_LOST)    
        if ((can_INT_SR_REG.byte[0u] & can_ARBITRATION_LOST_MASK) ==
             can_ARBITRATION_LOST_MASK)
        {
            can_ArbLostIsr();
        } 
    #endif /* can_ARB_LOST */
    
    /* Overload Error */
    #if (can_OVERLOAD)
        if ((can_INT_SR_REG.byte[0u] & can_OVERLOAD_ERROR_MASK) ==
             can_OVERLOAD_ERROR_MASK)
        {
            can_OvrLdErrorIsr();
        }
    #endif /* can_OVERLOAD */
    
    /* Bit Error */
    #if (can_BIT_ERR)
        if ((can_INT_SR_REG.byte[0u] & can_BIT_ERROR_MASK) == can_BIT_ERROR_MASK)
        {
            can_BitErrorIsr();
        }
    #endif /* can_BIT_ERR */
    
    /* Bit Staff Error */
    #if (can_STUFF_ERR)
        if ((can_INT_SR_REG.byte[0u] & can_STUFF_ERROR_MASK) ==
             can_STUFF_ERROR_MASK)
        {
            can_BitStuffErrorIsr();
        }
    #endif /* can_STUFF_ERR */
    
    /* ACK Error */
    #if (can_ACK_ERR)
        if ((can_INT_SR_REG.byte[0u] & can_ACK_ERROR_MASK) ==
             can_ACK_ERROR_MASK)
        {
            can_AckErrorIsr();
        }
    #endif /* can_ACK_ERR */
    
    /* Form(msg) Error */
    #if (can_FORM_ERR)
        if ((can_INT_SR_REG.byte[0u] & can_FORM_ERROR_MASK) ==
             can_FORM_ERROR_MASK)
        {
            can_MsgErrorIsr();
        }
    #endif /* can_FORM_ERR */
    
    /* CRC Error */
    #if (can_CRC_ERR)
        if ((can_INT_SR_REG.byte[1u] & can_CRC_ERROR_MASK) == can_CRC_ERROR_MASK)
        {
            can_CrcErrorIsr();
        }
    #endif /* can_CRC_ERR */
    
    /* Bus Off state */
    #if (can_BUS_OFF)
        if ((can_INT_SR_REG.byte[1u] & can_BUS_OFF_MASK) == can_BUS_OFF_MASK)
        {
            can_BusOffIsr();
        }
    #endif /* can_BUS_OFF */
    
    /* Message Lost */
    #if (can_RX_MSG_LOST)
        if ((can_INT_SR_REG.byte[1u] & can_RX_MSG_LOST_MASK) ==
             can_RX_MSG_LOST_MASK)
        {
            can_MsgLostIsr();
        }
    #endif /* can_RX_MSG_LOST */
    
    /* TX Message Send */
    #if (can_TX_MESSAGE)
        if ((can_INT_SR_REG.byte[1u] & can_TX_MESSAGE_MASK) ==
             can_TX_MESSAGE_MASK)
        {
            can_MsgTXIsr();
        }
    #endif /* can_TX_MESSAGE */
    
    /* RX Message Available */
    #if (can_RX_MESSAGE)
        if ((can_INT_SR_REG.byte[1u] & can_RX_MESSAGE_MASK) ==
             can_RX_MESSAGE_MASK)
        {
            can_MsgRXIsr();
        }
    #endif /* can_RX_MESSAGE */
    
    /* PSoC3 ES1, ES2 can ISR PATCH  */     
    #if(can_PSOC3_ES2 && (can_isr__ES2_PATCH))
        can_ISR_PATCH();
    #endif /* End can_PSOC3_ES2*/       
}


/* [] END OF FILE */
