/*******************************************************************************
* File Name: can_rx.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "can_rx.h"


/*******************************************************************************
* Function Name: can_rx_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void can_rx_Write(uint8 value)
{
    uint8 staticBits = can_rx_DR & ~can_rx_MASK;
    can_rx_DR = staticBits | ((value << can_rx_SHIFT) & can_rx_MASK);
}


/*******************************************************************************
* Function Name: can_rx_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void can_rx_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(can_rx_0, mode);
}


/*******************************************************************************
* Function Name: can_rx_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro can_rx_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 can_rx_Read(void)
{
    return (can_rx_PS & can_rx_MASK) >> can_rx_SHIFT;
}


/*******************************************************************************
* Function Name: can_rx_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 can_rx_ReadDataReg(void)
{
    return (can_rx_DR & can_rx_MASK) >> can_rx_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(can_rx_INTSTAT) 

    /*******************************************************************************
    * Function Name: can_rx_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 can_rx_ClearInterrupt(void)
    {
        return (can_rx_INTSTAT & can_rx_MASK) >> can_rx_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
