/*******************************************************************************
* File Name: clock12.h
* Version 1.50
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_clock12_H)
#define CY_CLOCK_clock12_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void clock12_Start(void) ;
void clock12_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void clock12_StopBlock(void) ;
#endif

void clock12_StandbyPower(uint8 state) ;
void clock12_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 clock12_GetDividerRegister(void) ;
void clock12_SetModeRegister(uint8 modeBitMask) ;
void clock12_ClearModeRegister(uint8 modeBitMask) ;
uint8 clock12_GetModeRegister(void) ;
void clock12_SetSourceRegister(uint8 clkSource) ;
uint8 clock12_GetSourceRegister(void) ;
#if defined(clock12__CFG3)
void clock12_SetPhaseRegister(uint8 clkPhase) ;
uint8 clock12_GetPhaseRegister(void) ;
#endif

#define clock12_Enable()                       clock12_Start()
#define clock12_Disable()                      clock12_Stop()
#define clock12_SetDivider(clkDivider)         clock12_SetDividerRegister(clkDivider, 1)
#define clock12_SetDividerValue(clkDivider)    clock12_SetDividerRegister((clkDivider) - 1, 1)
#define clock12_SetMode(clkMode)               clock12_SetModeRegister(clkMode)
#define clock12_SetSource(clkSource)           clock12_SetSourceRegister(clkSource)
#if defined(clock12__CFG3)
#define clock12_SetPhase(clkPhase)             clock12_SetPhaseRegister(clkPhase)
#define clock12_SetPhaseValue(clkPhase)        clock12_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define clock12_CLKEN              (* (reg8 *) clock12__PM_ACT_CFG)
#define clock12_CLKEN_PTR          ((reg8 *) clock12__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define clock12_CLKSTBY            (* (reg8 *) clock12__PM_STBY_CFG)
#define clock12_CLKSTBY_PTR        ((reg8 *) clock12__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define clock12_DIV_LSB            (* (reg8 *) clock12__CFG0)
#define clock12_DIV_LSB_PTR        ((reg8 *) clock12__CFG0)
#define clock12_DIV_PTR            ((reg16 *) clock12__CFG0)

/* Clock MSB divider configuration register. */
#define clock12_DIV_MSB            (* (reg8 *) clock12__CFG1)
#define clock12_DIV_MSB_PTR        ((reg8 *) clock12__CFG1)

/* Mode and source configuration register */
#define clock12_MOD_SRC            (* (reg8 *) clock12__CFG2)
#define clock12_MOD_SRC_PTR        ((reg8 *) clock12__CFG2)

#if defined(clock12__CFG3)
/* Analog clock phase configuration register */
#define clock12_PHASE              (* (reg8 *) clock12__CFG3)
#define clock12_PHASE_PTR          ((reg8 *) clock12__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define clock12_CLKEN_MASK         clock12__PM_ACT_MSK
#define clock12_CLKSTBY_MASK       clock12__PM_STBY_MSK

/* CFG2 field masks */
#define clock12_SRC_SEL_MSK        clock12__CFG2_SRC_SEL_MASK
#define clock12_MODE_MASK          (~(clock12_SRC_SEL_MSK))

#if defined(clock12__CFG3)
/* CFG3 phase mask */
#define clock12_PHASE_MASK         clock12__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_clock12_H */


/* [] END OF FILE */
