/*******************************************************************************
* File Name: clock24.h
* Version 1.50
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_clock24_H)
#define CY_CLOCK_clock24_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void clock24_Start(void) ;
void clock24_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void clock24_StopBlock(void) ;
#endif

void clock24_StandbyPower(uint8 state) ;
void clock24_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 clock24_GetDividerRegister(void) ;
void clock24_SetModeRegister(uint8 modeBitMask) ;
void clock24_ClearModeRegister(uint8 modeBitMask) ;
uint8 clock24_GetModeRegister(void) ;
void clock24_SetSourceRegister(uint8 clkSource) ;
uint8 clock24_GetSourceRegister(void) ;
#if defined(clock24__CFG3)
void clock24_SetPhaseRegister(uint8 clkPhase) ;
uint8 clock24_GetPhaseRegister(void) ;
#endif

#define clock24_Enable()                       clock24_Start()
#define clock24_Disable()                      clock24_Stop()
#define clock24_SetDivider(clkDivider)         clock24_SetDividerRegister(clkDivider, 1)
#define clock24_SetDividerValue(clkDivider)    clock24_SetDividerRegister((clkDivider) - 1, 1)
#define clock24_SetMode(clkMode)               clock24_SetModeRegister(clkMode)
#define clock24_SetSource(clkSource)           clock24_SetSourceRegister(clkSource)
#if defined(clock24__CFG3)
#define clock24_SetPhase(clkPhase)             clock24_SetPhaseRegister(clkPhase)
#define clock24_SetPhaseValue(clkPhase)        clock24_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define clock24_CLKEN              (* (reg8 *) clock24__PM_ACT_CFG)
#define clock24_CLKEN_PTR          ((reg8 *) clock24__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define clock24_CLKSTBY            (* (reg8 *) clock24__PM_STBY_CFG)
#define clock24_CLKSTBY_PTR        ((reg8 *) clock24__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define clock24_DIV_LSB            (* (reg8 *) clock24__CFG0)
#define clock24_DIV_LSB_PTR        ((reg8 *) clock24__CFG0)
#define clock24_DIV_PTR            ((reg16 *) clock24__CFG0)

/* Clock MSB divider configuration register. */
#define clock24_DIV_MSB            (* (reg8 *) clock24__CFG1)
#define clock24_DIV_MSB_PTR        ((reg8 *) clock24__CFG1)

/* Mode and source configuration register */
#define clock24_MOD_SRC            (* (reg8 *) clock24__CFG2)
#define clock24_MOD_SRC_PTR        ((reg8 *) clock24__CFG2)

#if defined(clock24__CFG3)
/* Analog clock phase configuration register */
#define clock24_PHASE              (* (reg8 *) clock24__CFG3)
#define clock24_PHASE_PTR          ((reg8 *) clock24__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define clock24_CLKEN_MASK         clock24__PM_ACT_MSK
#define clock24_CLKSTBY_MASK       clock24__PM_STBY_MSK

/* CFG2 field masks */
#define clock24_SRC_SEL_MSK        clock24__CFG2_SRC_SEL_MASK
#define clock24_MODE_MASK          (~(clock24_SRC_SEL_MSK))

#if defined(clock24__CFG3)
/* CFG3 phase mask */
#define clock24_PHASE_MASK         clock24__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_clock24_H */


/* [] END OF FILE */
