/*******************************************************************************
* File Name: debug_uart.c
* Version 2.0
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "debug_uart.h"


/***************************************
* Local data allocation
***************************************/

static debug_uart_BACKUP_STRUCT  debug_uart_backup =
{
    /* enableState - disabled */
    0u,
};        



/*******************************************************************************
* Function Name: debug_uart_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  debug_uart_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void debug_uart_SaveConfig(void)
{
    /* PSoC3 ES2 or early, PSoC5 ES1*/
    #if (debug_uart_PSOC3_ES2 || debug_uart_PSOC5_ES1)

        #if(debug_uart_CONTROL_REG_REMOVED == 0u)
            debug_uart_backup.cr = debug_uart_CONTROL_REG;
        #endif /* End debug_uart_CONTROL_REG_REMOVED */

        #if( (debug_uart_RX_ENABLED) || (debug_uart_HD_ENABLED) )
            debug_uart_backup.rx_period = debug_uart_RXBITCTR_PERIOD_REG;
            debug_uart_backup.rx_mask = debug_uart_RXSTATUS_MASK_REG;
            #if (debug_uart_RXHW_ADDRESS_ENABLED)
                debug_uart_backup.rx_addr1 = debug_uart_RXADDRESS1_REG;
                debug_uart_backup.rx_addr2 = debug_uart_RXADDRESS2_REG;
            #endif /* End debug_uart_RXHW_ADDRESS_ENABLED */
        #endif /* End debug_uart_RX_ENABLED | debug_uart_HD_ENABLED*/

        #if(debug_uart_TX_ENABLED)
            #if(debug_uart_TXCLKGEN_DP)
                debug_uart_backup.tx_clk_ctr = debug_uart_TXBITCLKGEN_CTR_REG;
                debug_uart_backup.tx_clk_compl = debug_uart_TXBITCLKTX_COMPLETE_REG;
            #else
                debug_uart_backup.tx_period = debug_uart_TXBITCTR_PERIOD_REG;
            #endif /*End debug_uart_TXCLKGEN_DP */
            debug_uart_backup.tx_mask = debug_uart_TXSTATUS_MASK_REG;
        #endif /*End debug_uart_TX_ENABLED */

    /* PSoC3 ES3 or later, PSoC5 ES2 or later*/
    #elif (debug_uart_PSOC3_ES3 || debug_uart_PSOC5_ES2)

        #if(debug_uart_CONTROL_REG_REMOVED == 0u)
            debug_uart_backup.cr = debug_uart_CONTROL_REG;
        #endif /* End debug_uart_CONTROL_REG_REMOVED */

    #endif  /* End PSOC3_ES3 || PSOC5_ES2 */
}


/*******************************************************************************
* Function Name: debug_uart_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  debug_uart_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void debug_uart_RestoreConfig(void)
{
    /* PSoC3 ES2 or early, PSoC5 ES1*/
    #if (debug_uart_PSOC3_ES2 || debug_uart_PSOC5_ES1)

        #if(debug_uart_CONTROL_REG_REMOVED == 0u)
            debug_uart_CONTROL_REG = debug_uart_backup.cr;
        #endif /* End debug_uart_CONTROL_REG_REMOVED */

        #if( (debug_uart_RX_ENABLED) || (debug_uart_HD_ENABLED) )
            debug_uart_RXBITCTR_PERIOD_REG = debug_uart_backup.rx_period;
            debug_uart_RXSTATUS_MASK_REG = debug_uart_backup.rx_mask;
            #if (debug_uart_RXHW_ADDRESS_ENABLED)
                debug_uart_RXADDRESS1_REG = debug_uart_backup.rx_addr1;
                debug_uart_RXADDRESS2_REG = debug_uart_backup.rx_addr2;
            #endif /* End debug_uart_RXHW_ADDRESS_ENABLED */
        #endif  /* End (debug_uart_RX_ENABLED) || (debug_uart_HD_ENABLED) */

        #if(debug_uart_TX_ENABLED)
            #if(debug_uart_TXCLKGEN_DP)
                debug_uart_TXBITCLKGEN_CTR_REG = debug_uart_backup.tx_clk_ctr;
                debug_uart_TXBITCLKTX_COMPLETE_REG = debug_uart_backup.tx_clk_compl;
            #else
                debug_uart_TXBITCTR_PERIOD_REG = debug_uart_backup.tx_period;
            #endif /*End debug_uart_TXCLKGEN_DP */
            debug_uart_TXSTATUS_MASK_REG = debug_uart_backup.tx_mask;
        #endif /*End debug_uart_TX_ENABLED */

    /* PSoC3 ES3 or later, PSoC5 ES2 or later*/
    #elif (debug_uart_PSOC3_ES3 || debug_uart_PSOC5_ES2)

        #if(debug_uart_CONTROL_REG_REMOVED == 0u)
            debug_uart_CONTROL_REG = debug_uart_backup.cr;
        #endif /* End debug_uart_CONTROL_REG_REMOVED */

    #endif  /* End PSOC3_ES3 || PSOC5_ES2 */
}


/*******************************************************************************
* Function Name: debug_uart_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  debug_uart_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void debug_uart_Sleep(void)
{

    #if(debug_uart_RX_ENABLED || debug_uart_HD_ENABLED)
        if((debug_uart_RXSTATUS_ACTL_REG  & debug_uart_INT_ENABLE) != 0u) 
        {
            debug_uart_backup.enableState = 1u;
        }
        else
        {
            debug_uart_backup.enableState = 0u;
        }
    #else
        if((debug_uart_TXSTATUS_ACTL_REG  & debug_uart_INT_ENABLE) !=0u)
        {
            debug_uart_backup.enableState = 1u;
        }
        else
        {
            debug_uart_backup.enableState = 0u;
        }
    #endif /* End debug_uart_RX_ENABLED || debug_uart_HD_ENABLED*/

    debug_uart_Stop();
    debug_uart_SaveConfig();
}


/*******************************************************************************
* Function Name: debug_uart_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  debug_uart_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void debug_uart_Wakeup(void)
{
    debug_uart_RestoreConfig();
    #if( (debug_uart_RX_ENABLED) || (debug_uart_HD_ENABLED) )
        debug_uart_ClearRxBuffer();
    #endif /* End (debug_uart_RX_ENABLED) || (debug_uart_HD_ENABLED) */
    #if(debug_uart_TX_ENABLED || debug_uart_HD_ENABLED)
        debug_uart_ClearTxBuffer();
    #endif /* End debug_uart_TX_ENABLED || debug_uart_HD_ENABLED */

    if(debug_uart_backup.enableState != 0u)
    {
        debug_uart_Enable();
    } 
}


/* [] END OF FILE */
