/*******************************************************************************
* File Name: gpio5.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "gpio5.h"


/*******************************************************************************
* Function Name: gpio5_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void gpio5_Write(uint8 value) 
{
    uint8 staticBits = gpio5_DR & ~gpio5_MASK;
    gpio5_DR = staticBits | ((value << gpio5_SHIFT) & gpio5_MASK);
}


/*******************************************************************************
* Function Name: gpio5_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void gpio5_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(gpio5_0, mode);
}


/*******************************************************************************
* Function Name: gpio5_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro gpio5_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 gpio5_Read(void) 
{
    return (gpio5_PS & gpio5_MASK) >> gpio5_SHIFT;
}


/*******************************************************************************
* Function Name: gpio5_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 gpio5_ReadDataReg(void) 
{
    return (gpio5_DR & gpio5_MASK) >> gpio5_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(gpio5_INTSTAT) 

    /*******************************************************************************
    * Function Name: gpio5_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 gpio5_ClearInterrupt(void) 
    {
        return (gpio5_INTSTAT & gpio5_MASK) >> gpio5_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
