/*******************************************************************************
* File Name: gpio6.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "gpio6.h"


/*******************************************************************************
* Function Name: gpio6_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void gpio6_Write(uint8 value) 
{
    uint8 staticBits = gpio6_DR & ~gpio6_MASK;
    gpio6_DR = staticBits | ((value << gpio6_SHIFT) & gpio6_MASK);
}


/*******************************************************************************
* Function Name: gpio6_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void gpio6_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(gpio6_0, mode);
}


/*******************************************************************************
* Function Name: gpio6_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro gpio6_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 gpio6_Read(void) 
{
    return (gpio6_PS & gpio6_MASK) >> gpio6_SHIFT;
}


/*******************************************************************************
* Function Name: gpio6_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 gpio6_ReadDataReg(void) 
{
    return (gpio6_DR & gpio6_MASK) >> gpio6_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(gpio6_INTSTAT) 

    /*******************************************************************************
    * Function Name: gpio6_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 gpio6_ClearInterrupt(void) 
    {
        return (gpio6_INTSTAT & gpio6_MASK) >> gpio6_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
