/*******************************************************************************
* File Name: oled_reset.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "oled_reset.h"


/*******************************************************************************
* Function Name: oled_reset_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void oled_reset_Write(uint8 value) 
{
    uint8 staticBits = oled_reset_DR & ~oled_reset_MASK;
    oled_reset_DR = staticBits | ((value << oled_reset_SHIFT) & oled_reset_MASK);
}


/*******************************************************************************
* Function Name: oled_reset_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void oled_reset_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(oled_reset_0, mode);
}


/*******************************************************************************
* Function Name: oled_reset_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro oled_reset_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 oled_reset_Read(void) 
{
    return (oled_reset_PS & oled_reset_MASK) >> oled_reset_SHIFT;
}


/*******************************************************************************
* Function Name: oled_reset_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 oled_reset_ReadDataReg(void) 
{
    return (oled_reset_DR & oled_reset_MASK) >> oled_reset_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(oled_reset_INTSTAT) 

    /*******************************************************************************
    * Function Name: oled_reset_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 oled_reset_ClearInterrupt(void) 
    {
        return (oled_reset_INTSTAT & oled_reset_MASK) >> oled_reset_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
