/*******************************************************************************
* File Name: oled_uart.h
* Version 2.0
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/


#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_UART_oled_uart_H)
#define CY_UART_oled_uart_H


/***************************************
* Conditional Compilation Parameters
***************************************/

#define oled_uart_RX_ENABLED                     (1u)
#define oled_uart_TX_ENABLED                     (1u)
#define oled_uart_HD_ENABLED                     (0u)
#define oled_uart_RX_INTERRUPT_ENABLED           (0u)
#define oled_uart_TX_INTERRUPT_ENABLED           (0u)
#define oled_uart_INTERNAL_CLOCK_USED            (1u)
#define oled_uart_RXHW_ADDRESS_ENABLED           (0u)
#define oled_uart_OVER_SAMPLE_COUNT              (8u)
#define oled_uart_PARITY_TYPE                    (0u)
#define oled_uart_PARITY_TYPE_SW                 (0u)
#define oled_uart_BREAK_DETECT                   (0u)
#define oled_uart_BREAK_BITS_TX                  (13u)
#define oled_uart_BREAK_BITS_RX                  (13u)
#define oled_uart_TXCLKGEN_DP                    (1u)
#define oled_uart_USE23POLLING                   (1u)

/* PSoC3 ES2 or early */
#define oled_uart_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define oled_uart_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define oled_uart_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES2 or later */
#define oled_uart_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

#if(oled_uart_PSOC3_ES2 && (oled_uart_RX_INTERRUPT_ENABLED || oled_uart_TX_INTERRUPT_ENABLED))
    #include <intrins.h>
    #define oled_uart_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
#endif /* End PSOC3_ES2 */

#ifdef oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define oled_uart_CONTROL_REG_REMOVED            (0u)
#else
    #define oled_uart_CONTROL_REG_REMOVED            (1u)
#endif /* End oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct _oled_uart_backupStruct
{
    uint8 enableState;

    #if(oled_uart_CONTROL_REG_REMOVED == 0u)
        uint8 cr;            
    #endif /* End oled_uart_CONTROL_REG_REMOVED */    
    #if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )
        uint8 rx_period;
        #if (oled_uart_PSOC3_ES2 || oled_uart_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 rx_mask;
            #if (oled_uart_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End oled_uart_RXHW_ADDRESS_ENABLED */
        #endif /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif  /* End (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED)*/

    #if(oled_uart_TX_ENABLED)
        #if(oled_uart_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (oled_uart_PSOC3_ES2 || oled_uart_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
                uint8 tx_clk_compl;
            #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
        #else
            uint8 tx_period;
        #endif /*End oled_uart_TXCLKGEN_DP */
        #if (oled_uart_PSOC3_ES2 || oled_uart_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 tx_mask;
        #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif /*End oled_uart_TX_ENABLED */
} oled_uart_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void oled_uart_Start(void);
void oled_uart_Stop(void) ;
uint8 oled_uart_ReadControlRegister(void) ;
void oled_uart_WriteControlRegister(uint8 control) ;

void oled_uart_Init(void) ;
void oled_uart_Enable(void) ;
void oled_uart_SaveConfig(void);
void oled_uart_RestoreConfig(void);
void oled_uart_Sleep(void);
void oled_uart_Wakeup(void);

/* Only if RX is enabled */
#if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )

    #if(oled_uart_RX_INTERRUPT_ENABLED)
        void  oled_uart_EnableRxInt(void) ;
        void  oled_uart_DisableRxInt(void) ;
        CY_ISR_PROTO(oled_uart_RXISR);
    #endif /* oled_uart_RX_INTERRUPT_ENABLED */

    #if (oled_uart_RXHW_ADDRESS_ENABLED)
        void oled_uart_SetRxAddressMode(uint8 addressMode) 
                                                            ;
        void oled_uart_SetRxAddress1(uint8 address) ;
        void oled_uart_SetRxAddress2(uint8 address) ;
    #endif /* End oled_uart_RXHW_ADDRESS_ENABLED */

    void  oled_uart_SetRxInterruptMode(uint8 intSrc) ;
    uint8 oled_uart_ReadRxData(void);
    uint8 oled_uart_ReadRxStatus(void) ;
    uint8 oled_uart_GetChar(void);
    uint16 oled_uart_GetByte(void);
    uint8 oled_uart_GetRxBufferSize(void);
    void oled_uart_ClearRxBuffer(void);

    /* Obsolete functions, defines for backward compatible */
    #define oled_uart_GetRxInterruptSource   oled_uart_ReadRxStatus

#endif /* End (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) */

/* Only if TX is enabled */
#if(oled_uart_TX_ENABLED || oled_uart_HD_ENABLED)

    #if(oled_uart_TX_INTERRUPT_ENABLED)
        void oled_uart_EnableTxInt(void) ;
        void oled_uart_DisableTxInt(void) ;
        CY_ISR_PROTO(oled_uart_TXISR);
    #endif /* oled_uart_TX_INTERRUPT_ENABLED */

    void oled_uart_SetTxInterruptMode(uint8 intSrc) ;
    void oled_uart_WriteTxData(uint8 txDataByte);
    uint8 oled_uart_ReadTxStatus(void) ;
    void oled_uart_PutChar(uint8 txDataByte);
    void oled_uart_PutString(uint8* string);
    void oled_uart_PutArray(uint8* string, uint8 byteCount);
    void oled_uart_PutCRLF(uint8 txDataByte);
    void oled_uart_ClearTxBuffer(void);
    void oled_uart_SetTxAddressMode(uint8 addressMode) ;
    void oled_uart_SendBreak(uint8 retMode);
    uint8 oled_uart_GetTxBufferSize(void);
    /* Obsolete functions, defines for backward compatible */
    #define oled_uart_PutStringConst         oled_uart_PutString
    #define oled_uart_PutArrayConst          oled_uart_PutArray
    #define oled_uart_GetTxInterruptSource   oled_uart_ReadTxStatus
    
#endif /* End oled_uart_TX_ENABLED || oled_uart_HD_ENABLED */

#if(oled_uart_HD_ENABLED)
    void oled_uart_LoadRxConfig(void) ;
    void oled_uart_LoadTxConfig(void) ;
#endif /* End oled_uart_HD_ENABLED */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define oled_uart_SET_SPACE                              (0x00u)
#define oled_uart_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (oled_uart_TX_ENABLED) || (oled_uart_HD_ENABLED) )
    #if(oled_uart_TX_INTERRUPT_ENABLED)
        #define oled_uart_TX_VECT_NUM                oled_uart_TXInternalInterrupt__INTC_NUMBER
        #define oled_uart_TX_PRIOR_NUM               oled_uart_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* oled_uart_TX_INTERRUPT_ENABLED */
    #if(oled_uart_TX_ENABLED) 
        #define oled_uart_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define oled_uart_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define oled_uart_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define oled_uart_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* oled_uart_TX_ENABLED */
    #if(oled_uart_HD_ENABLED) 
        #define oled_uart_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define oled_uart_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define oled_uart_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define oled_uart_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* oled_uart_HD_ENABLED */
    #define oled_uart_TX_STS_COMPLETE                (0x01u << oled_uart_TX_STS_COMPLETE_SHIFT)
    #define oled_uart_TX_STS_FIFO_EMPTY              (0x01u << oled_uart_TX_STS_FIFO_EMPTY_SHIFT)
    #define oled_uart_TX_STS_FIFO_FULL               (0x01u << oled_uart_TX_STS_FIFO_FULL_SHIFT)
    #define oled_uart_TX_STS_FIFO_NOT_FULL           (0x01u << oled_uart_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (oled_uart_TX_ENABLED) || (oled_uart_HD_ENABLED)*/

#if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )
    #if(oled_uart_RX_INTERRUPT_ENABLED)
        #define oled_uart_RX_VECT_NUM                oled_uart_RXInternalInterrupt__INTC_NUMBER
        #define oled_uart_RX_PRIOR_NUM               oled_uart_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* oled_uart_RX_INTERRUPT_ENABLED */
    #define oled_uart_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define oled_uart_RX_STS_BREAK_SHIFT             (0x01u)
    #define oled_uart_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define oled_uart_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define oled_uart_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define oled_uart_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define oled_uart_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define oled_uart_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define oled_uart_RX_STS_MRKSPC                  (0x01u << oled_uart_RX_STS_MRKSPC_SHIFT)
    #define oled_uart_RX_STS_BREAK                   (0x01u << oled_uart_RX_STS_BREAK_SHIFT)
    #define oled_uart_RX_STS_PAR_ERROR               (0x01u << oled_uart_RX_STS_PAR_ERROR_SHIFT)
    #define oled_uart_RX_STS_STOP_ERROR              (0x01u << oled_uart_RX_STS_STOP_ERROR_SHIFT)
    #define oled_uart_RX_STS_OVERRUN                 (0x01u << oled_uart_RX_STS_OVERRUN_SHIFT)
    #define oled_uart_RX_STS_FIFO_NOTEMPTY           (0x01u << oled_uart_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define oled_uart_RX_STS_ADDR_MATCH              (0x01u << oled_uart_RX_STS_ADDR_MATCH_SHIFT)
    #define oled_uart_RX_STS_SOFT_BUFF_OVER          (0x01u << oled_uart_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define oled_uart_RX_HW_MASK                     (0x7Fu)
#endif /* End (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) */

/* Control Register definitions */
#define oled_uart_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define oled_uart_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define oled_uart_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define oled_uart_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define oled_uart_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define oled_uart_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define oled_uart_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define oled_uart_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define oled_uart_CTRL_HD_SEND                       (0x01u << oled_uart_CTRL_HD_SEND_SHIFT)
#define oled_uart_CTRL_HD_SEND_BREAK                 (0x01u << oled_uart_CTRL_HD_SEND_BREAK_SHIFT)
#define oled_uart_CTRL_MARK                          (0x01u << oled_uart_CTRL_MARK_SHIFT)
#define oled_uart_CTRL_PARITY_TYPE_MASK              (0x03u << oled_uart_CTRL_PARITY_TYPE0_SHIFT)
#define oled_uart_CTRL_RXADDR_MODE_MASK              (0x07u << oled_uart_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define oled_uart_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define oled_uart_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define oled_uart_SEND_BREAK                         (0x00u)
#define oled_uart_WAIT_FOR_COMLETE_REINIT            (0x01u)
#define oled_uart_REINIT                             (0x02u)
#define oled_uart_SEND_WAIT_REINIT                   (0x03u)

#define oled_uart_OVER_SAMPLE_8                      (8u)
#define oled_uart_OVER_SAMPLE_16                     (16u)

#define oled_uart_BIT_CENTER                         (oled_uart_OVER_SAMPLE_COUNT - 1u)

#define oled_uart_FIFO_LENGTH                        (4u)
#define oled_uart_NUMBER_OF_START_BIT                (1u)

/* 8X always for count7 implementation*/
#define oled_uart_TXBITCTR_BREAKBITS8X   (oled_uart_BREAK_BITS_TX * oled_uart_OVER_SAMPLE_8 - 1u)
/* 8X or 16X for DP implementation*/
#define oled_uart_TXBITCTR_BREAKBITS   (oled_uart_BREAK_BITS_TX * oled_uart_OVER_SAMPLE_COUNT - 1u)

#if (oled_uart_OVER_SAMPLE_COUNT == oled_uart_OVER_SAMPLE_8)
    #define oled_uart_HD_TXBITCTR_INIT   ((oled_uart_BREAK_BITS_TX + \
        oled_uart_NUMBER_OF_START_BIT) * oled_uart_OVER_SAMPLE_COUNT - 1u)
    /* This parameter is increased on the 1 in 2 out of 3 mode to sample voting in the middle */
    #define oled_uart_HD_RXBITCTR_INIT   ((oled_uart_BREAK_BITS_RX + \
    oled_uart_NUMBER_OF_START_BIT) * oled_uart_OVER_SAMPLE_COUNT - 1u + \
    (oled_uart_OVER_SAMPLE_COUNT / 2u) + (oled_uart_USE23POLLING * 2u) - 1u)
#else /* oled_uart_OVER_SAMPLE_COUNT == oled_uart_OVER_SAMPLE_16 */
    #define oled_uart_HD_TXBITCTR_INIT   (8u * oled_uart_OVER_SAMPLE_COUNT - 1u)
    #define oled_uart_HD_RXBITCTR_INIT   (7u * oled_uart_OVER_SAMPLE_COUNT - 1u  +  \
       (oled_uart_OVER_SAMPLE_COUNT / 2u) + (oled_uart_USE23POLLING * 2u) - 1u)
#endif /* End oled_uart_OVER_SAMPLE_COUNT */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define oled_uart__B_UART__AM_SW_BYTE_BYTE 1
#define oled_uart__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define oled_uart__B_UART__AM_HW_BYTE_BY_BYTE 3
#define oled_uart__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define oled_uart__B_UART__AM_NONE 0

#define oled_uart__B_UART__NONE_REVB 0
#define oled_uart__B_UART__EVEN_REVB 1
#define oled_uart__B_UART__ODD_REVB 2
#define oled_uart__B_UART__MARK_SPACE_REVB 3


/***************************************
*    Initial Parameter Constants
***************************************/

#define oled_uart_TXBUFFERSIZE           (4u)
#define oled_uart_RXBUFFERSIZE           (4u)
/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define oled_uart_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define oled_uart_NUMBER_OF_STOP_BITS    (1u)

#if (oled_uart_RXHW_ADDRESS_ENABLED)
    #define oled_uart_RXAddressMode      (0u)
    #define oled_uart_RXHWADDRESS1       (0u)
    #define oled_uart_RXHWADDRESS2       (0u)
#endif /* End EnableHWAddress */

#define oled_uart_INIT_RX_INTERRUPTS_MASK \
                                          (1 << oled_uart_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << oled_uart_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << oled_uart_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << oled_uart_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << oled_uart_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << oled_uart_RX_STS_BREAK_SHIFT) \
                                        | (0 << oled_uart_RX_STS_OVERRUN_SHIFT)

#define oled_uart_INIT_TX_INTERRUPTS_MASK \
                                          (0 << oled_uart_TX_STS_COMPLETE_SHIFT) \
                                        | (1 << oled_uart_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << oled_uart_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << oled_uart_TX_STS_FIFO_NOT_FULL_SHIFT)


/***************************************
*              Registers
***************************************/

#ifdef oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define oled_uart_CONTROL_REG \
                            (* (reg8 *) oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
    #define oled_uart_CONTROL_PTR \
                            (  (reg8 *) oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
#endif /* End oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(oled_uart_TX_ENABLED)
    #define oled_uart_TXDATA_REG          (* (reg8 *) oled_uart_BUART_sTX_TxShifter_u0__F0_REG)
    #define oled_uart_TXDATA_PTR          (  (reg8 *) oled_uart_BUART_sTX_TxShifter_u0__F0_REG)

    #define oled_uart_TXSTATUS_REG        (* (reg8 *) oled_uart_BUART_sTX_TxSts__STATUS_REG)
    #define oled_uart_TXSTATUS_PTR        (  (reg8 *) oled_uart_BUART_sTX_TxSts__STATUS_REG)
    #define oled_uart_TXSTATUS_MASK_REG   (* (reg8 *) oled_uart_BUART_sTX_TxSts__MASK_REG)
    #define oled_uart_TXSTATUS_MASK_PTR   (  (reg8 *) oled_uart_BUART_sTX_TxSts__MASK_REG)
    #define oled_uart_TXSTATUS_ACTL_REG   (* (reg8 *) oled_uart_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define oled_uart_TXSTATUS_ACTL_PTR   (  (reg8 *) oled_uart_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(oled_uart_TXCLKGEN_DP)
        #define oled_uart_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define oled_uart_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define oled_uart_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define oled_uart_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define oled_uart_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define oled_uart_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define oled_uart_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define oled_uart_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define oled_uart_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define oled_uart_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) oled_uart_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* oled_uart_TXCLKGEN_DP */

#endif /* End oled_uart_TX_ENABLED */

#if(oled_uart_HD_ENABLED)

    #define oled_uart_TXDATA_REG             (* (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__F1_REG )
    #define oled_uart_TXDATA_PTR             (  (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__F1_REG )

    #define oled_uart_TXSTATUS_REG           (* (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_REG )
    #define oled_uart_TXSTATUS_PTR           (  (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_REG )
    #define oled_uart_TXSTATUS_MASK_REG      (* (reg8 *) oled_uart_BUART_sRX_RxSts__MASK_REG )
    #define oled_uart_TXSTATUS_MASK_PTR      (  (reg8 *) oled_uart_BUART_sRX_RxSts__MASK_REG )
    #define oled_uart_TXSTATUS_ACTL_REG      (* (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define oled_uart_TXSTATUS_ACTL_PTR      (  (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End oled_uart_HD_ENABLED */

#if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )
    #define oled_uart_RXDATA_REG             (* (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__F0_REG )
    #define oled_uart_RXDATA_PTR             (  (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__F0_REG )
    #define oled_uart_RXADDRESS1_REG         (* (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__D0_REG )
    #define oled_uart_RXADDRESS1_PTR         (  (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__D0_REG )
    #define oled_uart_RXADDRESS2_REG         (* (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__D1_REG )
    #define oled_uart_RXADDRESS2_PTR         (  (reg8 *) oled_uart_BUART_sRX_RxShifter_u0__D1_REG )

    #define oled_uart_RXBITCTR_PERIOD_REG    (* (reg8 *) oled_uart_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define oled_uart_RXBITCTR_PERIOD_PTR    (  (reg8 *) oled_uart_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define oled_uart_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) oled_uart_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define oled_uart_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) oled_uart_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define oled_uart_RXBITCTR_COUNTER_REG   (* (reg8 *) oled_uart_BUART_sRX_RxBitCounter__COUNT_REG )
    #define oled_uart_RXBITCTR_COUNTER_PTR   (  (reg8 *) oled_uart_BUART_sRX_RxBitCounter__COUNT_REG )

    #define oled_uart_RXSTATUS_REG           (* (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_REG )
    #define oled_uart_RXSTATUS_PTR           (  (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_REG )
    #define oled_uart_RXSTATUS_MASK_REG      (* (reg8 *) oled_uart_BUART_sRX_RxSts__MASK_REG )
    #define oled_uart_RXSTATUS_MASK_PTR      (  (reg8 *) oled_uart_BUART_sRX_RxSts__MASK_REG )
    #define oled_uart_RXSTATUS_ACTL_REG      (* (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define oled_uart_RXSTATUS_ACTL_PTR      (  (reg8 *) oled_uart_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) */

#if(oled_uart_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define oled_uart_INTCLOCK_CLKEN_REG     (* (reg8 *) oled_uart_IntClock__PM_ACT_CFG)
    #define oled_uart_INTCLOCK_CLKEN_PTR     (  (reg8 *) oled_uart_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define oled_uart_INTCLOCK_CLKEN_MASK    oled_uart_IntClock__PM_ACT_MSK
#endif /* End oled_uart_INTERNAL_CLOCK_USED */


/***************************************
* Renamed global variables or defines 
* for backward compatible
***************************************/

#define oled_uart_initvar                    oled_uart_initVar

#define oled_uart_RX_Enabled                 oled_uart_RX_ENABLED
#define oled_uart_TX_Enabled                 oled_uart_TX_ENABLED
#define oled_uart_HD_Enabled                 oled_uart_HD_ENABLED
#define oled_uart_RX_IntInterruptEnabled     oled_uart_RX_INTERRUPT_ENABLED
#define oled_uart_TX_IntInterruptEnabled     oled_uart_TX_INTERRUPT_ENABLED
#define oled_uart_InternalClockUsed          oled_uart_INTERNAL_CLOCK_USED
#define oled_uart_RXHW_Address_Enabled       oled_uart_RXHW_ADDRESS_ENABLED
#define oled_uart_OverSampleCount            oled_uart_OVER_SAMPLE_COUNT
#define oled_uart_ParityType                 oled_uart_PARITY_TYPE

#if( oled_uart_TX_ENABLED && (oled_uart_TXBUFFERSIZE > oled_uart_FIFO_LENGTH))
    #define oled_uart_TXBUFFER               oled_uart_txBuffer
    #define oled_uart_TXBUFFERREAD           oled_uart_txBufferRead 
    #define oled_uart_TXBUFFERWRITE          oled_uart_txBufferWrite 
#endif /* End oled_uart_TX_ENABLED */
#if( ( oled_uart_RX_ENABLED || oled_uart_HD_ENABLED ) && \
     (oled_uart_RXBUFFERSIZE > oled_uart_FIFO_LENGTH) )
    #define oled_uart_RXBUFFER               oled_uart_rxBuffer
    #define oled_uart_RXBUFFERREAD           oled_uart_rxBufferRead 
    #define oled_uart_RXBUFFERWRITE          oled_uart_rxBufferWrite 
    #define oled_uart_RXBUFFERLOOPDETECT     oled_uart_rxBufferLoopDetect
    #define oled_uart_RXBUFFER_OVERFLOW      oled_uart_rxBufferOverflow
#endif /* End oled_uart_RX_ENABLED */

#ifdef oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define oled_uart_CONTROL                oled_uart_CONTROL_REG 
#endif /* End oled_uart_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(oled_uart_TX_ENABLED)
    #define oled_uart_TXDATA                 oled_uart_TXDATA_REG
    #define oled_uart_TXSTATUS               oled_uart_TXSTATUS_REG
    #define oled_uart_TXSTATUS_MASK          oled_uart_TXSTATUS_MASK_REG   
    #define oled_uart_TXSTATUS_ACTL          oled_uart_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(oled_uart_TXCLKGEN_DP)
        #define oled_uart_TXBITCLKGEN_CTR        oled_uart_TXBITCLKGEN_CTR_REG
        #define oled_uart_TXBITCLKTX_COMPLETE    oled_uart_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define oled_uart_TXBITCTR_PERIOD        oled_uart_TXBITCTR_PERIOD_REG
        #define oled_uart_TXBITCTR_CONTROL       oled_uart_TXBITCTR_CONTROL_REG
        #define oled_uart_TXBITCTR_COUNTER       oled_uart_TXBITCTR_COUNTER_REG
    #endif /* oled_uart_TXCLKGEN_DP */
#endif /* End oled_uart_TX_ENABLED */

#if(oled_uart_HD_ENABLED)
    #define oled_uart_TXDATA                 oled_uart_TXDATA_REG
    #define oled_uart_TXSTATUS               oled_uart_TXSTATUS_REG
    #define oled_uart_TXSTATUS_MASK          oled_uart_TXSTATUS_MASK_REG   
    #define oled_uart_TXSTATUS_ACTL          oled_uart_TXSTATUS_ACTL_REG
#endif /* End oled_uart_HD_ENABLED */

#if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )
    #define oled_uart_RXDATA                 oled_uart_RXDATA_REG             
    #define oled_uart_RXADDRESS1             oled_uart_RXADDRESS1_REG
    #define oled_uart_RXADDRESS2             oled_uart_RXADDRESS2_REG
    #define oled_uart_RXBITCTR_PERIOD        oled_uart_RXBITCTR_PERIOD_REG
    #define oled_uart_RXBITCTR_CONTROL       oled_uart_RXBITCTR_CONTROL_REG
    #define oled_uart_RXBITCTR_COUNTER       oled_uart_RXBITCTR_COUNTER_REG
    #define oled_uart_RXSTATUS               oled_uart_RXSTATUS_REG
    #define oled_uart_RXSTATUS_MASK          oled_uart_RXSTATUS_MASK_REG
    #define oled_uart_RXSTATUS_ACTL          oled_uart_RXSTATUS_ACTL_REG
#endif /* End  (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) */

#if(oled_uart_INTERNAL_CLOCK_USED)
    #define oled_uart_INTCLOCK_CLKEN         oled_uart_INTCLOCK_CLKEN_REG
#endif /* End oled_uart_INTERNAL_CLOCK_USED */

#endif  /* CY_UART_oled_uart_H */


/* [] END OF FILE */
