/*******************************************************************************
* File Name: oled_uart.c
* Version 2.0
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "oled_uart.h"


/***************************************
* Local data allocation
***************************************/

static oled_uart_BACKUP_STRUCT  oled_uart_backup =
{
    /* enableState - disabled */
    0u,
};        



/*******************************************************************************
* Function Name: oled_uart_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  oled_uart_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void oled_uart_SaveConfig(void)
{
    /* PSoC3 ES2 or early, PSoC5 ES1*/
    #if (oled_uart_PSOC3_ES2 || oled_uart_PSOC5_ES1)

        #if(oled_uart_CONTROL_REG_REMOVED == 0u)
            oled_uart_backup.cr = oled_uart_CONTROL_REG;
        #endif /* End oled_uart_CONTROL_REG_REMOVED */

        #if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )
            oled_uart_backup.rx_period = oled_uart_RXBITCTR_PERIOD_REG;
            oled_uart_backup.rx_mask = oled_uart_RXSTATUS_MASK_REG;
            #if (oled_uart_RXHW_ADDRESS_ENABLED)
                oled_uart_backup.rx_addr1 = oled_uart_RXADDRESS1_REG;
                oled_uart_backup.rx_addr2 = oled_uart_RXADDRESS2_REG;
            #endif /* End oled_uart_RXHW_ADDRESS_ENABLED */
        #endif /* End oled_uart_RX_ENABLED | oled_uart_HD_ENABLED*/

        #if(oled_uart_TX_ENABLED)
            #if(oled_uart_TXCLKGEN_DP)
                oled_uart_backup.tx_clk_ctr = oled_uart_TXBITCLKGEN_CTR_REG;
                oled_uart_backup.tx_clk_compl = oled_uart_TXBITCLKTX_COMPLETE_REG;
            #else
                oled_uart_backup.tx_period = oled_uart_TXBITCTR_PERIOD_REG;
            #endif /*End oled_uart_TXCLKGEN_DP */
            oled_uart_backup.tx_mask = oled_uart_TXSTATUS_MASK_REG;
        #endif /*End oled_uart_TX_ENABLED */

    /* PSoC3 ES3 or later, PSoC5 ES2 or later*/
    #elif (oled_uart_PSOC3_ES3 || oled_uart_PSOC5_ES2)

        #if(oled_uart_CONTROL_REG_REMOVED == 0u)
            oled_uart_backup.cr = oled_uart_CONTROL_REG;
        #endif /* End oled_uart_CONTROL_REG_REMOVED */

    #endif  /* End PSOC3_ES3 || PSOC5_ES2 */
}


/*******************************************************************************
* Function Name: oled_uart_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  oled_uart_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void oled_uart_RestoreConfig(void)
{
    /* PSoC3 ES2 or early, PSoC5 ES1*/
    #if (oled_uart_PSOC3_ES2 || oled_uart_PSOC5_ES1)

        #if(oled_uart_CONTROL_REG_REMOVED == 0u)
            oled_uart_CONTROL_REG = oled_uart_backup.cr;
        #endif /* End oled_uart_CONTROL_REG_REMOVED */

        #if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )
            oled_uart_RXBITCTR_PERIOD_REG = oled_uart_backup.rx_period;
            oled_uart_RXSTATUS_MASK_REG = oled_uart_backup.rx_mask;
            #if (oled_uart_RXHW_ADDRESS_ENABLED)
                oled_uart_RXADDRESS1_REG = oled_uart_backup.rx_addr1;
                oled_uart_RXADDRESS2_REG = oled_uart_backup.rx_addr2;
            #endif /* End oled_uart_RXHW_ADDRESS_ENABLED */
        #endif  /* End (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) */

        #if(oled_uart_TX_ENABLED)
            #if(oled_uart_TXCLKGEN_DP)
                oled_uart_TXBITCLKGEN_CTR_REG = oled_uart_backup.tx_clk_ctr;
                oled_uart_TXBITCLKTX_COMPLETE_REG = oled_uart_backup.tx_clk_compl;
            #else
                oled_uart_TXBITCTR_PERIOD_REG = oled_uart_backup.tx_period;
            #endif /*End oled_uart_TXCLKGEN_DP */
            oled_uart_TXSTATUS_MASK_REG = oled_uart_backup.tx_mask;
        #endif /*End oled_uart_TX_ENABLED */

    /* PSoC3 ES3 or later, PSoC5 ES2 or later*/
    #elif (oled_uart_PSOC3_ES3 || oled_uart_PSOC5_ES2)

        #if(oled_uart_CONTROL_REG_REMOVED == 0u)
            oled_uart_CONTROL_REG = oled_uart_backup.cr;
        #endif /* End oled_uart_CONTROL_REG_REMOVED */

    #endif  /* End PSOC3_ES3 || PSOC5_ES2 */
}


/*******************************************************************************
* Function Name: oled_uart_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  oled_uart_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void oled_uart_Sleep(void)
{

    #if(oled_uart_RX_ENABLED || oled_uart_HD_ENABLED)
        if((oled_uart_RXSTATUS_ACTL_REG  & oled_uart_INT_ENABLE) != 0u) 
        {
            oled_uart_backup.enableState = 1u;
        }
        else
        {
            oled_uart_backup.enableState = 0u;
        }
    #else
        if((oled_uart_TXSTATUS_ACTL_REG  & oled_uart_INT_ENABLE) !=0u)
        {
            oled_uart_backup.enableState = 1u;
        }
        else
        {
            oled_uart_backup.enableState = 0u;
        }
    #endif /* End oled_uart_RX_ENABLED || oled_uart_HD_ENABLED*/

    oled_uart_Stop();
    oled_uart_SaveConfig();
}


/*******************************************************************************
* Function Name: oled_uart_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  oled_uart_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void oled_uart_Wakeup(void)
{
    oled_uart_RestoreConfig();
    #if( (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) )
        oled_uart_ClearRxBuffer();
    #endif /* End (oled_uart_RX_ENABLED) || (oled_uart_HD_ENABLED) */
    #if(oled_uart_TX_ENABLED || oled_uart_HD_ENABLED)
        oled_uart_ClearTxBuffer();
    #endif /* End oled_uart_TX_ENABLED || oled_uart_HD_ENABLED */

    if(oled_uart_backup.enableState != 0u)
    {
        oled_uart_Enable();
    } 
}


/* [] END OF FILE */
