/*******************************************************************************
* File Name: rs232.h
* Version 2.0
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/


#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_UART_rs232_H)
#define CY_UART_rs232_H


/***************************************
* Conditional Compilation Parameters
***************************************/

#define rs232_RX_ENABLED                     (1u)
#define rs232_TX_ENABLED                     (1u)
#define rs232_HD_ENABLED                     (0u)
#define rs232_RX_INTERRUPT_ENABLED           (0u)
#define rs232_TX_INTERRUPT_ENABLED           (0u)
#define rs232_INTERNAL_CLOCK_USED            (1u)
#define rs232_RXHW_ADDRESS_ENABLED           (0u)
#define rs232_OVER_SAMPLE_COUNT              (8u)
#define rs232_PARITY_TYPE                    (0u)
#define rs232_PARITY_TYPE_SW                 (0u)
#define rs232_BREAK_DETECT                   (0u)
#define rs232_BREAK_BITS_TX                  (13u)
#define rs232_BREAK_BITS_RX                  (13u)
#define rs232_TXCLKGEN_DP                    (1u)
#define rs232_USE23POLLING                   (1u)

/* PSoC3 ES2 or early */
#define rs232_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define rs232_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define rs232_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES2 or later */
#define rs232_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

#if(rs232_PSOC3_ES2 && (rs232_RX_INTERRUPT_ENABLED || rs232_TX_INTERRUPT_ENABLED))
    #include <intrins.h>
    #define rs232_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
#endif /* End PSOC3_ES2 */

#ifdef rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define rs232_CONTROL_REG_REMOVED            (0u)
#else
    #define rs232_CONTROL_REG_REMOVED            (1u)
#endif /* End rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct _rs232_backupStruct
{
    uint8 enableState;

    #if(rs232_CONTROL_REG_REMOVED == 0u)
        uint8 cr;            
    #endif /* End rs232_CONTROL_REG_REMOVED */    
    #if( (rs232_RX_ENABLED) || (rs232_HD_ENABLED) )
        uint8 rx_period;
        #if (rs232_PSOC3_ES2 || rs232_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 rx_mask;
            #if (rs232_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End rs232_RXHW_ADDRESS_ENABLED */
        #endif /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif  /* End (rs232_RX_ENABLED) || (rs232_HD_ENABLED)*/

    #if(rs232_TX_ENABLED)
        #if(rs232_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (rs232_PSOC3_ES2 || rs232_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
                uint8 tx_clk_compl;
            #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
        #else
            uint8 tx_period;
        #endif /*End rs232_TXCLKGEN_DP */
        #if (rs232_PSOC3_ES2 || rs232_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 tx_mask;
        #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif /*End rs232_TX_ENABLED */
} rs232_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void rs232_Start(void);
void rs232_Stop(void) ;
uint8 rs232_ReadControlRegister(void) ;
void rs232_WriteControlRegister(uint8 control) ;

void rs232_Init(void) ;
void rs232_Enable(void) ;
void rs232_SaveConfig(void);
void rs232_RestoreConfig(void);
void rs232_Sleep(void);
void rs232_Wakeup(void);

/* Only if RX is enabled */
#if( (rs232_RX_ENABLED) || (rs232_HD_ENABLED) )

    #if(rs232_RX_INTERRUPT_ENABLED)
        void  rs232_EnableRxInt(void) ;
        void  rs232_DisableRxInt(void) ;
        CY_ISR_PROTO(rs232_RXISR);
    #endif /* rs232_RX_INTERRUPT_ENABLED */

    #if (rs232_RXHW_ADDRESS_ENABLED)
        void rs232_SetRxAddressMode(uint8 addressMode) 
                                                            ;
        void rs232_SetRxAddress1(uint8 address) ;
        void rs232_SetRxAddress2(uint8 address) ;
    #endif /* End rs232_RXHW_ADDRESS_ENABLED */

    void  rs232_SetRxInterruptMode(uint8 intSrc) ;
    uint8 rs232_ReadRxData(void);
    uint8 rs232_ReadRxStatus(void) ;
    uint8 rs232_GetChar(void);
    uint16 rs232_GetByte(void);
    uint8 rs232_GetRxBufferSize(void);
    void rs232_ClearRxBuffer(void);

    /* Obsolete functions, defines for backward compatible */
    #define rs232_GetRxInterruptSource   rs232_ReadRxStatus

#endif /* End (rs232_RX_ENABLED) || (rs232_HD_ENABLED) */

/* Only if TX is enabled */
#if(rs232_TX_ENABLED || rs232_HD_ENABLED)

    #if(rs232_TX_INTERRUPT_ENABLED)
        void rs232_EnableTxInt(void) ;
        void rs232_DisableTxInt(void) ;
        CY_ISR_PROTO(rs232_TXISR);
    #endif /* rs232_TX_INTERRUPT_ENABLED */

    void rs232_SetTxInterruptMode(uint8 intSrc) ;
    void rs232_WriteTxData(uint8 txDataByte);
    uint8 rs232_ReadTxStatus(void) ;
    void rs232_PutChar(uint8 txDataByte);
    void rs232_PutString(uint8* string);
    void rs232_PutArray(uint8* string, uint8 byteCount);
    void rs232_PutCRLF(uint8 txDataByte);
    void rs232_ClearTxBuffer(void);
    void rs232_SetTxAddressMode(uint8 addressMode) ;
    void rs232_SendBreak(uint8 retMode);
    uint8 rs232_GetTxBufferSize(void);
    /* Obsolete functions, defines for backward compatible */
    #define rs232_PutStringConst         rs232_PutString
    #define rs232_PutArrayConst          rs232_PutArray
    #define rs232_GetTxInterruptSource   rs232_ReadTxStatus
    
#endif /* End rs232_TX_ENABLED || rs232_HD_ENABLED */

#if(rs232_HD_ENABLED)
    void rs232_LoadRxConfig(void) ;
    void rs232_LoadTxConfig(void) ;
#endif /* End rs232_HD_ENABLED */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define rs232_SET_SPACE                              (0x00u)
#define rs232_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (rs232_TX_ENABLED) || (rs232_HD_ENABLED) )
    #if(rs232_TX_INTERRUPT_ENABLED)
        #define rs232_TX_VECT_NUM                rs232_TXInternalInterrupt__INTC_NUMBER
        #define rs232_TX_PRIOR_NUM               rs232_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* rs232_TX_INTERRUPT_ENABLED */
    #if(rs232_TX_ENABLED) 
        #define rs232_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define rs232_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define rs232_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define rs232_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* rs232_TX_ENABLED */
    #if(rs232_HD_ENABLED) 
        #define rs232_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define rs232_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define rs232_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define rs232_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* rs232_HD_ENABLED */
    #define rs232_TX_STS_COMPLETE                (0x01u << rs232_TX_STS_COMPLETE_SHIFT)
    #define rs232_TX_STS_FIFO_EMPTY              (0x01u << rs232_TX_STS_FIFO_EMPTY_SHIFT)
    #define rs232_TX_STS_FIFO_FULL               (0x01u << rs232_TX_STS_FIFO_FULL_SHIFT)
    #define rs232_TX_STS_FIFO_NOT_FULL           (0x01u << rs232_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (rs232_TX_ENABLED) || (rs232_HD_ENABLED)*/

#if( (rs232_RX_ENABLED) || (rs232_HD_ENABLED) )
    #if(rs232_RX_INTERRUPT_ENABLED)
        #define rs232_RX_VECT_NUM                rs232_RXInternalInterrupt__INTC_NUMBER
        #define rs232_RX_PRIOR_NUM               rs232_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* rs232_RX_INTERRUPT_ENABLED */
    #define rs232_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define rs232_RX_STS_BREAK_SHIFT             (0x01u)
    #define rs232_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define rs232_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define rs232_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define rs232_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define rs232_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define rs232_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define rs232_RX_STS_MRKSPC                  (0x01u << rs232_RX_STS_MRKSPC_SHIFT)
    #define rs232_RX_STS_BREAK                   (0x01u << rs232_RX_STS_BREAK_SHIFT)
    #define rs232_RX_STS_PAR_ERROR               (0x01u << rs232_RX_STS_PAR_ERROR_SHIFT)
    #define rs232_RX_STS_STOP_ERROR              (0x01u << rs232_RX_STS_STOP_ERROR_SHIFT)
    #define rs232_RX_STS_OVERRUN                 (0x01u << rs232_RX_STS_OVERRUN_SHIFT)
    #define rs232_RX_STS_FIFO_NOTEMPTY           (0x01u << rs232_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define rs232_RX_STS_ADDR_MATCH              (0x01u << rs232_RX_STS_ADDR_MATCH_SHIFT)
    #define rs232_RX_STS_SOFT_BUFF_OVER          (0x01u << rs232_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define rs232_RX_HW_MASK                     (0x7Fu)
#endif /* End (rs232_RX_ENABLED) || (rs232_HD_ENABLED) */

/* Control Register definitions */
#define rs232_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define rs232_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define rs232_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define rs232_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define rs232_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define rs232_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define rs232_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define rs232_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define rs232_CTRL_HD_SEND                       (0x01u << rs232_CTRL_HD_SEND_SHIFT)
#define rs232_CTRL_HD_SEND_BREAK                 (0x01u << rs232_CTRL_HD_SEND_BREAK_SHIFT)
#define rs232_CTRL_MARK                          (0x01u << rs232_CTRL_MARK_SHIFT)
#define rs232_CTRL_PARITY_TYPE_MASK              (0x03u << rs232_CTRL_PARITY_TYPE0_SHIFT)
#define rs232_CTRL_RXADDR_MODE_MASK              (0x07u << rs232_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define rs232_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define rs232_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define rs232_SEND_BREAK                         (0x00u)
#define rs232_WAIT_FOR_COMLETE_REINIT            (0x01u)
#define rs232_REINIT                             (0x02u)
#define rs232_SEND_WAIT_REINIT                   (0x03u)

#define rs232_OVER_SAMPLE_8                      (8u)
#define rs232_OVER_SAMPLE_16                     (16u)

#define rs232_BIT_CENTER                         (rs232_OVER_SAMPLE_COUNT - 1u)

#define rs232_FIFO_LENGTH                        (4u)
#define rs232_NUMBER_OF_START_BIT                (1u)

/* 8X always for count7 implementation*/
#define rs232_TXBITCTR_BREAKBITS8X   (rs232_BREAK_BITS_TX * rs232_OVER_SAMPLE_8 - 1u)
/* 8X or 16X for DP implementation*/
#define rs232_TXBITCTR_BREAKBITS   (rs232_BREAK_BITS_TX * rs232_OVER_SAMPLE_COUNT - 1u)

#if (rs232_OVER_SAMPLE_COUNT == rs232_OVER_SAMPLE_8)
    #define rs232_HD_TXBITCTR_INIT   ((rs232_BREAK_BITS_TX + \
        rs232_NUMBER_OF_START_BIT) * rs232_OVER_SAMPLE_COUNT - 1u)
    /* This parameter is increased on the 1 in 2 out of 3 mode to sample voting in the middle */
    #define rs232_HD_RXBITCTR_INIT   ((rs232_BREAK_BITS_RX + \
    rs232_NUMBER_OF_START_BIT) * rs232_OVER_SAMPLE_COUNT - 1u + \
    (rs232_OVER_SAMPLE_COUNT / 2u) + (rs232_USE23POLLING * 2u) - 1u)
#else /* rs232_OVER_SAMPLE_COUNT == rs232_OVER_SAMPLE_16 */
    #define rs232_HD_TXBITCTR_INIT   (8u * rs232_OVER_SAMPLE_COUNT - 1u)
    #define rs232_HD_RXBITCTR_INIT   (7u * rs232_OVER_SAMPLE_COUNT - 1u  +  \
       (rs232_OVER_SAMPLE_COUNT / 2u) + (rs232_USE23POLLING * 2u) - 1u)
#endif /* End rs232_OVER_SAMPLE_COUNT */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define rs232__B_UART__AM_SW_BYTE_BYTE 1
#define rs232__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define rs232__B_UART__AM_HW_BYTE_BY_BYTE 3
#define rs232__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define rs232__B_UART__AM_NONE 0

#define rs232__B_UART__NONE_REVB 0
#define rs232__B_UART__EVEN_REVB 1
#define rs232__B_UART__ODD_REVB 2
#define rs232__B_UART__MARK_SPACE_REVB 3


/***************************************
*    Initial Parameter Constants
***************************************/

#define rs232_TXBUFFERSIZE           (4u)
#define rs232_RXBUFFERSIZE           (4u)
/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define rs232_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define rs232_NUMBER_OF_STOP_BITS    (1u)

#if (rs232_RXHW_ADDRESS_ENABLED)
    #define rs232_RXAddressMode      (0u)
    #define rs232_RXHWADDRESS1       (0u)
    #define rs232_RXHWADDRESS2       (0u)
#endif /* End EnableHWAddress */

#define rs232_INIT_RX_INTERRUPTS_MASK \
                                          (1 << rs232_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << rs232_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << rs232_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << rs232_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << rs232_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << rs232_RX_STS_BREAK_SHIFT) \
                                        | (0 << rs232_RX_STS_OVERRUN_SHIFT)

#define rs232_INIT_TX_INTERRUPTS_MASK \
                                          (0 << rs232_TX_STS_COMPLETE_SHIFT) \
                                        | (1 << rs232_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << rs232_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << rs232_TX_STS_FIFO_NOT_FULL_SHIFT)


/***************************************
*              Registers
***************************************/

#ifdef rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define rs232_CONTROL_REG \
                            (* (reg8 *) rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
    #define rs232_CONTROL_PTR \
                            (  (reg8 *) rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
#endif /* End rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(rs232_TX_ENABLED)
    #define rs232_TXDATA_REG          (* (reg8 *) rs232_BUART_sTX_TxShifter_u0__F0_REG)
    #define rs232_TXDATA_PTR          (  (reg8 *) rs232_BUART_sTX_TxShifter_u0__F0_REG)

    #define rs232_TXSTATUS_REG        (* (reg8 *) rs232_BUART_sTX_TxSts__STATUS_REG)
    #define rs232_TXSTATUS_PTR        (  (reg8 *) rs232_BUART_sTX_TxSts__STATUS_REG)
    #define rs232_TXSTATUS_MASK_REG   (* (reg8 *) rs232_BUART_sTX_TxSts__MASK_REG)
    #define rs232_TXSTATUS_MASK_PTR   (  (reg8 *) rs232_BUART_sTX_TxSts__MASK_REG)
    #define rs232_TXSTATUS_ACTL_REG   (* (reg8 *) rs232_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define rs232_TXSTATUS_ACTL_PTR   (  (reg8 *) rs232_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(rs232_TXCLKGEN_DP)
        #define rs232_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define rs232_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define rs232_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define rs232_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define rs232_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define rs232_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define rs232_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define rs232_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define rs232_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define rs232_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) rs232_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* rs232_TXCLKGEN_DP */

#endif /* End rs232_TX_ENABLED */

#if(rs232_HD_ENABLED)

    #define rs232_TXDATA_REG             (* (reg8 *) rs232_BUART_sRX_RxShifter_u0__F1_REG )
    #define rs232_TXDATA_PTR             (  (reg8 *) rs232_BUART_sRX_RxShifter_u0__F1_REG )

    #define rs232_TXSTATUS_REG           (* (reg8 *) rs232_BUART_sRX_RxSts__STATUS_REG )
    #define rs232_TXSTATUS_PTR           (  (reg8 *) rs232_BUART_sRX_RxSts__STATUS_REG )
    #define rs232_TXSTATUS_MASK_REG      (* (reg8 *) rs232_BUART_sRX_RxSts__MASK_REG )
    #define rs232_TXSTATUS_MASK_PTR      (  (reg8 *) rs232_BUART_sRX_RxSts__MASK_REG )
    #define rs232_TXSTATUS_ACTL_REG      (* (reg8 *) rs232_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define rs232_TXSTATUS_ACTL_PTR      (  (reg8 *) rs232_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End rs232_HD_ENABLED */

#if( (rs232_RX_ENABLED) || (rs232_HD_ENABLED) )
    #define rs232_RXDATA_REG             (* (reg8 *) rs232_BUART_sRX_RxShifter_u0__F0_REG )
    #define rs232_RXDATA_PTR             (  (reg8 *) rs232_BUART_sRX_RxShifter_u0__F0_REG )
    #define rs232_RXADDRESS1_REG         (* (reg8 *) rs232_BUART_sRX_RxShifter_u0__D0_REG )
    #define rs232_RXADDRESS1_PTR         (  (reg8 *) rs232_BUART_sRX_RxShifter_u0__D0_REG )
    #define rs232_RXADDRESS2_REG         (* (reg8 *) rs232_BUART_sRX_RxShifter_u0__D1_REG )
    #define rs232_RXADDRESS2_PTR         (  (reg8 *) rs232_BUART_sRX_RxShifter_u0__D1_REG )

    #define rs232_RXBITCTR_PERIOD_REG    (* (reg8 *) rs232_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define rs232_RXBITCTR_PERIOD_PTR    (  (reg8 *) rs232_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define rs232_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) rs232_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define rs232_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) rs232_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define rs232_RXBITCTR_COUNTER_REG   (* (reg8 *) rs232_BUART_sRX_RxBitCounter__COUNT_REG )
    #define rs232_RXBITCTR_COUNTER_PTR   (  (reg8 *) rs232_BUART_sRX_RxBitCounter__COUNT_REG )

    #define rs232_RXSTATUS_REG           (* (reg8 *) rs232_BUART_sRX_RxSts__STATUS_REG )
    #define rs232_RXSTATUS_PTR           (  (reg8 *) rs232_BUART_sRX_RxSts__STATUS_REG )
    #define rs232_RXSTATUS_MASK_REG      (* (reg8 *) rs232_BUART_sRX_RxSts__MASK_REG )
    #define rs232_RXSTATUS_MASK_PTR      (  (reg8 *) rs232_BUART_sRX_RxSts__MASK_REG )
    #define rs232_RXSTATUS_ACTL_REG      (* (reg8 *) rs232_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define rs232_RXSTATUS_ACTL_PTR      (  (reg8 *) rs232_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (rs232_RX_ENABLED) || (rs232_HD_ENABLED) */

#if(rs232_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define rs232_INTCLOCK_CLKEN_REG     (* (reg8 *) rs232_IntClock__PM_ACT_CFG)
    #define rs232_INTCLOCK_CLKEN_PTR     (  (reg8 *) rs232_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define rs232_INTCLOCK_CLKEN_MASK    rs232_IntClock__PM_ACT_MSK
#endif /* End rs232_INTERNAL_CLOCK_USED */


/***************************************
* Renamed global variables or defines 
* for backward compatible
***************************************/

#define rs232_initvar                    rs232_initVar

#define rs232_RX_Enabled                 rs232_RX_ENABLED
#define rs232_TX_Enabled                 rs232_TX_ENABLED
#define rs232_HD_Enabled                 rs232_HD_ENABLED
#define rs232_RX_IntInterruptEnabled     rs232_RX_INTERRUPT_ENABLED
#define rs232_TX_IntInterruptEnabled     rs232_TX_INTERRUPT_ENABLED
#define rs232_InternalClockUsed          rs232_INTERNAL_CLOCK_USED
#define rs232_RXHW_Address_Enabled       rs232_RXHW_ADDRESS_ENABLED
#define rs232_OverSampleCount            rs232_OVER_SAMPLE_COUNT
#define rs232_ParityType                 rs232_PARITY_TYPE

#if( rs232_TX_ENABLED && (rs232_TXBUFFERSIZE > rs232_FIFO_LENGTH))
    #define rs232_TXBUFFER               rs232_txBuffer
    #define rs232_TXBUFFERREAD           rs232_txBufferRead 
    #define rs232_TXBUFFERWRITE          rs232_txBufferWrite 
#endif /* End rs232_TX_ENABLED */
#if( ( rs232_RX_ENABLED || rs232_HD_ENABLED ) && \
     (rs232_RXBUFFERSIZE > rs232_FIFO_LENGTH) )
    #define rs232_RXBUFFER               rs232_rxBuffer
    #define rs232_RXBUFFERREAD           rs232_rxBufferRead 
    #define rs232_RXBUFFERWRITE          rs232_rxBufferWrite 
    #define rs232_RXBUFFERLOOPDETECT     rs232_rxBufferLoopDetect
    #define rs232_RXBUFFER_OVERFLOW      rs232_rxBufferOverflow
#endif /* End rs232_RX_ENABLED */

#ifdef rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define rs232_CONTROL                rs232_CONTROL_REG 
#endif /* End rs232_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(rs232_TX_ENABLED)
    #define rs232_TXDATA                 rs232_TXDATA_REG
    #define rs232_TXSTATUS               rs232_TXSTATUS_REG
    #define rs232_TXSTATUS_MASK          rs232_TXSTATUS_MASK_REG   
    #define rs232_TXSTATUS_ACTL          rs232_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(rs232_TXCLKGEN_DP)
        #define rs232_TXBITCLKGEN_CTR        rs232_TXBITCLKGEN_CTR_REG
        #define rs232_TXBITCLKTX_COMPLETE    rs232_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define rs232_TXBITCTR_PERIOD        rs232_TXBITCTR_PERIOD_REG
        #define rs232_TXBITCTR_CONTROL       rs232_TXBITCTR_CONTROL_REG
        #define rs232_TXBITCTR_COUNTER       rs232_TXBITCTR_COUNTER_REG
    #endif /* rs232_TXCLKGEN_DP */
#endif /* End rs232_TX_ENABLED */

#if(rs232_HD_ENABLED)
    #define rs232_TXDATA                 rs232_TXDATA_REG
    #define rs232_TXSTATUS               rs232_TXSTATUS_REG
    #define rs232_TXSTATUS_MASK          rs232_TXSTATUS_MASK_REG   
    #define rs232_TXSTATUS_ACTL          rs232_TXSTATUS_ACTL_REG
#endif /* End rs232_HD_ENABLED */

#if( (rs232_RX_ENABLED) || (rs232_HD_ENABLED) )
    #define rs232_RXDATA                 rs232_RXDATA_REG             
    #define rs232_RXADDRESS1             rs232_RXADDRESS1_REG
    #define rs232_RXADDRESS2             rs232_RXADDRESS2_REG
    #define rs232_RXBITCTR_PERIOD        rs232_RXBITCTR_PERIOD_REG
    #define rs232_RXBITCTR_CONTROL       rs232_RXBITCTR_CONTROL_REG
    #define rs232_RXBITCTR_COUNTER       rs232_RXBITCTR_COUNTER_REG
    #define rs232_RXSTATUS               rs232_RXSTATUS_REG
    #define rs232_RXSTATUS_MASK          rs232_RXSTATUS_MASK_REG
    #define rs232_RXSTATUS_ACTL          rs232_RXSTATUS_ACTL_REG
#endif /* End  (rs232_RX_ENABLED) || (rs232_HD_ENABLED) */

#if(rs232_INTERNAL_CLOCK_USED)
    #define rs232_INTCLOCK_CLKEN         rs232_INTCLOCK_CLKEN_REG
#endif /* End rs232_INTERNAL_CLOCK_USED */

#endif  /* CY_UART_rs232_H */


/* [] END OF FILE */
