/*******************************************************************************
* File Name: rs485.h
* Version 2.0
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/


#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_UART_rs485_H)
#define CY_UART_rs485_H


/***************************************
* Conditional Compilation Parameters
***************************************/

#define rs485_RX_ENABLED                     (1u)
#define rs485_TX_ENABLED                     (1u)
#define rs485_HD_ENABLED                     (0u)
#define rs485_RX_INTERRUPT_ENABLED           (0u)
#define rs485_TX_INTERRUPT_ENABLED           (0u)
#define rs485_INTERNAL_CLOCK_USED            (1u)
#define rs485_RXHW_ADDRESS_ENABLED           (0u)
#define rs485_OVER_SAMPLE_COUNT              (8u)
#define rs485_PARITY_TYPE                    (0u)
#define rs485_PARITY_TYPE_SW                 (0u)
#define rs485_BREAK_DETECT                   (0u)
#define rs485_BREAK_BITS_TX                  (13u)
#define rs485_BREAK_BITS_RX                  (13u)
#define rs485_TXCLKGEN_DP                    (1u)
#define rs485_USE23POLLING                   (1u)

/* PSoC3 ES2 or early */
#define rs485_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define rs485_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define rs485_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES2 or later */
#define rs485_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

#if(rs485_PSOC3_ES2 && (rs485_RX_INTERRUPT_ENABLED || rs485_TX_INTERRUPT_ENABLED))
    #include <intrins.h>
    #define rs485_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
#endif /* End PSOC3_ES2 */

#ifdef rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define rs485_CONTROL_REG_REMOVED            (0u)
#else
    #define rs485_CONTROL_REG_REMOVED            (1u)
#endif /* End rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct _rs485_backupStruct
{
    uint8 enableState;

    #if(rs485_CONTROL_REG_REMOVED == 0u)
        uint8 cr;            
    #endif /* End rs485_CONTROL_REG_REMOVED */    
    #if( (rs485_RX_ENABLED) || (rs485_HD_ENABLED) )
        uint8 rx_period;
        #if (rs485_PSOC3_ES2 || rs485_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 rx_mask;
            #if (rs485_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End rs485_RXHW_ADDRESS_ENABLED */
        #endif /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif  /* End (rs485_RX_ENABLED) || (rs485_HD_ENABLED)*/

    #if(rs485_TX_ENABLED)
        #if(rs485_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (rs485_PSOC3_ES2 || rs485_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
                uint8 tx_clk_compl;
            #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
        #else
            uint8 tx_period;
        #endif /*End rs485_TXCLKGEN_DP */
        #if (rs485_PSOC3_ES2 || rs485_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 tx_mask;
        #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif /*End rs485_TX_ENABLED */
} rs485_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void rs485_Start(void);
void rs485_Stop(void) ;
uint8 rs485_ReadControlRegister(void) ;
void rs485_WriteControlRegister(uint8 control) ;

void rs485_Init(void) ;
void rs485_Enable(void) ;
void rs485_SaveConfig(void);
void rs485_RestoreConfig(void);
void rs485_Sleep(void);
void rs485_Wakeup(void);

/* Only if RX is enabled */
#if( (rs485_RX_ENABLED) || (rs485_HD_ENABLED) )

    #if(rs485_RX_INTERRUPT_ENABLED)
        void  rs485_EnableRxInt(void) ;
        void  rs485_DisableRxInt(void) ;
        CY_ISR_PROTO(rs485_RXISR);
    #endif /* rs485_RX_INTERRUPT_ENABLED */

    #if (rs485_RXHW_ADDRESS_ENABLED)
        void rs485_SetRxAddressMode(uint8 addressMode) 
                                                            ;
        void rs485_SetRxAddress1(uint8 address) ;
        void rs485_SetRxAddress2(uint8 address) ;
    #endif /* End rs485_RXHW_ADDRESS_ENABLED */

    void  rs485_SetRxInterruptMode(uint8 intSrc) ;
    uint8 rs485_ReadRxData(void);
    uint8 rs485_ReadRxStatus(void) ;
    uint8 rs485_GetChar(void);
    uint16 rs485_GetByte(void);
    uint8 rs485_GetRxBufferSize(void);
    void rs485_ClearRxBuffer(void);

    /* Obsolete functions, defines for backward compatible */
    #define rs485_GetRxInterruptSource   rs485_ReadRxStatus

#endif /* End (rs485_RX_ENABLED) || (rs485_HD_ENABLED) */

/* Only if TX is enabled */
#if(rs485_TX_ENABLED || rs485_HD_ENABLED)

    #if(rs485_TX_INTERRUPT_ENABLED)
        void rs485_EnableTxInt(void) ;
        void rs485_DisableTxInt(void) ;
        CY_ISR_PROTO(rs485_TXISR);
    #endif /* rs485_TX_INTERRUPT_ENABLED */

    void rs485_SetTxInterruptMode(uint8 intSrc) ;
    void rs485_WriteTxData(uint8 txDataByte);
    uint8 rs485_ReadTxStatus(void) ;
    void rs485_PutChar(uint8 txDataByte);
    void rs485_PutString(uint8* string);
    void rs485_PutArray(uint8* string, uint8 byteCount);
    void rs485_PutCRLF(uint8 txDataByte);
    void rs485_ClearTxBuffer(void);
    void rs485_SetTxAddressMode(uint8 addressMode) ;
    void rs485_SendBreak(uint8 retMode);
    uint8 rs485_GetTxBufferSize(void);
    /* Obsolete functions, defines for backward compatible */
    #define rs485_PutStringConst         rs485_PutString
    #define rs485_PutArrayConst          rs485_PutArray
    #define rs485_GetTxInterruptSource   rs485_ReadTxStatus
    
#endif /* End rs485_TX_ENABLED || rs485_HD_ENABLED */

#if(rs485_HD_ENABLED)
    void rs485_LoadRxConfig(void) ;
    void rs485_LoadTxConfig(void) ;
#endif /* End rs485_HD_ENABLED */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define rs485_SET_SPACE                              (0x00u)
#define rs485_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (rs485_TX_ENABLED) || (rs485_HD_ENABLED) )
    #if(rs485_TX_INTERRUPT_ENABLED)
        #define rs485_TX_VECT_NUM                rs485_TXInternalInterrupt__INTC_NUMBER
        #define rs485_TX_PRIOR_NUM               rs485_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* rs485_TX_INTERRUPT_ENABLED */
    #if(rs485_TX_ENABLED) 
        #define rs485_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define rs485_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define rs485_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define rs485_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* rs485_TX_ENABLED */
    #if(rs485_HD_ENABLED) 
        #define rs485_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define rs485_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define rs485_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define rs485_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* rs485_HD_ENABLED */
    #define rs485_TX_STS_COMPLETE                (0x01u << rs485_TX_STS_COMPLETE_SHIFT)
    #define rs485_TX_STS_FIFO_EMPTY              (0x01u << rs485_TX_STS_FIFO_EMPTY_SHIFT)
    #define rs485_TX_STS_FIFO_FULL               (0x01u << rs485_TX_STS_FIFO_FULL_SHIFT)
    #define rs485_TX_STS_FIFO_NOT_FULL           (0x01u << rs485_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (rs485_TX_ENABLED) || (rs485_HD_ENABLED)*/

#if( (rs485_RX_ENABLED) || (rs485_HD_ENABLED) )
    #if(rs485_RX_INTERRUPT_ENABLED)
        #define rs485_RX_VECT_NUM                rs485_RXInternalInterrupt__INTC_NUMBER
        #define rs485_RX_PRIOR_NUM               rs485_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* rs485_RX_INTERRUPT_ENABLED */
    #define rs485_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define rs485_RX_STS_BREAK_SHIFT             (0x01u)
    #define rs485_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define rs485_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define rs485_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define rs485_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define rs485_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define rs485_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define rs485_RX_STS_MRKSPC                  (0x01u << rs485_RX_STS_MRKSPC_SHIFT)
    #define rs485_RX_STS_BREAK                   (0x01u << rs485_RX_STS_BREAK_SHIFT)
    #define rs485_RX_STS_PAR_ERROR               (0x01u << rs485_RX_STS_PAR_ERROR_SHIFT)
    #define rs485_RX_STS_STOP_ERROR              (0x01u << rs485_RX_STS_STOP_ERROR_SHIFT)
    #define rs485_RX_STS_OVERRUN                 (0x01u << rs485_RX_STS_OVERRUN_SHIFT)
    #define rs485_RX_STS_FIFO_NOTEMPTY           (0x01u << rs485_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define rs485_RX_STS_ADDR_MATCH              (0x01u << rs485_RX_STS_ADDR_MATCH_SHIFT)
    #define rs485_RX_STS_SOFT_BUFF_OVER          (0x01u << rs485_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define rs485_RX_HW_MASK                     (0x7Fu)
#endif /* End (rs485_RX_ENABLED) || (rs485_HD_ENABLED) */

/* Control Register definitions */
#define rs485_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define rs485_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define rs485_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define rs485_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define rs485_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define rs485_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define rs485_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define rs485_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define rs485_CTRL_HD_SEND                       (0x01u << rs485_CTRL_HD_SEND_SHIFT)
#define rs485_CTRL_HD_SEND_BREAK                 (0x01u << rs485_CTRL_HD_SEND_BREAK_SHIFT)
#define rs485_CTRL_MARK                          (0x01u << rs485_CTRL_MARK_SHIFT)
#define rs485_CTRL_PARITY_TYPE_MASK              (0x03u << rs485_CTRL_PARITY_TYPE0_SHIFT)
#define rs485_CTRL_RXADDR_MODE_MASK              (0x07u << rs485_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define rs485_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define rs485_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define rs485_SEND_BREAK                         (0x00u)
#define rs485_WAIT_FOR_COMLETE_REINIT            (0x01u)
#define rs485_REINIT                             (0x02u)
#define rs485_SEND_WAIT_REINIT                   (0x03u)

#define rs485_OVER_SAMPLE_8                      (8u)
#define rs485_OVER_SAMPLE_16                     (16u)

#define rs485_BIT_CENTER                         (rs485_OVER_SAMPLE_COUNT - 1u)

#define rs485_FIFO_LENGTH                        (4u)
#define rs485_NUMBER_OF_START_BIT                (1u)

/* 8X always for count7 implementation*/
#define rs485_TXBITCTR_BREAKBITS8X   (rs485_BREAK_BITS_TX * rs485_OVER_SAMPLE_8 - 1u)
/* 8X or 16X for DP implementation*/
#define rs485_TXBITCTR_BREAKBITS   (rs485_BREAK_BITS_TX * rs485_OVER_SAMPLE_COUNT - 1u)

#if (rs485_OVER_SAMPLE_COUNT == rs485_OVER_SAMPLE_8)
    #define rs485_HD_TXBITCTR_INIT   ((rs485_BREAK_BITS_TX + \
        rs485_NUMBER_OF_START_BIT) * rs485_OVER_SAMPLE_COUNT - 1u)
    /* This parameter is increased on the 1 in 2 out of 3 mode to sample voting in the middle */
    #define rs485_HD_RXBITCTR_INIT   ((rs485_BREAK_BITS_RX + \
    rs485_NUMBER_OF_START_BIT) * rs485_OVER_SAMPLE_COUNT - 1u + \
    (rs485_OVER_SAMPLE_COUNT / 2u) + (rs485_USE23POLLING * 2u) - 1u)
#else /* rs485_OVER_SAMPLE_COUNT == rs485_OVER_SAMPLE_16 */
    #define rs485_HD_TXBITCTR_INIT   (8u * rs485_OVER_SAMPLE_COUNT - 1u)
    #define rs485_HD_RXBITCTR_INIT   (7u * rs485_OVER_SAMPLE_COUNT - 1u  +  \
       (rs485_OVER_SAMPLE_COUNT / 2u) + (rs485_USE23POLLING * 2u) - 1u)
#endif /* End rs485_OVER_SAMPLE_COUNT */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define rs485__B_UART__AM_SW_BYTE_BYTE 1
#define rs485__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define rs485__B_UART__AM_HW_BYTE_BY_BYTE 3
#define rs485__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define rs485__B_UART__AM_NONE 0

#define rs485__B_UART__NONE_REVB 0
#define rs485__B_UART__EVEN_REVB 1
#define rs485__B_UART__ODD_REVB 2
#define rs485__B_UART__MARK_SPACE_REVB 3


/***************************************
*    Initial Parameter Constants
***************************************/

#define rs485_TXBUFFERSIZE           (4u)
#define rs485_RXBUFFERSIZE           (4u)
/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define rs485_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define rs485_NUMBER_OF_STOP_BITS    (1u)

#if (rs485_RXHW_ADDRESS_ENABLED)
    #define rs485_RXAddressMode      (0u)
    #define rs485_RXHWADDRESS1       (0u)
    #define rs485_RXHWADDRESS2       (0u)
#endif /* End EnableHWAddress */

#define rs485_INIT_RX_INTERRUPTS_MASK \
                                          (1 << rs485_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << rs485_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << rs485_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << rs485_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << rs485_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << rs485_RX_STS_BREAK_SHIFT) \
                                        | (0 << rs485_RX_STS_OVERRUN_SHIFT)

#define rs485_INIT_TX_INTERRUPTS_MASK \
                                          (0 << rs485_TX_STS_COMPLETE_SHIFT) \
                                        | (1 << rs485_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << rs485_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << rs485_TX_STS_FIFO_NOT_FULL_SHIFT)


/***************************************
*              Registers
***************************************/

#ifdef rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define rs485_CONTROL_REG \
                            (* (reg8 *) rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
    #define rs485_CONTROL_PTR \
                            (  (reg8 *) rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
#endif /* End rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(rs485_TX_ENABLED)
    #define rs485_TXDATA_REG          (* (reg8 *) rs485_BUART_sTX_TxShifter_u0__F0_REG)
    #define rs485_TXDATA_PTR          (  (reg8 *) rs485_BUART_sTX_TxShifter_u0__F0_REG)

    #define rs485_TXSTATUS_REG        (* (reg8 *) rs485_BUART_sTX_TxSts__STATUS_REG)
    #define rs485_TXSTATUS_PTR        (  (reg8 *) rs485_BUART_sTX_TxSts__STATUS_REG)
    #define rs485_TXSTATUS_MASK_REG   (* (reg8 *) rs485_BUART_sTX_TxSts__MASK_REG)
    #define rs485_TXSTATUS_MASK_PTR   (  (reg8 *) rs485_BUART_sTX_TxSts__MASK_REG)
    #define rs485_TXSTATUS_ACTL_REG   (* (reg8 *) rs485_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define rs485_TXSTATUS_ACTL_PTR   (  (reg8 *) rs485_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(rs485_TXCLKGEN_DP)
        #define rs485_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define rs485_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define rs485_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define rs485_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define rs485_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define rs485_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define rs485_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define rs485_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define rs485_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define rs485_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) rs485_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* rs485_TXCLKGEN_DP */

#endif /* End rs485_TX_ENABLED */

#if(rs485_HD_ENABLED)

    #define rs485_TXDATA_REG             (* (reg8 *) rs485_BUART_sRX_RxShifter_u0__F1_REG )
    #define rs485_TXDATA_PTR             (  (reg8 *) rs485_BUART_sRX_RxShifter_u0__F1_REG )

    #define rs485_TXSTATUS_REG           (* (reg8 *) rs485_BUART_sRX_RxSts__STATUS_REG )
    #define rs485_TXSTATUS_PTR           (  (reg8 *) rs485_BUART_sRX_RxSts__STATUS_REG )
    #define rs485_TXSTATUS_MASK_REG      (* (reg8 *) rs485_BUART_sRX_RxSts__MASK_REG )
    #define rs485_TXSTATUS_MASK_PTR      (  (reg8 *) rs485_BUART_sRX_RxSts__MASK_REG )
    #define rs485_TXSTATUS_ACTL_REG      (* (reg8 *) rs485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define rs485_TXSTATUS_ACTL_PTR      (  (reg8 *) rs485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End rs485_HD_ENABLED */

#if( (rs485_RX_ENABLED) || (rs485_HD_ENABLED) )
    #define rs485_RXDATA_REG             (* (reg8 *) rs485_BUART_sRX_RxShifter_u0__F0_REG )
    #define rs485_RXDATA_PTR             (  (reg8 *) rs485_BUART_sRX_RxShifter_u0__F0_REG )
    #define rs485_RXADDRESS1_REG         (* (reg8 *) rs485_BUART_sRX_RxShifter_u0__D0_REG )
    #define rs485_RXADDRESS1_PTR         (  (reg8 *) rs485_BUART_sRX_RxShifter_u0__D0_REG )
    #define rs485_RXADDRESS2_REG         (* (reg8 *) rs485_BUART_sRX_RxShifter_u0__D1_REG )
    #define rs485_RXADDRESS2_PTR         (  (reg8 *) rs485_BUART_sRX_RxShifter_u0__D1_REG )

    #define rs485_RXBITCTR_PERIOD_REG    (* (reg8 *) rs485_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define rs485_RXBITCTR_PERIOD_PTR    (  (reg8 *) rs485_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define rs485_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) rs485_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define rs485_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) rs485_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define rs485_RXBITCTR_COUNTER_REG   (* (reg8 *) rs485_BUART_sRX_RxBitCounter__COUNT_REG )
    #define rs485_RXBITCTR_COUNTER_PTR   (  (reg8 *) rs485_BUART_sRX_RxBitCounter__COUNT_REG )

    #define rs485_RXSTATUS_REG           (* (reg8 *) rs485_BUART_sRX_RxSts__STATUS_REG )
    #define rs485_RXSTATUS_PTR           (  (reg8 *) rs485_BUART_sRX_RxSts__STATUS_REG )
    #define rs485_RXSTATUS_MASK_REG      (* (reg8 *) rs485_BUART_sRX_RxSts__MASK_REG )
    #define rs485_RXSTATUS_MASK_PTR      (  (reg8 *) rs485_BUART_sRX_RxSts__MASK_REG )
    #define rs485_RXSTATUS_ACTL_REG      (* (reg8 *) rs485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define rs485_RXSTATUS_ACTL_PTR      (  (reg8 *) rs485_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (rs485_RX_ENABLED) || (rs485_HD_ENABLED) */

#if(rs485_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define rs485_INTCLOCK_CLKEN_REG     (* (reg8 *) rs485_IntClock__PM_ACT_CFG)
    #define rs485_INTCLOCK_CLKEN_PTR     (  (reg8 *) rs485_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define rs485_INTCLOCK_CLKEN_MASK    rs485_IntClock__PM_ACT_MSK
#endif /* End rs485_INTERNAL_CLOCK_USED */


/***************************************
* Renamed global variables or defines 
* for backward compatible
***************************************/

#define rs485_initvar                    rs485_initVar

#define rs485_RX_Enabled                 rs485_RX_ENABLED
#define rs485_TX_Enabled                 rs485_TX_ENABLED
#define rs485_HD_Enabled                 rs485_HD_ENABLED
#define rs485_RX_IntInterruptEnabled     rs485_RX_INTERRUPT_ENABLED
#define rs485_TX_IntInterruptEnabled     rs485_TX_INTERRUPT_ENABLED
#define rs485_InternalClockUsed          rs485_INTERNAL_CLOCK_USED
#define rs485_RXHW_Address_Enabled       rs485_RXHW_ADDRESS_ENABLED
#define rs485_OverSampleCount            rs485_OVER_SAMPLE_COUNT
#define rs485_ParityType                 rs485_PARITY_TYPE

#if( rs485_TX_ENABLED && (rs485_TXBUFFERSIZE > rs485_FIFO_LENGTH))
    #define rs485_TXBUFFER               rs485_txBuffer
    #define rs485_TXBUFFERREAD           rs485_txBufferRead 
    #define rs485_TXBUFFERWRITE          rs485_txBufferWrite 
#endif /* End rs485_TX_ENABLED */
#if( ( rs485_RX_ENABLED || rs485_HD_ENABLED ) && \
     (rs485_RXBUFFERSIZE > rs485_FIFO_LENGTH) )
    #define rs485_RXBUFFER               rs485_rxBuffer
    #define rs485_RXBUFFERREAD           rs485_rxBufferRead 
    #define rs485_RXBUFFERWRITE          rs485_rxBufferWrite 
    #define rs485_RXBUFFERLOOPDETECT     rs485_rxBufferLoopDetect
    #define rs485_RXBUFFER_OVERFLOW      rs485_rxBufferOverflow
#endif /* End rs485_RX_ENABLED */

#ifdef rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define rs485_CONTROL                rs485_CONTROL_REG 
#endif /* End rs485_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(rs485_TX_ENABLED)
    #define rs485_TXDATA                 rs485_TXDATA_REG
    #define rs485_TXSTATUS               rs485_TXSTATUS_REG
    #define rs485_TXSTATUS_MASK          rs485_TXSTATUS_MASK_REG   
    #define rs485_TXSTATUS_ACTL          rs485_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(rs485_TXCLKGEN_DP)
        #define rs485_TXBITCLKGEN_CTR        rs485_TXBITCLKGEN_CTR_REG
        #define rs485_TXBITCLKTX_COMPLETE    rs485_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define rs485_TXBITCTR_PERIOD        rs485_TXBITCTR_PERIOD_REG
        #define rs485_TXBITCTR_CONTROL       rs485_TXBITCTR_CONTROL_REG
        #define rs485_TXBITCTR_COUNTER       rs485_TXBITCTR_COUNTER_REG
    #endif /* rs485_TXCLKGEN_DP */
#endif /* End rs485_TX_ENABLED */

#if(rs485_HD_ENABLED)
    #define rs485_TXDATA                 rs485_TXDATA_REG
    #define rs485_TXSTATUS               rs485_TXSTATUS_REG
    #define rs485_TXSTATUS_MASK          rs485_TXSTATUS_MASK_REG   
    #define rs485_TXSTATUS_ACTL          rs485_TXSTATUS_ACTL_REG
#endif /* End rs485_HD_ENABLED */

#if( (rs485_RX_ENABLED) || (rs485_HD_ENABLED) )
    #define rs485_RXDATA                 rs485_RXDATA_REG             
    #define rs485_RXADDRESS1             rs485_RXADDRESS1_REG
    #define rs485_RXADDRESS2             rs485_RXADDRESS2_REG
    #define rs485_RXBITCTR_PERIOD        rs485_RXBITCTR_PERIOD_REG
    #define rs485_RXBITCTR_CONTROL       rs485_RXBITCTR_CONTROL_REG
    #define rs485_RXBITCTR_COUNTER       rs485_RXBITCTR_COUNTER_REG
    #define rs485_RXSTATUS               rs485_RXSTATUS_REG
    #define rs485_RXSTATUS_MASK          rs485_RXSTATUS_MASK_REG
    #define rs485_RXSTATUS_ACTL          rs485_RXSTATUS_ACTL_REG
#endif /* End  (rs485_RX_ENABLED) || (rs485_HD_ENABLED) */

#if(rs485_INTERNAL_CLOCK_USED)
    #define rs485_INTCLOCK_CLKEN         rs485_INTCLOCK_CLKEN_REG
#endif /* End rs485_INTERNAL_CLOCK_USED */

#endif  /* CY_UART_rs485_H */


/* [] END OF FILE */
