/*******************************************************************************
* File Name: sdcard_spi.h
* Version 2.10
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the SPI Master Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SPIM_sdcard_spi_H)
#define CY_SPIM_sdcard_spi_H

#include "cyfitter.h"

/* PSoC3 ES2 or earlier*/
#define sdcard_spi_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                     			      (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
                     
/* PSoC5 ES1 or earlier */
#define sdcard_spi_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                     		    	  (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
	
#ifdef sdcard_spi_TxInternalInterrupt__ES2_PATCH
	#if(sdcard_spi_PSOC3_ES2 && sdcard_spi_TxInternalInterrupt__ES2_PATCH)
		#include <intrins.h>
        #define sdcard_spi_TX_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
	#endif /* End PSOC3_ES2 */
#endif /* sdcard_spi_TxInternalInterrupt__ES2_PATCH */

#ifdef sdcard_spi_RxInternalInterrupt__ES2_PATCH  
	#if(sdcard_spi_PSOC3_ES2 && sdcard_spi_RxInternalInterrupt__ES2_PATCH)
		#include <intrins.h>
        #define sdcard_spi_RX_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
	#endif /* End PSOC3_ES2 */
#endif /* sdcard_spi_RxInternalInterrupt__ES2_PATCH */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define sdcard_spi_DataWidth                  (8u)
#define sdcard_spi_InternalClockUsed          (1u)
#define sdcard_spi_InternalTxInterruptEnabled (0u)
#define sdcard_spi_InternalRxInterruptEnabled (0u)
#define sdcard_spi_ModeUseZero                (1u)
#define sdcard_spi_BidirectionalMode          (0u)
#define sdcard_spi_Mode                       (1u)

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects 
*/
#define sdcard_spi_DATAWIDHT                (sdcard_spi_DataWidth)
#define sdcard_spi_InternalInterruptEnabled (0u)


/***************************************
*        Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct _sdcard_spi_backupStruct
{
    uint8 enableState;
    uint8 cntrPeriod;
    
    #if(sdcard_spi_PSOC3_ES2 || sdcard_spi_PSOC5_ES1) /* PSoC3 ES2 or earlier, PSoC5 ES1 */
    
        uint8 saveSrTxIntMask;
        uint8 saveSrRxIntMask;
        
    #endif /* End sdcard_spi_PSOC3_ES2 || sdcard_spi_PSOC5_ES1 */

} sdcard_spi_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  sdcard_spi_Init(void);
void  sdcard_spi_Enable(void) ;
void  sdcard_spi_Start(void);
void  sdcard_spi_Stop(void) ;
void  sdcard_spi_EnableTxInt(void) ;
void  sdcard_spi_EnableRxInt(void) ;
void  sdcard_spi_DisableTxInt(void) ;
void  sdcard_spi_DisableRxInt(void) ;
void  sdcard_spi_SetTxInterruptMode(uint8 intSource) ;
void  sdcard_spi_SetRxInterruptMode(uint8 intSource) ;
uint8 sdcard_spi_ReadTxStatus(void);
uint8 sdcard_spi_ReadRxStatus(void);
void  sdcard_spi_WriteTxData(uint8 txData);
uint8 sdcard_spi_ReadRxData(void);
uint8 sdcard_spi_GetRxBufferSize(void) ;
uint8 sdcard_spi_GetTxBufferSize(void) ;
void  sdcard_spi_ClearRxBuffer(void);
void  sdcard_spi_ClearTxBuffer(void);
void  sdcard_spi_ClearFIFO(void) ;
void  sdcard_spi_PutArray(uint8 *buffer, uint8 byteCount);
void  sdcard_spi_Sleep(void);
void  sdcard_spi_Wakeup(void);
void  sdcard_spi_SaveConfig(void);
void  sdcard_spi_RestoreConfig(void) ;

#if (sdcard_spi_BidirectionalMode)

    void  sdcard_spi_TxEnable(void) ;
    void  sdcard_spi_TxDisable(void) ;

#endif /* sdcard_spi_BidirectionalMode == 1u*/

CY_ISR_PROTO(sdcard_spi_TX_ISR);
CY_ISR_PROTO(sdcard_spi_RX_ISR);

/* Macros for getting software status of SPIM Statusi Register */
#define sdcard_spi_GET_STATUS_TX(swTxSts) (uint8)(sdcard_spi_TX_STATUS_REG | \
                                                       (swTxSts & sdcard_spi_TX_STS_CLR_ON_RD_BYTES_MASK))
#define sdcard_spi_GET_STATUS_RX(swRxSts) (uint8)(sdcard_spi_RX_STATUS_REG | \
                                                       (swRxSts & sdcard_spi_RX_STS_CLR_ON_RD_BYTES_MASK))                                                  

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects 
*/
#define sdcard_spi_WriteByte (sdcard_spi_WriteTxData)
#define sdcard_spi_ReadByte  (sdcard_spi_ReadRxData)
void  sdcard_spi_SetInterruptMode(uint8 intSource) ;
uint8 sdcard_spi_ReadStatus(void);
void  sdcard_spi_EnableInt(void) ;
void  sdcard_spi_DisableInt(void) ;


/***************************************
*           API Constants
***************************************/

#define sdcard_spi_TX_ISR_NUMBER     (sdcard_spi_TxInternalInterrupt__INTC_NUMBER)
#define sdcard_spi_RX_ISR_NUMBER     (sdcard_spi_RxInternalInterrupt__INTC_NUMBER)
#define sdcard_spi_TX_ISR_PRIORITY   (sdcard_spi_TxInternalInterrupt__INTC_PRIOR_NUM)
#define sdcard_spi_RX_ISR_PRIORITY   (sdcard_spi_RxInternalInterrupt__INTC_PRIOR_NUM)


/***************************************
*    Initial Parameter Constants
***************************************/
                                               
#define sdcard_spi_INT_ON_SPI_DONE    (0u << sdcard_spi_STS_SPI_DONE_SHIFT)
#define sdcard_spi_INT_ON_TX_EMPTY    (0u << sdcard_spi_STS_TX_FIFO_EMPTY_SHIFT)
#define sdcard_spi_INT_ON_TX_NOT_FULL (0u << sdcard_spi_STS_TX_FIFO_NOT_FULL_SHIFT)
#define sdcard_spi_INT_ON_BYTE_COMP   (0u << sdcard_spi_STS_BYTE_COMPLETE_SHIFT)
#define sdcard_spi_INT_ON_SPI_IDLE    (0u << sdcard_spi_STS_SPI_IDLE_SHIFT)

#define sdcard_spi_TX_INIT_INTERRUPTS_MASK  (sdcard_spi_INT_ON_SPI_DONE | \
                                            sdcard_spi_INT_ON_TX_EMPTY | sdcard_spi_INT_ON_TX_NOT_FULL | \
                                            sdcard_spi_INT_ON_BYTE_COMP | sdcard_spi_INT_ON_SPI_IDLE)
            
#define sdcard_spi_INT_ON_RX_FULL      (0u << sdcard_spi_STS_RX_FIFO_FULL_SHIFT)
#define sdcard_spi_INT_ON_RX_NOT_EMPTY (0u << sdcard_spi_STS_RX_FIFO_NOT_EMPTY_SHIFT)
#define sdcard_spi_INT_ON_RX_OVER      (0u << sdcard_spi_STS_RX_FIFO_OVERRUN_SHIFT)

#define sdcard_spi_RX_INIT_INTERRUPTS_MASK  (sdcard_spi_INT_ON_RX_FULL | \
                                            sdcard_spi_INT_ON_RX_NOT_EMPTY | sdcard_spi_INT_ON_RX_OVER)
                                               
#define sdcard_spi_BITCTR_INIT           ( (sdcard_spi_DataWidth << 1u) - 1u)

#define sdcard_spi_TXBUFFERSIZE          (4u)
#define sdcard_spi_RXBUFFERSIZE          (4u)

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects 
*/
#define sdcard_spi_INIT_INTERRUPTS_MASK  (sdcard_spi_INT_ON_SPI_DONE | sdcard_spi_INT_ON_TX_EMPTY | \
                                            sdcard_spi_INT_ON_TX_NOT_FULL | sdcard_spi_INT_ON_RX_FULL | \
                                            sdcard_spi_INT_ON_RX_NOT_EMPTY | sdcard_spi_INT_ON_RX_OVER | \
                                            sdcard_spi_INT_ON_BYTE_COMP)


/***************************************
*             Registers
***************************************/

#define sdcard_spi_TXDATA_REG         (* (reg8 *) \
        sdcard_spi_BSPIM_sR8_Dp_u0__F0_REG)
#define sdcard_spi_TXDATA_PTR         (  (reg8 *) \
        sdcard_spi_BSPIM_sR8_Dp_u0__F0_REG)
#define sdcard_spi_RXDATA_REG         (* (reg8 *) \
        sdcard_spi_BSPIM_sR8_Dp_u0__F1_REG)
#define sdcard_spi_RXDATA_PTR         (  (reg8 *) \
        sdcard_spi_BSPIM_sR8_Dp_u0__F1_REG)

#define sdcard_spi_AUX_CONTROL_DP0_REG (* (reg8 *) \
        sdcard_spi_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)
#define sdcard_spi_AUX_CONTROL_DP0_PTR (  (reg8 *) \
        sdcard_spi_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)        

#if (sdcard_spi_DataWidth > 8u)

    #define sdcard_spi_AUX_CONTROL_DP1_REG  (* (reg8 *) \
            sdcard_spi_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
    #define sdcard_spi_AUX_CONTROL_DP1_PTR  (  (reg8 *) \
            sdcard_spi_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
#endif /* sdcard_spi_DataWidth > 8u */

#define sdcard_spi_COUNTER_PERIOD_REG  (* (reg8 *)  sdcard_spi_BSPIM_BitCounter__PERIOD_REG)
#define sdcard_spi_COUNTER_PERIOD_PTR  (  (reg8 *)  sdcard_spi_BSPIM_BitCounter__PERIOD_REG)
#define sdcard_spi_COUNTER_CONTROL_REG (* (reg8 *)  sdcard_spi_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)
#define sdcard_spi_COUNTER_CONTROL_PTR (  (reg8 *)  sdcard_spi_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)

#define sdcard_spi_TX_STATUS_REG       (* (reg8 *)  sdcard_spi_BSPIM_TxStsReg__STATUS_REG)
#define sdcard_spi_TX_STATUS_PTR       (  (reg8 *)  sdcard_spi_BSPIM_TxStsReg__STATUS_REG)
#define sdcard_spi_RX_STATUS_REG       (* (reg8 *)  sdcard_spi_BSPIM_RxStsReg__STATUS_REG)
#define sdcard_spi_RX_STATUS_PTR       (  (reg8 *)  sdcard_spi_BSPIM_RxStsReg__STATUS_REG)

#define sdcard_spi_CONTROL_REG         (* (reg8 *)  \
        sdcard_spi_BSPIM_BidirMode_AsyncCtl_CtrlReg__CONTROL_REG)
#define sdcard_spi_CONTROL_PTR         (  (reg8 *)  \
        sdcard_spi_BSPIM_BidirMode_AsyncCtl_CtrlReg__CONTROL_REG)
        
#define sdcard_spi_TX_STATUS_MASK_REG  (* (reg8 *)  sdcard_spi_BSPIM_TxStsReg__MASK_REG)
#define sdcard_spi_TX_STATUS_MASK_PTR  (  (reg8 *)  sdcard_spi_BSPIM_TxStsReg__MASK_REG)
#define sdcard_spi_RX_STATUS_MASK_REG  (* (reg8 *)  sdcard_spi_BSPIM_RxStsReg__MASK_REG)
#define sdcard_spi_RX_STATUS_MASK_PTR  (  (reg8 *)  sdcard_spi_BSPIM_RxStsReg__MASK_REG)

#define sdcard_spi_TX_STATUS_ACTL_REG  (* (reg8 *)  sdcard_spi_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define sdcard_spi_TX_STATUS_ACTL_PTR  (  (reg8 *)  sdcard_spi_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define sdcard_spi_RX_STATUS_ACTL_REG  (* (reg8 *)  sdcard_spi_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)
#define sdcard_spi_RX_STATUS_ACTL_PTR  (  (reg8 *)  sdcard_spi_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)

/* Obsolete register names. Not to be used in new designs */
#define sdcard_spi_TXDATA                 (sdcard_spi_TXDATA_REG)
#define sdcard_spi_RXDATA                 (sdcard_spi_RXDATA_REG)
#define sdcard_spi_AUX_CONTROLDP0         (sdcard_spi_AUX_CONTROL_DP0_REG)
#define sdcard_spi_TXBUFFERREAD           (sdcard_spi_txBufferRead)
#define sdcard_spi_TXBUFFERWRITE          (sdcard_spi_txBufferWrite)
#define sdcard_spi_RXBUFFERREAD           (sdcard_spi_rxBufferRead)
#define sdcard_spi_RXBUFFERWRITE          (sdcard_spi_rxBufferWrite)

#if(sdcard_spi_DataWidth > 8u)    
    #define sdcard_spi_AUX_CONTROLDP1     (sdcard_spi_AUX_CONTROL_DP1_REG)    
#endif /* sdcard_spi_DataWidth > 8u */
    
#define sdcard_spi_COUNTER_PERIOD         (sdcard_spi_COUNTER_PERIOD_REG)
#define sdcard_spi_COUNTER_CONTROL        (sdcard_spi_COUNTER_CONTROL_REG)
#define sdcard_spi_STATUS                 (sdcard_spi_TX_STATUS_REG)
#define sdcard_spi_CONTROL                (sdcard_spi_CONTROL_REG)
#define sdcard_spi_STATUS_MASK            (sdcard_spi_TX_STATUS_MASK_REG)
#define sdcard_spi_STATUS_ACTL            (sdcard_spi_TX_STATUS_ACTL_REG)


/***************************************
*       Register Constants 
***************************************/

/* Status Register Definitions */
#define sdcard_spi_STS_SPI_DONE_SHIFT          (0x00u)
#define sdcard_spi_STS_TX_FIFO_EMPTY_SHIFT     (0x01u)
#define sdcard_spi_STS_TX_FIFO_NOT_FULL_SHIFT  (0x02u)
#define sdcard_spi_STS_BYTE_COMPLETE_SHIFT     (0x03u)
#define sdcard_spi_STS_SPI_IDLE_SHIFT          (0x04u)
#define sdcard_spi_STS_RX_FIFO_FULL_SHIFT      (0x04u)
#define sdcard_spi_STS_RX_FIFO_NOT_EMPTY_SHIFT (0x05u)
#define sdcard_spi_STS_RX_FIFO_OVERRUN_SHIFT   (0x06u)

#define sdcard_spi_STS_SPI_DONE                (0x01u << sdcard_spi_STS_SPI_DONE_SHIFT)        
#define sdcard_spi_STS_TX_FIFO_EMPTY           (0x01u << sdcard_spi_STS_TX_FIFO_EMPTY_SHIFT)    
#define sdcard_spi_STS_TX_FIFO_NOT_FULL        (0x01u << sdcard_spi_STS_TX_FIFO_NOT_FULL_SHIFT)    
#define sdcard_spi_STS_SPI_IDLE                (0x01u << sdcard_spi_STS_SPI_IDLE_SHIFT)
#define sdcard_spi_STS_RX_FIFO_FULL            (0x01u << sdcard_spi_STS_RX_FIFO_FULL_SHIFT)    
#define sdcard_spi_STS_RX_FIFO_NOT_EMPTY       (0x01u << sdcard_spi_STS_RX_FIFO_NOT_EMPTY_SHIFT)    
#define sdcard_spi_STS_RX_FIFO_OVERRUN         (0x01u << sdcard_spi_STS_RX_FIFO_OVERRUN_SHIFT)  
#define sdcard_spi_STS_BYTE_COMPLETE           (0x01u << sdcard_spi_STS_BYTE_COMPLETE_SHIFT)

#define sdcard_spi_TX_STS_CLR_ON_RD_BYTES_MASK (0x09u)
#define sdcard_spi_RX_STS_CLR_ON_RD_BYTES_MASK (0x40u)

/* StatusI Register Interrupt Enable Control Bits */
/* As defined by the Register map for the AUX Control Register */
#define sdcard_spi_INT_ENABLE                  (0x10u)
#define sdcard_spi_FIFO_CLR                    (0x03u)
                                                                 
/* Bit Counter (7-bit) Control Register Bit Definitions */
/* As defined by the Register map for the AUX Control Register */
#define sdcard_spi_CNTR_ENABLE                 (0x20u)   
                                                                  
/* Bi-Directional mode control bit */
#define sdcard_spi_CTRL_TX_SIGNAL_EN           (0x01u)

/* Datapath Auxillary Control Register definitions */
#define sdcard_spi_AUX_CTRL_FIFO0_CLR          (0x01u)
#define sdcard_spi_AUX_CTRL_FIFO1_CLR          (0x02u)
#define sdcard_spi_AUX_CTRL_FIFO0_LVL          (0x04u)
#define sdcard_spi_AUX_CTRL_FIFO1_LVL          (0x08u)
#define sdcard_spi_STATUS_ACTL_INT_EN_MASK     (0x10u)

#endif  /* CY_SPIM_sdcard_spi_H */


/* [] END OF FILE */
