/*******************************************************************************
* File Name: sdcard_spi_IntClock.h
* Version 1.50
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_sdcard_spi_IntClock_H)
#define CY_CLOCK_sdcard_spi_IntClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void sdcard_spi_IntClock_Start(void) ;
void sdcard_spi_IntClock_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void sdcard_spi_IntClock_StopBlock(void) ;
#endif

void sdcard_spi_IntClock_StandbyPower(uint8 state) ;
void sdcard_spi_IntClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 sdcard_spi_IntClock_GetDividerRegister(void) ;
void sdcard_spi_IntClock_SetModeRegister(uint8 modeBitMask) ;
void sdcard_spi_IntClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 sdcard_spi_IntClock_GetModeRegister(void) ;
void sdcard_spi_IntClock_SetSourceRegister(uint8 clkSource) ;
uint8 sdcard_spi_IntClock_GetSourceRegister(void) ;
#if defined(sdcard_spi_IntClock__CFG3)
void sdcard_spi_IntClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 sdcard_spi_IntClock_GetPhaseRegister(void) ;
#endif

#define sdcard_spi_IntClock_Enable()                       sdcard_spi_IntClock_Start()
#define sdcard_spi_IntClock_Disable()                      sdcard_spi_IntClock_Stop()
#define sdcard_spi_IntClock_SetDivider(clkDivider)         sdcard_spi_IntClock_SetDividerRegister(clkDivider, 1)
#define sdcard_spi_IntClock_SetDividerValue(clkDivider)    sdcard_spi_IntClock_SetDividerRegister((clkDivider) - 1, 1)
#define sdcard_spi_IntClock_SetMode(clkMode)               sdcard_spi_IntClock_SetModeRegister(clkMode)
#define sdcard_spi_IntClock_SetSource(clkSource)           sdcard_spi_IntClock_SetSourceRegister(clkSource)
#if defined(sdcard_spi_IntClock__CFG3)
#define sdcard_spi_IntClock_SetPhase(clkPhase)             sdcard_spi_IntClock_SetPhaseRegister(clkPhase)
#define sdcard_spi_IntClock_SetPhaseValue(clkPhase)        sdcard_spi_IntClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define sdcard_spi_IntClock_CLKEN              (* (reg8 *) sdcard_spi_IntClock__PM_ACT_CFG)
#define sdcard_spi_IntClock_CLKEN_PTR          ((reg8 *) sdcard_spi_IntClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define sdcard_spi_IntClock_CLKSTBY            (* (reg8 *) sdcard_spi_IntClock__PM_STBY_CFG)
#define sdcard_spi_IntClock_CLKSTBY_PTR        ((reg8 *) sdcard_spi_IntClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define sdcard_spi_IntClock_DIV_LSB            (* (reg8 *) sdcard_spi_IntClock__CFG0)
#define sdcard_spi_IntClock_DIV_LSB_PTR        ((reg8 *) sdcard_spi_IntClock__CFG0)
#define sdcard_spi_IntClock_DIV_PTR            ((reg16 *) sdcard_spi_IntClock__CFG0)

/* Clock MSB divider configuration register. */
#define sdcard_spi_IntClock_DIV_MSB            (* (reg8 *) sdcard_spi_IntClock__CFG1)
#define sdcard_spi_IntClock_DIV_MSB_PTR        ((reg8 *) sdcard_spi_IntClock__CFG1)

/* Mode and source configuration register */
#define sdcard_spi_IntClock_MOD_SRC            (* (reg8 *) sdcard_spi_IntClock__CFG2)
#define sdcard_spi_IntClock_MOD_SRC_PTR        ((reg8 *) sdcard_spi_IntClock__CFG2)

#if defined(sdcard_spi_IntClock__CFG3)
/* Analog clock phase configuration register */
#define sdcard_spi_IntClock_PHASE              (* (reg8 *) sdcard_spi_IntClock__CFG3)
#define sdcard_spi_IntClock_PHASE_PTR          ((reg8 *) sdcard_spi_IntClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define sdcard_spi_IntClock_CLKEN_MASK         sdcard_spi_IntClock__PM_ACT_MSK
#define sdcard_spi_IntClock_CLKSTBY_MASK       sdcard_spi_IntClock__PM_STBY_MSK

/* CFG2 field masks */
#define sdcard_spi_IntClock_SRC_SEL_MSK        sdcard_spi_IntClock__CFG2_SRC_SEL_MASK
#define sdcard_spi_IntClock_MODE_MASK          (~(sdcard_spi_IntClock_SRC_SEL_MSK))

#if defined(sdcard_spi_IntClock__CFG3)
/* CFG3 phase mask */
#define sdcard_spi_IntClock_PHASE_MASK         sdcard_spi_IntClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_sdcard_spi_IntClock_H */


/* [] END OF FILE */
