/*******************************************************************************
* File Name: sdcard_write_protect.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "sdcard_write_protect.h"


/*******************************************************************************
* Function Name: sdcard_write_protect_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void sdcard_write_protect_Write(uint8 value) 
{
    uint8 staticBits = sdcard_write_protect_DR & ~sdcard_write_protect_MASK;
    sdcard_write_protect_DR = staticBits | ((value << sdcard_write_protect_SHIFT) & sdcard_write_protect_MASK);
}


/*******************************************************************************
* Function Name: sdcard_write_protect_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void sdcard_write_protect_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(sdcard_write_protect_0, mode);
}


/*******************************************************************************
* Function Name: sdcard_write_protect_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro sdcard_write_protect_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 sdcard_write_protect_Read(void) 
{
    return (sdcard_write_protect_PS & sdcard_write_protect_MASK) >> sdcard_write_protect_SHIFT;
}


/*******************************************************************************
* Function Name: sdcard_write_protect_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 sdcard_write_protect_ReadDataReg(void) 
{
    return (sdcard_write_protect_DR & sdcard_write_protect_MASK) >> sdcard_write_protect_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(sdcard_write_protect_INTSTAT) 

    /*******************************************************************************
    * Function Name: sdcard_write_protect_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 sdcard_write_protect_ClearInterrupt(void) 
    {
        return (sdcard_write_protect_INTSTAT & sdcard_write_protect_MASK) >> sdcard_write_protect_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
