/*******************************************************************************
* File Name: spi_chipselect.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "spi_chipselect.h"


/*******************************************************************************
* Function Name: spi_chipselect_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void spi_chipselect_Write(uint8 value) 
{
    uint8 staticBits = spi_chipselect_DR & ~spi_chipselect_MASK;
    spi_chipselect_DR = staticBits | ((value << spi_chipselect_SHIFT) & spi_chipselect_MASK);
}


/*******************************************************************************
* Function Name: spi_chipselect_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void spi_chipselect_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(spi_chipselect_0, mode);
}


/*******************************************************************************
* Function Name: spi_chipselect_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro spi_chipselect_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 spi_chipselect_Read(void) 
{
    return (spi_chipselect_PS & spi_chipselect_MASK) >> spi_chipselect_SHIFT;
}


/*******************************************************************************
* Function Name: spi_chipselect_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 spi_chipselect_ReadDataReg(void) 
{
    return (spi_chipselect_DR & spi_chipselect_MASK) >> spi_chipselect_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(spi_chipselect_INTSTAT) 

    /*******************************************************************************
    * Function Name: spi_chipselect_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 spi_chipselect_ClearInterrupt(void) 
    {
        return (spi_chipselect_INTSTAT & spi_chipselect_MASK) >> spi_chipselect_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
