/*******************************************************************************
* File Name: tenMillisecondCounter.c  
* Version 2.0
*
*  Description:
*     The Counter User Module consists of a 8, 16, 24 or 32-bit counter with
*     a selectable period between 2 and 2^Width - 1.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "tenMillisecondCounter.h"

uint8 tenMillisecondCounter_initVar = 0u;


/*******************************************************************************
* Function Name: tenMillisecondCounter_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_Init(void) 
{
        #if (!tenMillisecondCounter_UsingFixedFunction && !tenMillisecondCounter_ControlRegRemoved)
            uint8 ctrl;
        #endif
        
        #if(!tenMillisecondCounter_UsingFixedFunction) 
            /* Interrupt State Backup for Critical Region*/
            uint8 tenMillisecondCounter_interruptState;
        #endif
        
        #if (tenMillisecondCounter_UsingFixedFunction)
            /* Clear all bits but the enable bit (if it's already set for Timer operation */
            tenMillisecondCounter_CONTROL &= tenMillisecondCounter_CTRL_ENABLE;
            
            /* Clear the mode bits for continuous run mode */
            #if (tenMillisecondCounter_PSOC3_ES2 || tenMillisecondCounter_PSOC5_ES1)
                tenMillisecondCounter_CONTROL2 &= ~tenMillisecondCounter_CTRL_MODE_MASK;
            #endif
            #if (tenMillisecondCounter_PSOC3_ES3 || tenMillisecondCounter_PSOC5_ES2)
                tenMillisecondCounter_CONTROL3 &= ~tenMillisecondCounter_CTRL_MODE_MASK;                
            #endif
            /* Check if One Shot mode is enabled i.e. RunMode !=0*/
            #if (tenMillisecondCounter_RunModeUsed != 0x0u)
                /* Set 3rd bit of Control register to enable one shot mode */
                tenMillisecondCounter_CONTROL |= tenMillisecondCounter_ONESHOT;
            #endif
            
            /* Set the IRQ to use the status register interrupts */
            tenMillisecondCounter_CONTROL2 |= tenMillisecondCounter_CTRL2_IRQ_SEL;
            
            /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
            tenMillisecondCounter_RT1 &= ~tenMillisecondCounter_RT1_MASK;
            tenMillisecondCounter_RT1 |= tenMillisecondCounter_SYNC;     
                    
            /*Enable DSI Sync all all inputs of the Timer*/
            tenMillisecondCounter_RT1 &= ~(tenMillisecondCounter_SYNCDSI_MASK);
            tenMillisecondCounter_RT1 |= tenMillisecondCounter_SYNCDSI_EN;

        #else
            #if(!tenMillisecondCounter_ControlRegRemoved)
            /* Set the default compare mode defined in the parameter */
            ctrl = tenMillisecondCounter_CONTROL & ~tenMillisecondCounter_CTRL_CMPMODE_MASK;
            tenMillisecondCounter_CONTROL = ctrl | tenMillisecondCounter_DEFAULT_COMPARE_MODE;
            
            /* Set the default capture mode defined in the parameter */
            ctrl = tenMillisecondCounter_CONTROL & ~tenMillisecondCounter_CTRL_CAPMODE_MASK;
            tenMillisecondCounter_CONTROL = ctrl | tenMillisecondCounter_DEFAULT_CAPTURE_MODE;
            #endif
        #endif 
        
        /* Clear all data in the FIFO's */
        #if (!tenMillisecondCounter_UsingFixedFunction)
            tenMillisecondCounter_ClearFIFO();
        #endif
        
        /* Set Initial values from Configuration */
        tenMillisecondCounter_WritePeriod(tenMillisecondCounter_INIT_PERIOD_VALUE);
        tenMillisecondCounter_WriteCounter(tenMillisecondCounter_INIT_COUNTER_VALUE);
        tenMillisecondCounter_SetInterruptMode(tenMillisecondCounter_INIT_INTERRUPTS_MASK);
        
        #if (!tenMillisecondCounter_UsingFixedFunction)
            /* Read the status register to clear the unwanted interrupts */
            tenMillisecondCounter_ReadStatusRegister();
            /* Set the compare value (only available to non-fixed function implementation */
            tenMillisecondCounter_WriteCompare(tenMillisecondCounter_INIT_COMPARE_VALUE);
            /* Use the interrupt output of the status register for IRQ output */
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            tenMillisecondCounter_interruptState = CyEnterCriticalSection();
            
            tenMillisecondCounter_STATUS_AUX_CTRL |= tenMillisecondCounter_STATUS_ACTL_INT_EN_MASK;
            
            /* Exit Critical Region*/
            CyExitCriticalSection(tenMillisecondCounter_interruptState);
            
        #endif
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_Enable
********************************************************************************
* Summary:
*     Enable the Counter
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: 
*   If the Enable mode is set to Hardware only then this function has no effect 
*   on the operation of the counter.
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (tenMillisecondCounter_UsingFixedFunction)
        tenMillisecondCounter_GLOBAL_ENABLE |= tenMillisecondCounter_BLOCK_EN_MASK;
        tenMillisecondCounter_GLOBAL_STBY_ENABLE |= tenMillisecondCounter_BLOCK_STBY_EN_MASK;
    #endif   
        
    /* Enable the counter from the control register  */
    /* If Fixed Function then make sure Mode is set correctly */
    /* else make sure reset is clear */
    #if(!tenMillisecondCounter_ControlRegRemoved || tenMillisecondCounter_UsingFixedFunction)
        tenMillisecondCounter_CONTROL |= tenMillisecondCounter_CTRL_ENABLE;                
    #endif
    
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_Start
********************************************************************************
* Summary:
*  Enables the counter for operation 
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondCounter_initVar: Is modified when this function is called for the first 
*   time. Is used to ensure that initialization happens only once.
*
* Reentrant
*  No
*
*******************************************************************************/
void tenMillisecondCounter_Start(void) 
{
    if(tenMillisecondCounter_initVar == 0u)
    {
        tenMillisecondCounter_Init();
        
        tenMillisecondCounter_initVar = 1u; /* Clear this bit for Initialization */        
    }
    
    /* Enable the Counter */
    tenMillisecondCounter_Enable();        
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_Stop
********************************************************************************
* Summary:
* Halts the counter, but does not change any modes or disable interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: If the Enable mode is set to Hardware only then this function
*               has no effect on the operation of the counter.
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_Stop(void) 
{
    /* Disable Counter */
    #if(!tenMillisecondCounter_ControlRegRemoved || tenMillisecondCounter_UsingFixedFunction)
        tenMillisecondCounter_CONTROL &= ~tenMillisecondCounter_CTRL_ENABLE;        
    #endif
    
    /* Globally disable the Fixed Function Block chosen */
    #if (tenMillisecondCounter_UsingFixedFunction)
        tenMillisecondCounter_GLOBAL_ENABLE &= ~tenMillisecondCounter_BLOCK_EN_MASK;
        tenMillisecondCounter_GLOBAL_STBY_ENABLE &= ~tenMillisecondCounter_BLOCK_STBY_EN_MASK;
    #endif
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_SetInterruptMode
********************************************************************************
* Summary:
* Configures which interrupt sources are enabled to generate the final interrupt
*
* Parameters:  
*  InterruptsMask: This parameter is an or'd collection of the status bits
*                   which will be allowed to generate the counters interrupt.   
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_SetInterruptMode(uint8 interruptsMask) 
{
    tenMillisecondCounter_STATUS_MASK = interruptsMask;
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_ReadStatusRegister
********************************************************************************
* Summary:
*   Reads the status register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the status register
*
* Side Effects:
*   Status register bits may be clear on read. 
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8   tenMillisecondCounter_ReadStatusRegister(void) 
{
    return tenMillisecondCounter_STATUS;
}


#if(!tenMillisecondCounter_ControlRegRemoved)
/*******************************************************************************
* Function Name: tenMillisecondCounter_ReadControlRegister
********************************************************************************
* Summary:
*   Reads the control register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint8   tenMillisecondCounter_ReadControlRegister(void) 
{
    return tenMillisecondCounter_CONTROL;
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_WriteControlRegister
********************************************************************************
* Summary:
*   Sets the bit-field of the control register.  This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*   
* Reentrant
*  Yes
*
*******************************************************************************/
void    tenMillisecondCounter_WriteControlRegister(uint8 control) 
{
    tenMillisecondCounter_CONTROL = control;
}

#endif  /* (!tenMillisecondCounter_ControlRegRemoved) */


/*******************************************************************************
* Function Name: tenMillisecondCounter_WriteCounter
********************************************************************************
* Summary:
*   This funtion is used to set the counter to a specific value
*
* Parameters:  
*  counter:  New counter value. 
*
* Return: 
*  void 
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_WriteCounter(uint32 counter) 
{
    #if(tenMillisecondCounter_UsingFixedFunction)
        CY_SET_REG16(tenMillisecondCounter_COUNTER_LSB_PTR, (uint16)counter);
    #else
        CY_SET_REG24(tenMillisecondCounter_COUNTER_LSB_PTR, counter);
    #endif
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_ReadCounter
********************************************************************************
* Summary:
* Returns the current value of the counter.  It doesn't matter
* if the counter is enabled or running.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint32) The present value of the counter.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint32 tenMillisecondCounter_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    CY_GET_REG8(tenMillisecondCounter_COUNTER_LSB_PTR);
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    return (CY_GET_REG24(tenMillisecondCounter_STATICCOUNT_LSB_PTR));
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_ReadCapture
********************************************************************************
* Summary:
*   This function returns the last value captured.
*
* Parameters:  
*  void
*
* Return: 
*  (uint32) Present Capture value.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint32 tenMillisecondCounter_ReadCapture(void) 
{
   return ( CY_GET_REG24(tenMillisecondCounter_STATICCOUNT_LSB_PTR) );  
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_WritePeriod
********************************************************************************
* Summary:
* Changes the period of the counter.  The new period 
* will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period: (uint32) A value of 0 will result in
*         the counter remaining at zero.  
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_WritePeriod(uint32 period) 
{
    #if(tenMillisecondCounter_UsingFixedFunction)
        CY_SET_REG16(tenMillisecondCounter_PERIOD_LSB_PTR,(uint16)period);
    #else
        CY_SET_REG24(tenMillisecondCounter_PERIOD_LSB_PTR,period);
    #endif
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_ReadPeriod
********************************************************************************
* Summary:
* Reads the current period value without affecting counter operation.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint32) Present period value.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint32 tenMillisecondCounter_ReadPeriod(void) 
{
   return ( CY_GET_REG24(tenMillisecondCounter_PERIOD_LSB_PTR));
}


#if (!tenMillisecondCounter_UsingFixedFunction)
/*******************************************************************************
* Function Name: tenMillisecondCounter_WriteCompare
********************************************************************************
* Summary:
* Changes the compare value.  The compare output will 
* reflect the new value on the next UDB clock.  The compare output will be 
* driven high when the present counter value compares true based on the 
* configured compare mode setting. 
*
* Parameters:  
*  Compare:  New compare value. 
*
* Return: 
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_WriteCompare(uint32 compare) 
{
    #if(tenMillisecondCounter_UsingFixedFunction)
        CY_SET_REG16(tenMillisecondCounter_COMPARE_LSB_PTR,(uint16)compare);
    #else
        CY_SET_REG24(tenMillisecondCounter_COMPARE_LSB_PTR,compare);
    #endif
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_ReadCompare
********************************************************************************
* Summary:
* Returns the compare value.
*
* Parameters:  
*  void:
*
* Return: 
*  (uint32) Present compare value.
*
* Reentrant
*  Yes
*
*******************************************************************************/
uint32 tenMillisecondCounter_ReadCompare(void) 
{
   return ( CY_GET_REG24(tenMillisecondCounter_COMPARE_LSB_PTR));
}


#if (tenMillisecondCounter_COMPARE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: tenMillisecondCounter_SetCompareMode
********************************************************************************
* Summary:
*  Sets the software controlled Compare Mode.
*
* Parameters:
*  compareMode:  Compare Mode Enumerated Type.
*
* Return:
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_SetCompareMode(uint8 compareMode) 
{
    /* Clear the compare mode bits in the control register */
    tenMillisecondCounter_CONTROL &= ~tenMillisecondCounter_CTRL_CMPMODE_MASK;
    
    /* Write the new setting */
    tenMillisecondCounter_CONTROL |= (compareMode << tenMillisecondCounter_CTRL_CMPMODE0_SHIFT);
}
#endif  /* (tenMillisecondCounter_COMPARE_MODE_SOFTWARE) */


#if (tenMillisecondCounter_CAPTURE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: tenMillisecondCounter_SetCaptureMode
********************************************************************************
* Summary:
*  Sets the software controlled Capture Mode.
*
* Parameters:
*  captureMode:  Capture Mode Enumerated Type.
*
* Return:
*  void
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_SetCaptureMode(uint8 captureMode) 
{
    /* Clear the capture mode bits in the control register */
    tenMillisecondCounter_CONTROL &= ~tenMillisecondCounter_CTRL_CAPMODE_MASK;
    
    /* Write the new setting */
    tenMillisecondCounter_CONTROL |= (captureMode << tenMillisecondCounter_CTRL_CAPMODE0_SHIFT);
}
#endif  /* (tenMillisecondCounter_CAPTURE_MODE_SOFTWARE) */


/*******************************************************************************
* Function Name: tenMillisecondCounter_ClearFIFO
********************************************************************************
* Summary:
*   This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void:
*
* Return: 
*  None
*
* Reentrant
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_ClearFIFO(void) 
{

    while(tenMillisecondCounter_ReadStatusRegister() & tenMillisecondCounter_STATUS_FIFONEMP)
    {
        tenMillisecondCounter_ReadCapture();
    }

}
#endif  /* (!tenMillisecondCounter_UsingFixedFunction) */


/* [] END OF FILE */

