/*******************************************************************************
* File Name: tenMillisecondCounter.h  
* Version 2.0
*
*  Description:
*   Contains the function prototypes and constants available to the counter
*   user module.
*
*   Note:
*    None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
    
#if !defined(CY_COUNTER_tenMillisecondCounter_H)
#define CY_COUNTER_tenMillisecondCounter_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

/***************************************
* Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define tenMillisecondCounter_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES1 or early */
#define tenMillisecondCounter_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define tenMillisecondCounter_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES2 or later */
#define tenMillisecondCounter_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))


/**************************************
*           Parameter Defaults        
**************************************/

#define tenMillisecondCounter_Resolution            24u
#define tenMillisecondCounter_UsingFixedFunction    0u
#define tenMillisecondCounter_ControlRegRemoved     0u
#define tenMillisecondCounter_COMPARE_MODE_SOFTWARE 0u
#define tenMillisecondCounter_CAPTURE_MODE_SOFTWARE 0u
#define tenMillisecondCounter_RunModeUsed           0u


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
/**************************************************************************
 * Backup structure for Sleep Wake up operations
 *************************************************************************/
typedef struct tenMillisecondCounter_backupStruct
{
    /* Sleep BackUp structure */
    uint8 CounterEnableState; 
    #if (tenMillisecondCounter_PSOC3_ES2 || tenMillisecondCounter_PSOC5_ES1)
        uint32 CounterUdb;    /* Current Counter Value      */
        uint32 CounterPeriod; /* Counter Period Value       */
        uint32 CompareValue;  /* Counter Compare Value      */           
        uint8 InterruptMaskValue; /* Counter Compare Value */
    #endif
	
	#if (tenMillisecondCounter_PSOC3_ES3 || tenMillisecondCounter_PSOC5_ES2)
			uint32 CounterUdb;
			uint8 InterruptMaskValue;
	#endif
	
    #if (!tenMillisecondCounter_ControlRegRemoved)
        uint8 CounterControlRegister;          /* Counter Control Register   */
    #endif
}tenMillisecondCounter_backupStruct;

/**************************************
 *  Function Prototypes
 *************************************/
void    tenMillisecondCounter_Start(void);
void    tenMillisecondCounter_Stop(void) ;
void    tenMillisecondCounter_SetInterruptMode(uint8 interruptsMask) ;
uint8   tenMillisecondCounter_ReadStatusRegister(void) ;
#define tenMillisecondCounter_GetInterruptSource() tenMillisecondCounter_ReadStatusRegister()
#if(!tenMillisecondCounter_ControlRegRemoved)
    uint8   tenMillisecondCounter_ReadControlRegister(void) ;
    void    tenMillisecondCounter_WriteControlRegister(uint8 control) \
        ;
#endif
void    tenMillisecondCounter_WriteCounter(uint32 counter) \
    ; 
uint32  tenMillisecondCounter_ReadCounter(void) ;
uint32  tenMillisecondCounter_ReadCapture(void) ;
void    tenMillisecondCounter_WritePeriod(uint32 period) \
    ;
uint32  tenMillisecondCounter_ReadPeriod( void ) ;
#if (!tenMillisecondCounter_UsingFixedFunction)
    void    tenMillisecondCounter_WriteCompare(uint32 compare) \
        ;
    uint32  tenMillisecondCounter_ReadCompare( void ) \
        ;
#endif

#if (tenMillisecondCounter_COMPARE_MODE_SOFTWARE)
    void    tenMillisecondCounter_SetCompareMode(uint8 comparemode) ;
#endif
#if (tenMillisecondCounter_CAPTURE_MODE_SOFTWARE)
    void    tenMillisecondCounter_SetCaptureMode(uint8 capturemode) ;
#endif
void tenMillisecondCounter_ClearFIFO(void)     ;
void tenMillisecondCounter_Init(void)          ;
void tenMillisecondCounter_Enable(void)        ;
void tenMillisecondCounter_SaveConfig(void)    ;
void tenMillisecondCounter_RestoreConfig(void) ;
void tenMillisecondCounter_Sleep(void)         ;
void tenMillisecondCounter_Wakeup(void)        ;

/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Counter__CompareModes, Used in Compare Mode retained for backward compatibility of tests*/
#define tenMillisecondCounter__B_COUNTER__LESS_THAN 1
#define tenMillisecondCounter__B_COUNTER__LESS_THAN_OR_EQUAL 2
#define tenMillisecondCounter__B_COUNTER__EQUAL 0
#define tenMillisecondCounter__B_COUNTER__GREATER_THAN 3
#define tenMillisecondCounter__B_COUNTER__GREATER_THAN_OR_EQUAL 4
#define tenMillisecondCounter__B_COUNTER__SOFTWARE 5

/* Enumerated Type Counter_CompareModes */
#define tenMillisecondCounter_CMP_MODE_LT 1u
#define tenMillisecondCounter_CMP_MODE_LTE 2u
#define tenMillisecondCounter_CMP_MODE_EQ 0u
#define tenMillisecondCounter_CMP_MODE_GT 3u
#define tenMillisecondCounter_CMP_MODE_GTE 4u
#define tenMillisecondCounter_CMP_MODE_SOFTWARE_CONTROLLED 5u

/* Enumerated Type B_Counter__CaptureModes, Used in Capture Mode retained for backward compatibility of tests*/
#define tenMillisecondCounter__B_COUNTER__NONE 0
#define tenMillisecondCounter__B_COUNTER__RISING_EDGE 1
#define tenMillisecondCounter__B_COUNTER__FALLING_EDGE 2
#define tenMillisecondCounter__B_COUNTER__EITHER_EDGE 3
#define tenMillisecondCounter__B_COUNTER__SOFTWARE_CONTROL 4

/* Enumerated Type Counter_CompareModes */
#define tenMillisecondCounter_CAP_MODE_NONE 0u
#define tenMillisecondCounter_CAP_MODE_RISE 1u
#define tenMillisecondCounter_CAP_MODE_FALL 2u
#define tenMillisecondCounter_CAP_MODE_BOTH 3u
#define tenMillisecondCounter_CAP_MODE_SOFTWARE_CONTROLLED 4u
/***************************************
 *  Initialization Values
 **************************************/
#define tenMillisecondCounter_INIT_PERIOD_VALUE       240000u
#define tenMillisecondCounter_INIT_COUNTER_VALUE      240000u
#if (tenMillisecondCounter_UsingFixedFunction)
#define tenMillisecondCounter_INIT_INTERRUPTS_MASK    ((0u << tenMillisecondCounter_STATUS_ZERO_INT_EN_MASK_SHIFT))
#else
#define tenMillisecondCounter_INIT_COMPARE_VALUE      128u
#define tenMillisecondCounter_INIT_INTERRUPTS_MASK ((0u << tenMillisecondCounter_STATUS_ZERO_INT_EN_MASK_SHIFT) | \
        (0u << tenMillisecondCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT) | \
        (0u << tenMillisecondCounter_STATUS_CMP_INT_EN_MASK_SHIFT) | \
        (0u << tenMillisecondCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT) | \
        (0u << tenMillisecondCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT))
#define tenMillisecondCounter_DEFAULT_COMPARE_MODE    (1u << tenMillisecondCounter_CTRL_CMPMODE0_SHIFT)
#define tenMillisecondCounter_DEFAULT_CAPTURE_MODE    (0u << tenMillisecondCounter_CTRL_CAPMODE0_SHIFT)
#endif /* (tenMillisecondCounter_UsingFixedFunction) */

/**************************************
 *  Registers
 *************************************/
#if (tenMillisecondCounter_UsingFixedFunction)
    #define tenMillisecondCounter_STATICCOUNT_LSB     (*(reg16 *) tenMillisecondCounter_CounterHW__CAP0 )
    #define tenMillisecondCounter_STATICCOUNT_LSB_PTR ( (reg16 *) tenMillisecondCounter_CounterHW__CAP0 )
    #define tenMillisecondCounter_PERIOD_LSB          (*(reg16 *) tenMillisecondCounter_CounterHW__PER0 )
    #define tenMillisecondCounter_PERIOD_LSB_PTR      ( (reg16 *) tenMillisecondCounter_CounterHW__PER0 )
    /* MODE must be set to 1 to set the compare value */
    #define tenMillisecondCounter_COMPARE_LSB         (*(reg16 *) tenMillisecondCounter_CounterHW__CNT_CMP0 )
    #define tenMillisecondCounter_COMPARE_LSB_PTR     ( (reg16 *) tenMillisecondCounter_CounterHW__CNT_CMP0 )
    /* MODE must be set to 0 to get the count */
    #define tenMillisecondCounter_COUNTER_LSB         (*(reg16 *) tenMillisecondCounter_CounterHW__CNT_CMP0 )
    #define tenMillisecondCounter_COUNTER_LSB_PTR     ( (reg16 *) tenMillisecondCounter_CounterHW__CNT_CMP0 )
    #define tenMillisecondCounter_RT1                 (*(reg8 *) tenMillisecondCounter_CounterHW__RT1)
    #define tenMillisecondCounter_RT1_PTR             ( (reg8 *) tenMillisecondCounter_CounterHW__RT1)
#else
    #define tenMillisecondCounter_STATICCOUNT_LSB     (*(reg32 *) \
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
    #define tenMillisecondCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
    #define tenMillisecondCounter_PERIOD_LSB          (*(reg32 *) \
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
    #define tenMillisecondCounter_PERIOD_LSB_PTR      ( (reg32 *) \
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
    #define tenMillisecondCounter_COMPARE_LSB         (*(reg32 *) \
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
    #define tenMillisecondCounter_COMPARE_LSB_PTR     ( (reg32 *) \
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
    #define tenMillisecondCounter_COUNTER_LSB         (*(reg32 *) \
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__A0_REG )
    #define tenMillisecondCounter_COUNTER_LSB_PTR     ( (reg32 *)\
        tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__A0_REG )

    #define tenMillisecondCounter_AUX_CONTROLDP0 \
        (*(reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__DP_AUX_CTL_REG)
    #define tenMillisecondCounter_AUX_CONTROLDP0_PTR \
        ( (reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u0__DP_AUX_CTL_REG)
    #if (tenMillisecondCounter_Resolution == 16 || tenMillisecondCounter_Resolution == 24 || tenMillisecondCounter_Resolution == 32)
       #define tenMillisecondCounter_AUX_CONTROLDP1 \
           (*(reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u1__DP_AUX_CTL_REG)
       #define tenMillisecondCounter_AUX_CONTROLDP1_PTR \
           ( (reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u1__DP_AUX_CTL_REG)
    #endif
    #if (tenMillisecondCounter_Resolution == 24 || tenMillisecondCounter_Resolution == 32)
       #define tenMillisecondCounter_AUX_CONTROLDP2 \
           (*(reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u2__DP_AUX_CTL_REG)
       #define tenMillisecondCounter_AUX_CONTROLDP2_PTR \
           ( (reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u2__DP_AUX_CTL_REG)
    #endif
    #if (tenMillisecondCounter_Resolution == 32)
       #define tenMillisecondCounter_AUX_CONTROLDP3 \
           (*(reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u3__DP_AUX_CTL_REG)
       #define tenMillisecondCounter_AUX_CONTROLDP3_PTR \
           ( (reg8 *) tenMillisecondCounter_CounterUDB_sC24_counterdp_u3__DP_AUX_CTL_REG)
    #endif
#endif  /* (tenMillisecondCounter_UsingFixedFunction) */

#if (tenMillisecondCounter_UsingFixedFunction)
    #define tenMillisecondCounter_STATUS         (*(reg8 *) tenMillisecondCounter_CounterHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define tenMillisecondCounter_STATUS_MASK             (*(reg8 *) tenMillisecondCounter_CounterHW__SR0 )
    #define tenMillisecondCounter_STATUS_MASK_PTR         ( (reg8 *) tenMillisecondCounter_CounterHW__SR0 )
    #define tenMillisecondCounter_CONTROL                 (*(reg8 *) tenMillisecondCounter_CounterHW__CFG0)
    #define tenMillisecondCounter_CONTROL_PTR             ( (reg8 *) tenMillisecondCounter_CounterHW__CFG0)
    #define tenMillisecondCounter_CONTROL2                (*(reg8 *) tenMillisecondCounter_CounterHW__CFG1)
    #define tenMillisecondCounter_CONTROL2_PTR            ( (reg8 *) tenMillisecondCounter_CounterHW__CFG1)
    #if (tenMillisecondCounter_PSOC3_ES3 || tenMillisecondCounter_PSOC5_ES2)
        #define tenMillisecondCounter_CONTROL3       (*(reg8 *) tenMillisecondCounter_CounterHW__CFG2)
        #define tenMillisecondCounter_CONTROL3_PTR   ( (reg8 *) tenMillisecondCounter_CounterHW__CFG2)
    #endif
    #define tenMillisecondCounter_GLOBAL_ENABLE           (*(reg8 *) tenMillisecondCounter_CounterHW__PM_ACT_CFG)
    #define tenMillisecondCounter_GLOBAL_ENABLE_PTR       ( (reg8 *) tenMillisecondCounter_CounterHW__PM_ACT_CFG)
    #define tenMillisecondCounter_GLOBAL_STBY_ENABLE      (*(reg8 *) tenMillisecondCounter_CounterHW__PM_STBY_CFG)
    #define tenMillisecondCounter_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) tenMillisecondCounter_CounterHW__PM_STBY_CFG)
    
    /********************************
    *    Constants
    ********************************/
    /* Fixed Function Block Chosen */
    #define tenMillisecondCounter_BLOCK_EN_MASK          tenMillisecondCounter_CounterHW__PM_ACT_MSK
    #define tenMillisecondCounter_BLOCK_STBY_EN_MASK     tenMillisecondCounter_CounterHW__PM_STBY_MSK 
    
    /* Control Register Bit Locations */    
    /* As defined in Register Map, part of TMRX_CFG0 register */
    #define tenMillisecondCounter_CTRL_ENABLE_SHIFT      0x00u
	#define tenMillisecondCounter_ONESHOT_SHIFT			0x02u
    /* Control Register Bit Masks */
    #define tenMillisecondCounter_CTRL_ENABLE            (0x01u << tenMillisecondCounter_CTRL_ENABLE_SHIFT)         
	#define tenMillisecondCounter_ONESHOT 				(0x01u << tenMillisecondCounter_ONESHOT_SHIFT)
	
    /* Control2 Register Bit Masks */
    /* Set the mask for run mode */
    #if (tenMillisecondCounter_PSOC3_ES2 || tenMillisecondCounter_PSOC5_ES1)
        /* Use CFG1 Mode bits to set run mode */
        #define tenMillisecondCounter_CTRL_MODE_SHIFT        0x01u    
        #define tenMillisecondCounter_CTRL_MODE_MASK         (0x07u << tenMillisecondCounter_CTRL_MODE_SHIFT)
    #endif
    #if (tenMillisecondCounter_PSOC3_ES3 || tenMillisecondCounter_PSOC5_ES2)
        /* Use CFG2 Mode bits to set run mode */
        #define tenMillisecondCounter_CTRL_MODE_SHIFT        0x00u    
        #define tenMillisecondCounter_CTRL_MODE_MASK         (0x03u << tenMillisecondCounter_CTRL_MODE_SHIFT)
    #endif
    /* Set the mask for interrupt (raw/status register) */
    #define tenMillisecondCounter_CTRL2_IRQ_SEL_SHIFT     0x00u
    #define tenMillisecondCounter_CTRL2_IRQ_SEL          (0x01u << tenMillisecondCounter_CTRL2_IRQ_SEL_SHIFT)     
    
    /* Status Register Bit Locations */
    #define tenMillisecondCounter_STATUS_ZERO_SHIFT      0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 

    /* Status Register Interrupt Enable Bit Locations */
    #define tenMillisecondCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      (tenMillisecondCounter_STATUS_ZERO_SHIFT - 0x04u)

    /* Status Register Bit Masks */                           
    #define tenMillisecondCounter_STATUS_ZERO            (0x01u << tenMillisecondCounter_STATUS_ZERO_SHIFT)

    /* Status Register Interrupt Bit Masks*/
    #define tenMillisecondCounter_STATUS_ZERO_INT_EN_MASK       (tenMillisecondCounter_STATUS_ZERO >> 0x04u)
    
    /*RT1 Synch Constants: Applicable for PSoC3 ES2/PSoC3 ES3 PSoC5 ES2*/
    #define tenMillisecondCounter_RT1_SHIFT            0x04u
    #define tenMillisecondCounter_RT1_MASK             (0x03u << tenMillisecondCounter_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define tenMillisecondCounter_SYNC                 (0x03u << tenMillisecondCounter_RT1_SHIFT)
    #define tenMillisecondCounter_SYNCDSI_SHIFT        0x00u
    #define tenMillisecondCounter_SYNCDSI_MASK         (0x0Fu << tenMillisecondCounter_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define tenMillisecondCounter_SYNCDSI_EN           (0x0Fu << tenMillisecondCounter_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    
#else /* !tenMillisecondCounter_UsingFixedFunction */
    #define tenMillisecondCounter_STATUS               (* (reg8 *) tenMillisecondCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define tenMillisecondCounter_STATUS_PTR           (  (reg8 *) tenMillisecondCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define tenMillisecondCounter_STATUS_MASK          (* (reg8 *) tenMillisecondCounter_CounterUDB_sSTSReg_nrstSts_stsreg__MASK_REG )
    #define tenMillisecondCounter_STATUS_MASK_PTR      (  (reg8 *) tenMillisecondCounter_CounterUDB_sSTSReg_nrstSts_stsreg__MASK_REG )
    #define tenMillisecondCounter_STATUS_AUX_CTRL      (*(reg8 *) tenMillisecondCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define tenMillisecondCounter_STATUS_AUX_CTRL_PTR  ( (reg8 *) tenMillisecondCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define tenMillisecondCounter_CONTROL              (* (reg8 *) tenMillisecondCounter_CounterUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG )
    #define tenMillisecondCounter_CONTROL_PTR          (  (reg8 *) tenMillisecondCounter_CounterUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG )

    /********************************
    *    Constants
    ********************************/
    /* Control Register Bit Locations */
    #define tenMillisecondCounter_CTRL_CMPMODE0_SHIFT    0x00u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_CTRL_CAPMODE0_SHIFT    0x03u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_CTRL_RESET_SHIFT       0x06u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_CTRL_ENABLE_SHIFT      0x07u       /* As defined by Verilog Implementation */
    /* Control Register Bit Masks */
    #define tenMillisecondCounter_CTRL_CMPMODE_MASK      (0x07u << tenMillisecondCounter_CTRL_CMPMODE0_SHIFT)  
    #define tenMillisecondCounter_CTRL_CAPMODE_MASK      (0x03u << tenMillisecondCounter_CTRL_CAPMODE0_SHIFT)  
    #define tenMillisecondCounter_CTRL_RESET             (0x01u << tenMillisecondCounter_CTRL_RESET_SHIFT)  
    #define tenMillisecondCounter_CTRL_ENABLE            (0x01u << tenMillisecondCounter_CTRL_ENABLE_SHIFT) 

    /* Status Register Bit Locations */
    #define tenMillisecondCounter_STATUS_CMP_SHIFT       0x00u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_STATUS_ZERO_SHIFT      0x01u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_STATUS_OVERFLOW_SHIFT  0x02u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_STATUS_UNDERFLOW_SHIFT 0x03u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_STATUS_CAPTURE_SHIFT   0x04u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_STATUS_FIFOFULL_SHIFT  0x05u       /* As defined by Verilog Implementation */
    #define tenMillisecondCounter_STATUS_FIFONEMP_SHIFT  0x06u       /* As defined by Verilog Implementation */
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define tenMillisecondCounter_STATUS_CMP_INT_EN_MASK_SHIFT       tenMillisecondCounter_STATUS_CMP_SHIFT       
    #define tenMillisecondCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      tenMillisecondCounter_STATUS_ZERO_SHIFT      
    #define tenMillisecondCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT  tenMillisecondCounter_STATUS_OVERFLOW_SHIFT  
    #define tenMillisecondCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT tenMillisecondCounter_STATUS_UNDERFLOW_SHIFT 
    #define tenMillisecondCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT   tenMillisecondCounter_STATUS_CAPTURE_SHIFT   
    #define tenMillisecondCounter_STATUS_FIFOFULL_INT_EN_MASK_SHIFT  tenMillisecondCounter_STATUS_FIFOFULL_SHIFT  
    #define tenMillisecondCounter_STATUS_FIFONEMP_INT_EN_MASK_SHIFT  tenMillisecondCounter_STATUS_FIFONEMP_SHIFT  
    /* Status Register Bit Masks */                
    #define tenMillisecondCounter_STATUS_CMP             (0x01u << tenMillisecondCounter_STATUS_CMP_SHIFT)  
    #define tenMillisecondCounter_STATUS_ZERO            (0x01u << tenMillisecondCounter_STATUS_ZERO_SHIFT) 
    #define tenMillisecondCounter_STATUS_OVERFLOW        (0x01u << tenMillisecondCounter_STATUS_OVERFLOW_SHIFT) 
    #define tenMillisecondCounter_STATUS_UNDERFLOW       (0x01u << tenMillisecondCounter_STATUS_UNDERFLOW_SHIFT) 
    #define tenMillisecondCounter_STATUS_CAPTURE         (0x01u << tenMillisecondCounter_STATUS_CAPTURE_SHIFT) 
    #define tenMillisecondCounter_STATUS_FIFOFULL        (0x01u << tenMillisecondCounter_STATUS_FIFOFULL_SHIFT)
    #define tenMillisecondCounter_STATUS_FIFONEMP        (0x01u << tenMillisecondCounter_STATUS_FIFONEMP_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define tenMillisecondCounter_STATUS_CMP_INT_EN_MASK            tenMillisecondCounter_STATUS_CMP                    
    #define tenMillisecondCounter_STATUS_ZERO_INT_EN_MASK           tenMillisecondCounter_STATUS_ZERO            
    #define tenMillisecondCounter_STATUS_OVERFLOW_INT_EN_MASK       tenMillisecondCounter_STATUS_OVERFLOW        
    #define tenMillisecondCounter_STATUS_UNDERFLOW_INT_EN_MASK      tenMillisecondCounter_STATUS_UNDERFLOW       
    #define tenMillisecondCounter_STATUS_CAPTURE_INT_EN_MASK        tenMillisecondCounter_STATUS_CAPTURE         
    #define tenMillisecondCounter_STATUS_FIFOFULL_INT_EN_MASK       tenMillisecondCounter_STATUS_FIFOFULL        
    #define tenMillisecondCounter_STATUS_FIFONEMP_INT_EN_MASK       tenMillisecondCounter_STATUS_FIFONEMP         
    

    /* StatusI Interrupt Enable bit Location in the Auxilliary Control Register */
    #define tenMillisecondCounter_STATUS_ACTL_INT_EN     0x10u /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define tenMillisecondCounter_AUX_CTRL_FIFO0_CLR         0x01u   /* As defined by Register map */
    #define tenMillisecondCounter_AUX_CTRL_FIFO1_CLR         0x02u   /* As defined by Register map */
    #define tenMillisecondCounter_AUX_CTRL_FIFO0_LVL         0x04u   /* As defined by Register map */
    #define tenMillisecondCounter_AUX_CTRL_FIFO1_LVL         0x08u   /* As defined by Register map */
    #define tenMillisecondCounter_STATUS_ACTL_INT_EN_MASK    0x10u   /* As defined for the ACTL Register */
    
#endif /* tenMillisecondCounter_UsingFixedFunction */

#endif  /* CY_COUNTER_tenMillisecondCounter_H */


/* [] END OF FILE */

