/*******************************************************************************
* File Name: tenMillisecondCounter_PM.c  
* Version 2.0
*
*  Description:
*     This file provides the power management source code to API for the
*     Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "tenMillisecondCounter.h"

static tenMillisecondCounter_backupStruct tenMillisecondCounter_backup;

/*******************************************************************************
* Function Name: tenMillisecondCounter_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondCounter_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*    No
*
*******************************************************************************/
void tenMillisecondCounter_SaveConfig(void)
{
    #if (!tenMillisecondCounter_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (tenMillisecondCounter_PSOC3_ES2 || tenMillisecondCounter_PSOC5_ES1)
            tenMillisecondCounter_backup.CounterUdb = tenMillisecondCounter_ReadCounter();
            tenMillisecondCounter_backup.CounterPeriod = tenMillisecondCounter_ReadPeriod();
            tenMillisecondCounter_backup.CompareValue = tenMillisecondCounter_ReadCompare();
            tenMillisecondCounter_backup.InterruptMaskValue = tenMillisecondCounter_STATUS_MASK;
        #endif
		
		#if (tenMillisecondCounter_PSOC3_ES3 || tenMillisecondCounter_PSOC5_ES2)
			tenMillisecondCounter_backup.CounterUdb = tenMillisecondCounter_ReadCounter();
			tenMillisecondCounter_backup.InterruptMaskValue = tenMillisecondCounter_STATUS_MASK;
		#endif
		
        #if(!tenMillisecondCounter_ControlRegRemoved)
            tenMillisecondCounter_backup.CounterControlRegister = tenMillisecondCounter_ReadControlRegister();
		#endif
    #endif
}

/*******************************************************************************
* Function Name: tenMillisecondCounter_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondCounter_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_RestoreConfig(void) 
{      
    #if (!tenMillisecondCounter_UsingFixedFunction)     
        /* Restore the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (tenMillisecondCounter_PSOC3_ES2 || tenMillisecondCounter_PSOC5_ES1)
            tenMillisecondCounter_WriteCounter(tenMillisecondCounter_backup.CounterUdb);
            tenMillisecondCounter_WritePeriod(tenMillisecondCounter_backup.CounterPeriod);
            tenMillisecondCounter_WriteCompare(tenMillisecondCounter_backup.CompareValue);
            tenMillisecondCounter_STATUS_MASK = tenMillisecondCounter_backup.InterruptMaskValue;
        #endif
		
		#if (tenMillisecondCounter_PSOC3_ES3 || tenMillisecondCounter_PSOC5_ES2)
			tenMillisecondCounter_WriteCounter(tenMillisecondCounter_backup.CounterUdb);
			tenMillisecondCounter_STATUS_MASK = tenMillisecondCounter_backup.InterruptMaskValue;
		#endif
		
		
        #if(!tenMillisecondCounter_ControlRegRemoved)
            tenMillisecondCounter_WriteControlRegister(tenMillisecondCounter_backup.CounterControlRegister);
        #endif
    #endif
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondCounter_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void tenMillisecondCounter_Sleep(void)
{
    #if(!tenMillisecondCounter_ControlRegRemoved)
        /* Save Counter's enable state */
        if(tenMillisecondCounter_CTRL_ENABLE == (tenMillisecondCounter_CONTROL & tenMillisecondCounter_CTRL_ENABLE))
        {
            /* Counter is enabled */
            tenMillisecondCounter_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            tenMillisecondCounter_backup.CounterEnableState = 0u;
        }
    #endif
    tenMillisecondCounter_Stop();
    tenMillisecondCounter_SaveConfig();
}


/*******************************************************************************
* Function Name: tenMillisecondCounter_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondCounter_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void tenMillisecondCounter_Wakeup(void) 
{
    tenMillisecondCounter_RestoreConfig();
    #if(!tenMillisecondCounter_ControlRegRemoved)
        if(tenMillisecondCounter_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            tenMillisecondCounter_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif
    
}


/* [] END OF FILE */
