/*******************************************************************************
* File Name: tenMillisecondTimer.h  
* Version 2.0
*
*  Description:
*     Contains the function prototypes and constants available to the timer
*     user module.
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_Timer_v2_0_tenMillisecondTimer_H)
#define CY_Timer_v2_0_tenMillisecondTimer_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

/***************************************
*   Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define tenMillisecondTimer_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES1 or early */
#define tenMillisecondTimer_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define tenMillisecondTimer_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES2 or later */
#define tenMillisecondTimer_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))


/**************************************
*           Parameter Defaults        
**************************************/

#define tenMillisecondTimer_Resolution                 24u
#define tenMillisecondTimer_UsingFixedFunction         0u
#define tenMillisecondTimer_UsingHWCaptureCounter      0u
#define tenMillisecondTimer_SoftwareCaptureMode        0u
#define tenMillisecondTimer_SoftwareTriggerMode        0u
#define tenMillisecondTimer_UsingHWEnable              0u
#define tenMillisecondTimer_EnableTriggerMode          0u
#define tenMillisecondTimer_InterruptOnCaptureCount    0u
#define tenMillisecondTimer_RunModeUsed                0u
#define tenMillisecondTimer_ControlRegRemoved          0u


/***************************************
*       Type defines
***************************************/
/**************************************************************************
 * Sleep Wakeup Backup structure for Timer Component
 *************************************************************************/
typedef struct tenMillisecondTimer_backupStruct
{
    uint8 TimerEnableState; 
    #if(!tenMillisecondTimer_UsingFixedFunction) 
        #if (tenMillisecondTimer_PSOC3_ES2 || tenMillisecondTimer_PSOC5_ES1)
            uint32 TimerUdb;                 /* Timer internal counter value      */
            uint32 TimerPeriod;              /* Timer Period value       */
            uint8 InterruptMaskValue;       /* Timer Compare Value */
            #if (tenMillisecondTimer_UsingHWCaptureCounter)
                uint32 TimerCaptureCounter;  /* Timer Capture Counter Value */           
            #endif
        #endif
        
        #if (tenMillisecondTimer_PSOC3_ES3 || tenMillisecondTimer_PSOC5_ES2)
            uint32 TimerUdb;  
            uint8 InterruptMaskValue;
            #if (tenMillisecondTimer_UsingHWCaptureCounter)
                uint32 TimerCaptureCounter;
            #endif
        #endif
        
        #if (!tenMillisecondTimer_ControlRegRemoved)
        uint8 TimerControlRegister;
        #endif
    #endif
}tenMillisecondTimer_backupStruct;


/*************************************** 
*       Function Prototypes 
***************************************/

void    tenMillisecondTimer_Start(void);
void    tenMillisecondTimer_Stop(void) ;

void    tenMillisecondTimer_SetInterruptMode(uint8 interruptMode) ;
uint8   tenMillisecondTimer_ReadStatusRegister(void) ;
/* Deprecated function. Do not use this in future. Retained for backward compatibility */
#define tenMillisecondTimer_GetInterruptSource() tenMillisecondTimer_ReadStatusRegister() 

#if(!tenMillisecondTimer_ControlRegRemoved)
    uint8   tenMillisecondTimer_ReadControlRegister(void) ;
    void    tenMillisecondTimer_WriteControlRegister(uint8 control) \
        ;
#endif

uint32  tenMillisecondTimer_ReadPeriod(void) ;
void    tenMillisecondTimer_WritePeriod(uint32 period) \
    ;
uint32  tenMillisecondTimer_ReadCounter(void) ;
void    tenMillisecondTimer_WriteCounter(uint32 counter) \
    ;
uint32  tenMillisecondTimer_ReadCapture(void) ;
void    tenMillisecondTimer_SoftwareCapture(void) ;


#if(!tenMillisecondTimer_UsingFixedFunction) /* UDB Prototypes */
    #if (tenMillisecondTimer_SoftwareCaptureMode)
        void    tenMillisecondTimer_SetCaptureMode(uint8 captureMode) ;
    #endif

    #if (tenMillisecondTimer_SoftwareTriggerMode)
        void    tenMillisecondTimer_SetTriggerMode(uint8 triggerMode) ;
    #endif
    #if (tenMillisecondTimer_EnableTriggerMode)
        void    tenMillisecondTimer_EnableTrigger(void) ;
        void    tenMillisecondTimer_DisableTrigger(void) ;
    #endif

    #if(tenMillisecondTimer_InterruptOnCaptureCount)
        #if(!tenMillisecondTimer_ControlRegRemoved)
            void    tenMillisecondTimer_SetInterruptCount(uint8 interruptCount) \
                ;
        #endif
    #endif

    #if (tenMillisecondTimer_UsingHWCaptureCounter)
        void    tenMillisecondTimer_SetCaptureCount(uint8 captureCount) \
            ;
        uint8   tenMillisecondTimer_ReadCaptureCount(void) ;
    #endif

    void tenMillisecondTimer_ClearFIFO(void) ;
#endif /* UDB Prototypes */

/* Sleep Retention APIs */
void tenMillisecondTimer_Init(void)          ;
void tenMillisecondTimer_Enable(void)        ;
void tenMillisecondTimer_SaveConfig(void);
void tenMillisecondTimer_RestoreConfig(void) ;
void tenMillisecondTimer_Sleep(void);
void tenMillisecondTimer_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Timer__CaptureModes, Used in Capture Mode */
#define tenMillisecondTimer__B_TIMER__CM_NONE 0
#define tenMillisecondTimer__B_TIMER__CM_RISINGEDGE 1
#define tenMillisecondTimer__B_TIMER__CM_FALLINGEDGE 2
#define tenMillisecondTimer__B_TIMER__CM_EITHEREDGE 3
#define tenMillisecondTimer__B_TIMER__CM_SOFTWARE 4


  
/* Enumerated Type B_Timer__TriggerModes, Used in Trigger Mode */
#define tenMillisecondTimer__B_TIMER__TM_NONE 0x00u
#define tenMillisecondTimer__B_TIMER__TM_RISINGEDGE 0x04u
#define tenMillisecondTimer__B_TIMER__TM_FALLINGEDGE 0x08u
#define tenMillisecondTimer__B_TIMER__TM_EITHEREDGE 0x0Cu
#define tenMillisecondTimer__B_TIMER__TM_SOFTWARE 0x10u


/***************************************
*    Initialial Parameter Constants
***************************************/

#define tenMillisecondTimer_INIT_PERIOD             47999u
#define tenMillisecondTimer_INIT_CAPTURE_MODE       (0u << tenMillisecondTimer_CTRL_CAP_MODE_SHIFT)
#define tenMillisecondTimer_INIT_TRIGGER_MODE       (0u << tenMillisecondTimer_CTRL_TRIG_MODE_SHIFT)
#if (tenMillisecondTimer_UsingFixedFunction)
    #define tenMillisecondTimer_INIT_INTERRUPT_MODE ((0u << tenMillisecondTimer_STATUS_TC_INT_MASK_SHIFT) | \
                                                  (0 << tenMillisecondTimer_STATUS_CAPTURE_INT_MASK_SHIFT))
#else
    #define tenMillisecondTimer_INIT_INTERRUPT_MODE ((0u << tenMillisecondTimer_STATUS_TC_INT_MASK_SHIFT) | \
                                                  (0 << tenMillisecondTimer_STATUS_CAPTURE_INT_MASK_SHIFT) | \
                                                  (0 << tenMillisecondTimer_STATUS_FIFOFULL_INT_MASK_SHIFT))
#endif
#define tenMillisecondTimer_INIT_CAPTURE_COUNT      (2u)
#define tenMillisecondTimer_INIT_INT_CAPTURE_COUNT  ((1u - 1) << tenMillisecondTimer_CTRL_INTCNT_SHIFT)


/***************************************
*           Registers
***************************************/

#if (tenMillisecondTimer_UsingFixedFunction) /* Implementation Specific Registers and Register Constants */

    
    /***************************************
    *    Fixed Function Registers 
    ***************************************/
    
    #define tenMillisecondTimer_STATUS         (*(reg8 *) tenMillisecondTimer_TimerHW__SR0 )
    #define tenMillisecondTimer_STATUS_MASK    (*(reg8 *) tenMillisecondTimer_TimerHW__SR0 ) /* In Fixed Function Block Status and Mask are the same register */
    #define tenMillisecondTimer_CONTROL        (*(reg8 *) tenMillisecondTimer_TimerHW__CFG0)
    #define tenMillisecondTimer_CONTROL2       (*(reg8 *) tenMillisecondTimer_TimerHW__CFG1)
    #define tenMillisecondTimer_CONTROL2_PTR   ( (reg8 *) tenMillisecondTimer_TimerHW__CFG1)    
    #define tenMillisecondTimer_RT1            (*(reg8 *) tenMillisecondTimer_TimerHW__RT1)
    #define tenMillisecondTimer_RT1_PTR        ( (reg8 *) tenMillisecondTimer_TimerHW__RT1)

    #if (tenMillisecondTimer_PSOC3_ES3 || tenMillisecondTimer_PSOC5_ES2)
        #define tenMillisecondTimer_CONTROL3       (*(reg8 *) tenMillisecondTimer_TimerHW__CFG2)
        #define tenMillisecondTimer_CONTROL3_PTR   ( (reg8 *) tenMillisecondTimer_TimerHW__CFG2)
    #endif
    #define tenMillisecondTimer_GLOBAL_ENABLE  (*(reg8 *) tenMillisecondTimer_TimerHW__PM_ACT_CFG)
    #define tenMillisecondTimer_GLOBAL_STBY_ENABLE  (*(reg8 *) tenMillisecondTimer_TimerHW__PM_STBY_CFG)
    
    #define tenMillisecondTimer_CAPTURE_LSB         (* (reg16 *) tenMillisecondTimer_TimerHW__CAP0 )
    #define tenMillisecondTimer_CAPTURE_LSB_PTR       ((reg16 *) tenMillisecondTimer_TimerHW__CAP0 )
    #define tenMillisecondTimer_PERIOD_LSB          (* (reg16 *) tenMillisecondTimer_TimerHW__PER0 )
    #define tenMillisecondTimer_PERIOD_LSB_PTR        ((reg16 *) tenMillisecondTimer_TimerHW__PER0 )
    #define tenMillisecondTimer_COUNTER_LSB         (* (reg16 *) tenMillisecondTimer_TimerHW__CNT_CMP0 )
    #define tenMillisecondTimer_COUNTER_LSB_PTR       ((reg16 *) tenMillisecondTimer_TimerHW__CNT_CMP0 )
    
    /***************************************
    *    Register Constants
    ***************************************/
    
    /* Fixed Function Block Chosen */
    #define tenMillisecondTimer_BLOCK_EN_MASK                     tenMillisecondTimer_TimerHW__PM_ACT_MSK
    #define tenMillisecondTimer_BLOCK_STBY_EN_MASK                tenMillisecondTimer_TimerHW__PM_STBY_MSK    
    
    /* Control Register Bit Locations */
    #define tenMillisecondTimer_CTRL_INTCNT_SHIFT                  0x00u       /* Interrupt Count - Not valid for Fixed Function Block */
    #define tenMillisecondTimer_CTRL_TRIG_MODE_SHIFT               0x00u       /* Trigger Polarity - Not valid for Fixed Function Block */
    #define tenMillisecondTimer_CTRL_TRIG_EN_SHIFT                 0x00u       /* Trigger Enable - Not valid for Fixed Function Block */
    #define tenMillisecondTimer_CTRL_CAP_MODE_SHIFT                0x00u       /* Capture Polarity - Not valid for Fixed Function Block */ 
    #define tenMillisecondTimer_CTRL_ENABLE_SHIFT                  0x00u       /* Timer Enable - As defined in Register Map, part of TMRX_CFG0 register */

    /* Control Register Bit Masks */
    #define tenMillisecondTimer_CTRL_ENABLE                        (0x01u << tenMillisecondTimer_CTRL_ENABLE_SHIFT)
    
    /* Control2 Register Bit Masks */
    #define tenMillisecondTimer_CTRL2_IRQ_SEL_SHIFT                 0x00u       /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define tenMillisecondTimer_CTRL2_IRQ_SEL                      (0x01u << tenMillisecondTimer_CTRL2_IRQ_SEL_SHIFT) 
    
    #if (tenMillisecondTimer_PSOC3_ES2 || tenMillisecondTimer_PSOC5_ES1)
        /* Use CFG1 Mode bits to set run mode */
        #define tenMillisecondTimer_CTRL_MODE_SHIFT                     0x01u       /* As defined by Verilog Implementation */ 
        #define tenMillisecondTimer_CTRL_MODE_MASK                     (0x07u << tenMillisecondTimer_CTRL_MODE_SHIFT) 
    #endif
    #if (tenMillisecondTimer_PSOC3_ES3 || tenMillisecondTimer_PSOC5_ES2)
        /* Control3 Register Bit Locations */
        #define tenMillisecondTimer_CTRL_RCOD_SHIFT        0x02u
        #define tenMillisecondTimer_CTRL_ENBL_SHIFT        0x00u
        #define tenMillisecondTimer_CTRL_MODE_SHIFT        0x00u 
        
        /* Control3 Register Bit Masks */
        #define tenMillisecondTimer_CTRL_RCOD_MASK  (0x03u << tenMillisecondTimer_CTRL_RCOD_SHIFT) /* ROD and COD bit masks */
        #define tenMillisecondTimer_CTRL_ENBL_MASK  (0x80u << tenMillisecondTimer_CTRL_ENBL_SHIFT) /* HW_EN bit mask */
        #define tenMillisecondTimer_CTRL_MODE_MASK  (0x03u << tenMillisecondTimer_CTRL_MODE_SHIFT) /* Run mode bit mask */
        
        #define tenMillisecondTimer_CTRL_RCOD       (0x03u << tenMillisecondTimer_CTRL_RCOD_SHIFT)
        #define tenMillisecondTimer_CTRL_ENBL       (0x80u << tenMillisecondTimer_CTRL_ENBL_SHIFT) 
    #endif
    
    /*RT1 Synch Constants: Applicable for PSoC3 ES2/PSoC3 ES3 PSoC5 ES2*/
    #define tenMillisecondTimer_RT1_SHIFT                                              0x04u
    #define tenMillisecondTimer_RT1_MASK                                               (0x03u << tenMillisecondTimer_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define tenMillisecondTimer_SYNC                                                   (0x03u << tenMillisecondTimer_RT1_SHIFT)
    #define tenMillisecondTimer_SYNCDSI_SHIFT                                          0x00u
    #define tenMillisecondTimer_SYNCDSI_MASK                                           (0x0Fu << tenMillisecondTimer_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define tenMillisecondTimer_SYNCDSI_EN                                             (0x0Fu << tenMillisecondTimer_SYNCDSI_SHIFT) /* Sync all DSI inputs */

    #define tenMillisecondTimer_CTRL_MODE_PULSEWIDTH               (0x01u << tenMillisecondTimer_CTRL_MODE_SHIFT) 
    #define tenMillisecondTimer_CTRL_MODE_PERIOD                   (0x02u << tenMillisecondTimer_CTRL_MODE_SHIFT) 
    #define tenMillisecondTimer_CTRL_MODE_CONTINUOUS               (0x00u << tenMillisecondTimer_CTRL_MODE_SHIFT) 
    
    /* Status Register Bit Locations */
    #define tenMillisecondTimer_STATUS_TC_SHIFT                    0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 
    #define tenMillisecondTimer_STATUS_CAPTURE_SHIFT               0x06u  /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define tenMillisecondTimer_STATUS_TC_INT_MASK_SHIFT           (tenMillisecondTimer_STATUS_TC_SHIFT - 4)      /* As defined in Register Map, part of TMRX_SR0 register */ 
    #define tenMillisecondTimer_STATUS_CAPTURE_INT_MASK_SHIFT      (tenMillisecondTimer_STATUS_CAPTURE_SHIFT - 4) /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */ 
    
    /* Status Register Bit Masks */
    #define tenMillisecondTimer_STATUS_TC                          (0x01u << tenMillisecondTimer_STATUS_TC_SHIFT)
    #define tenMillisecondTimer_STATUS_CAPTURE                     (0x01u << tenMillisecondTimer_STATUS_CAPTURE_SHIFT)
    #define tenMillisecondTimer_STATUS_TC_INT_MASK                 (0x01u << tenMillisecondTimer_STATUS_TC_INT_MASK_SHIFT)      /* Interrupt Enable Bit-Mask */ 
    #define tenMillisecondTimer_STATUS_CAPTURE_INT_MASK            (0x01u << tenMillisecondTimer_STATUS_CAPTURE_INT_MASK_SHIFT) /* Interrupt Enable Bit-Mask */ 
    
#else   /* UDB Registers and Register Constants */

    
    /***************************************
    *           UDB Registers 
    ***************************************/
    
    #define tenMillisecondTimer_STATUS              (* (reg8 *) tenMillisecondTimer_TimerUDB_nrstSts_stsreg__STATUS_REG )
    #define tenMillisecondTimer_STATUS_MASK         (* (reg8 *) tenMillisecondTimer_TimerUDB_nrstSts_stsreg__MASK_REG)
    #define tenMillisecondTimer_STATUS_AUX_CTRL     (* (reg8 *) tenMillisecondTimer_TimerUDB_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define tenMillisecondTimer_CONTROL             (* (reg8 *) tenMillisecondTimer_TimerUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG )
    
    #define tenMillisecondTimer_CAPTURE_LSB         (* (reg32 *) tenMillisecondTimer_TimerUDB_sT24_timerdp_u0__F0_REG )
    #define tenMillisecondTimer_CAPTURE_LSB_PTR       ((reg32 *) tenMillisecondTimer_TimerUDB_sT24_timerdp_u0__F0_REG )
    #define tenMillisecondTimer_PERIOD_LSB          (* (reg32 *) tenMillisecondTimer_TimerUDB_sT24_timerdp_u0__D0_REG )
    #define tenMillisecondTimer_PERIOD_LSB_PTR        ((reg32 *) tenMillisecondTimer_TimerUDB_sT24_timerdp_u0__D0_REG )
    #define tenMillisecondTimer_COUNTER_LSB         (* (reg32 *) tenMillisecondTimer_TimerUDB_sT24_timerdp_u0__A0_REG )
    #define tenMillisecondTimer_COUNTER_LSB_PTR       ((reg32 *) tenMillisecondTimer_TimerUDB_sT24_timerdp_u0__A0_REG )

    #if (tenMillisecondTimer_UsingHWCaptureCounter)
        #define tenMillisecondTimer_CAP_COUNT              (*(reg8 *) tenMillisecondTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define tenMillisecondTimer_CAP_COUNT_PTR          ( (reg8 *) tenMillisecondTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define tenMillisecondTimer_CAPTURE_COUNT_CTRL     (*(reg8 *) tenMillisecondTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
        #define tenMillisecondTimer_CAPTURE_COUNT_CTRL_PTR ( (reg8 *) tenMillisecondTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
    #endif


    /***************************************
    *       Register Constants
    ***************************************/
    
    /* Control Register Bit Locations */
    #define tenMillisecondTimer_CTRL_INTCNT_SHIFT              0x00u       /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_CTRL_TRIG_MODE_SHIFT           0x02u       /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_CTRL_TRIG_EN_SHIFT             0x04u       /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_CTRL_CAP_MODE_SHIFT            0x05u       /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_CTRL_ENABLE_SHIFT              0x07u       /* As defined by Verilog Implementation */
    
    /* Control Register Bit Masks */
    #define tenMillisecondTimer_CTRL_INTCNT_MASK               (0x03u << tenMillisecondTimer_CTRL_INTCNT_SHIFT)
    #define tenMillisecondTimer_CTRL_TRIG_MODE_MASK            (0x03u << tenMillisecondTimer_CTRL_TRIG_MODE_SHIFT)  
    #define tenMillisecondTimer_CTRL_TRIG_EN                   (0x01u << tenMillisecondTimer_CTRL_TRIG_EN_SHIFT)
    #define tenMillisecondTimer_CTRL_CAP_MODE_MASK             (0x03u << tenMillisecondTimer_CTRL_CAP_MODE_SHIFT)   
    #define tenMillisecondTimer_CTRL_ENABLE                    (0x01u << tenMillisecondTimer_CTRL_ENABLE_SHIFT)
    
    /* Bit Counter (7-bit) Control Register Bit Definitions */
    #define tenMillisecondTimer_CNTR_ENABLE                    0x20u   /* As defined by the Register map for the AUX Control Register */
    
    /* Status Register Bit Locations */
    #define tenMillisecondTimer_STATUS_TC_SHIFT                0x00u  /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_STATUS_CAPTURE_SHIFT           0x01u  /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_STATUS_TC_INT_MASK_SHIFT       tenMillisecondTimer_STATUS_TC_SHIFT                
    #define tenMillisecondTimer_STATUS_CAPTURE_INT_MASK_SHIFT  tenMillisecondTimer_STATUS_CAPTURE_SHIFT
    #define tenMillisecondTimer_STATUS_FIFOFULL_SHIFT          0x02u  /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_STATUS_FIFONEMP_SHIFT          0x03u  /* As defined by Verilog Implementation */
    #define tenMillisecondTimer_STATUS_FIFOFULL_INT_MASK_SHIFT tenMillisecondTimer_STATUS_FIFOFULL_SHIFT

    /* Status Register Bit Masks */
    #define tenMillisecondTimer_STATUS_TC                      (0x01u << tenMillisecondTimer_STATUS_TC_SHIFT)             /* Sticky TC Event Bit-Mask */ 
    #define tenMillisecondTimer_STATUS_CAPTURE                 (0x01u << tenMillisecondTimer_STATUS_CAPTURE_SHIFT)        /* Sticky Capture Event Bit-Mask */ 
    #define tenMillisecondTimer_STATUS_TC_INT_MASK             (0x01u << tenMillisecondTimer_STATUS_TC_SHIFT)             /* Interrupt Enable Bit-Mask */            
    #define tenMillisecondTimer_STATUS_CAPTURE_INT_MASK        (0x01u << tenMillisecondTimer_STATUS_CAPTURE_SHIFT)        /* Interrupt Enable Bit-Mask */ 
    #define tenMillisecondTimer_STATUS_FIFOFULL                (0x01u << tenMillisecondTimer_STATUS_FIFOFULL_SHIFT)       /* NOT-Sticky FIFO Full Bit-Mask */ 
    #define tenMillisecondTimer_STATUS_FIFONEMP                (0x01u << tenMillisecondTimer_STATUS_FIFONEMP_SHIFT)       /* NOT-Sticky FIFO Not Empty Bit-Mask */ 
    #define tenMillisecondTimer_STATUS_FIFOFULL_INT_MASK       (0x01u << tenMillisecondTimer_STATUS_FIFOFULL_SHIFT)       /* Interrupt Enable Bit-Mask */ 
    
    #define tenMillisecondTimer_STATUS_ACTL_INT_EN             0x10u   /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define tenMillisecondTimer_AUX_CTRL_FIFO0_CLR             0x01u   /* As defined by Register map */
    #define tenMillisecondTimer_AUX_CTRL_FIFO1_CLR             0x02u   /* As defined by Register map */
    #define tenMillisecondTimer_AUX_CTRL_FIFO0_LVL             0x04u   /* As defined by Register map */
    #define tenMillisecondTimer_AUX_CTRL_FIFO1_LVL             0x08u   /* As defined by Register map */
    #define tenMillisecondTimer_STATUS_ACTL_INT_EN_MASK        0x10u   /* As defined for the ACTL Register */
    
#endif /* Implementation Specific Registers and Register Constants */

#endif  /* CY_Timer_v2_0_tenMillisecondTimer_H */


/* [] END OF FILE */
