/*******************************************************************************
* File Name: tenMillisecondTimer_PM.c  
* Version 2.0
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "tenMillisecondTimer.h"
static tenMillisecondTimer_backupStruct tenMillisecondTimer_backup;

/*******************************************************************************
* Function Name: tenMillisecondTimer_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondTimer_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*    No
*
*******************************************************************************/
void tenMillisecondTimer_SaveConfig(void)
{   
    #if (!tenMillisecondTimer_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (tenMillisecondTimer_PSOC3_ES2 || tenMillisecondTimer_PSOC5_ES1)
            tenMillisecondTimer_backup.TimerUdb = tenMillisecondTimer_ReadCounter();
            tenMillisecondTimer_backup.TimerPeriod = tenMillisecondTimer_ReadPeriod();
            tenMillisecondTimer_backup.InterruptMaskValue = tenMillisecondTimer_STATUS_MASK;
            #if (tenMillisecondTimer_UsingHWCaptureCounter)
                tenMillisecondTimer_backup.TimerCaptureCounter = tenMillisecondTimer_ReadCaptureCount();        
            #endif
        #endif
        
        #if (tenMillisecondTimer_PSOC3_ES3 || tenMillisecondTimer_PSOC5_ES2)
            tenMillisecondTimer_backup.TimerUdb = tenMillisecondTimer_ReadCounter();
            tenMillisecondTimer_backup.InterruptMaskValue = tenMillisecondTimer_STATUS_MASK;
            #if (tenMillisecondTimer_UsingHWCaptureCounter)
                tenMillisecondTimer_backup.TimerCaptureCounter = tenMillisecondTimer_ReadCaptureCount();        
            #endif
        #endif
        
        #if(!tenMillisecondTimer_ControlRegRemoved)
            tenMillisecondTimer_backup.TimerControlRegister = tenMillisecondTimer_ReadControlRegister();
        #endif
    #endif
}

/*******************************************************************************
* Function Name: tenMillisecondTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondTimer_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*    Yes
*
*******************************************************************************/
void tenMillisecondTimer_RestoreConfig(void) 
{
    #if (!tenMillisecondTimer_UsingFixedFunction)
        /* Backup the UDB non-rentention registers for PSoC3 ES2 and PSoC5 ES1*/
        #if (tenMillisecondTimer_PSOC3_ES2 || tenMillisecondTimer_PSOC5_ES1)
            tenMillisecondTimer_WriteCounter(tenMillisecondTimer_backup.TimerUdb);
            tenMillisecondTimer_WritePeriod(tenMillisecondTimer_backup.TimerPeriod);
            tenMillisecondTimer_STATUS_MASK =tenMillisecondTimer_backup.InterruptMaskValue;
            #if (tenMillisecondTimer_UsingHWCaptureCounter)
                tenMillisecondTimer_SetCaptureCount(tenMillisecondTimer_backup.TimerCaptureCounter);        
            #endif
        #endif
        
        #if (tenMillisecondTimer_PSOC3_ES3 || tenMillisecondTimer_PSOC5_ES2)
            tenMillisecondTimer_WriteCounter(tenMillisecondTimer_backup.TimerUdb);
            tenMillisecondTimer_STATUS_MASK =tenMillisecondTimer_backup.InterruptMaskValue;
            #if (tenMillisecondTimer_UsingHWCaptureCounter)
                tenMillisecondTimer_SetCaptureCount(tenMillisecondTimer_backup.TimerCaptureCounter);           
            #endif
        #endif
        
        #if(!tenMillisecondTimer_ControlRegRemoved)
            tenMillisecondTimer_WriteControlRegister(tenMillisecondTimer_backup.TimerControlRegister);
        #endif
    #endif
}


/*******************************************************************************
* Function Name: tenMillisecondTimer_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondTimer_backup.TimerEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*    No
*
*******************************************************************************/
void tenMillisecondTimer_Sleep(void)
{
    #if(!tenMillisecondTimer_ControlRegRemoved)
        /* Save Counter's enable state */
        if(tenMillisecondTimer_CTRL_ENABLE == (tenMillisecondTimer_CONTROL & tenMillisecondTimer_CTRL_ENABLE))
        {
            /* Timer is enabled */
            tenMillisecondTimer_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            tenMillisecondTimer_backup.TimerEnableState = 0u;
        }
    #endif
    tenMillisecondTimer_Stop();
    tenMillisecondTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: tenMillisecondTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  tenMillisecondTimer_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*    Yes
*
*******************************************************************************/
void tenMillisecondTimer_Wakeup(void) 
{
    tenMillisecondTimer_RestoreConfig();
    #if(!tenMillisecondTimer_ControlRegRemoved)
        if(tenMillisecondTimer_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                tenMillisecondTimer_Enable();
        } /* Do nothing if Timer was disabled before */ 
    #endif
}


/* [] END OF FILE */
