#include "adc.h"

uint8_t g_conversionFinished = 0;

static uint8_t g_adWait = 0;
static uint8_t g_currentChannel = 0;
static uint8_t g_currentDivider = 0;

// current filtered input values
static float g_filtereds[CHANNEL_COUNT][DIVIDER_COUNT] = { { 0 } };

// calculated volt
static float g_volts[CHANNEL_COUNT] = { 0 };

// zero point calibration offsets
static int g_offsets[CHANNEL_COUNT][DIVIDER_COUNT] = {
	{ 107, 91, 75 },  // channel 0
	{ 224, 112, 73 },  // channel 1
};

// scale calibration values
static float g_scaleCorrection[CHANNEL_COUNT][DIVIDER_COUNT] = {
	{ 21286.0f, 2322.0f, 137.0f },  // channel 0
	{ 20350.0f, 2393.0f, 135.0f },  // channel 1
};

// scale constants
static float g_scaleFactors[DIVIDER_COUNT] = {
	1.0f, 10.0f, 100.0f
};

static uint8_t g_state = 0;

// select best dividers
static void coypResults(void)
{
	uint8_t channel;
	for (channel = 0; channel < CHANNEL_COUNT; channel++) {
		uint8_t divider;
		for (divider = 0; divider < DIVIDER_COUNT; divider++) {
			float filtered = g_filtereds[channel][divider];
			float volt = filtered / g_scaleCorrection[channel][divider];
			if (fabs(volt) < g_scaleFactors[divider]) {
				g_volts[channel] = volt;
				break;
			}
		}
	}
}

// scan all inputs
void scanInputs(void)
{
	switch (g_state) {
		case 0:
		{
			// get result, adjust zero point offset, and do a lowpass filter
			float filtered = g_filtereds[g_currentChannel][g_currentDivider];
			int32_t result = getSample() + g_offsets[g_currentChannel][g_currentDivider];
#ifdef CALIBRATION
			filtered = filtered + 0.005f * (((float) result) - filtered);
#else
			filtered = filtered + 0.05f * (((float) result) - filtered);
#endif
			g_filtereds[g_currentChannel][g_currentDivider] = filtered;
		
			// select next input and divider
			g_currentDivider++;
			if (g_currentDivider == DIVIDER_COUNT) {
				g_currentDivider = 0;
				g_currentChannel++;
				if (g_currentChannel == CHANNEL_COUNT) {
					coypResults();
					g_currentChannel = 0;
					g_conversionFinished = 1;
				}
			}
		
			selectDivider(g_currentDivider);
			selectChannel(g_currentChannel);
			g_state++;
			break;
		}

		case 1:
		{
			ADC_DelSig_1_StartConvert();
			g_state++;
			break;
		}

		case 2:
		{
			g_state = 0;
			break;
		}
	}
}

float getFiltered(uint8_t channel, uint8_t divider)
{
	return g_filtereds[channel][divider];
}

float getVoltage(uint8_t channel)
{
	return g_volts[channel];
}
