#include <stdint.h>
#include "hardware.h"

static void sendInt(uint16_t value)
{
	// show number
	uint16_t div = 10000;
	uint8_t firstChar = 1;
	uint8_t count = 0;
	while (div) {
		uint8_t digit = value / div;
		value -= digit * div;
		if (firstChar) {
			if (digit || (div == 1)) {
				writeOledChar(digit + '0');
				firstChar = 0;
				count++;
			}
		} else {
			writeOledChar(digit + '0');
			count++;
		}
		div /= 10;
	}
	
	// fill until line end with spaces
	while (count < 3) {
		writeOledChar(32);
		count++;
	}
}

static void writeColor(uint32_t color)
{
	uint8_t r = (color >> 16) & 0xff;
	uint8_t g = (color >> 8) & 0xff;
	uint8_t b = color & 0xff;
	r >>= 3;
	g >>= 2;
	b >>= 3;
	writeOledChar((r << 3) | (g >> 3));
	writeOledChar(((g & 7) << 5) | b);
}

static void drawStringPrefix(uint8_t x, uint8_t y, uint32_t color, uint8_t size)
{
	writeOledChar(0x53);
	writeOledChar(x);
	writeOledChar(y);
	writeOledChar(2);  // 8x12 font
	writeColor(color);
	writeOledChar(size);  // width
	writeOledChar(size);  // height
}

void drawString(uint8_t x, uint8_t y, uint32_t color, uint8_t size, const char* string)
{
	drawStringPrefix(x, y, color, size);
	while (1) {
		writeOledChar(*string);
		if (!(*string)) break;
		string++;
	}
	readOledChar();
}

void drawInt(uint8_t x, uint8_t y, uint32_t color, uint8_t size, uint16_t value)
{
	drawStringPrefix(x, y, color, size);
	sendInt(value);
	writeOledChar(0);  // terminator
	readOledChar();
}

void drawTime(uint8_t x, uint8_t y, uint32_t color, uint8_t hour, uint8_t minute, uint8_t second)
{
	drawStringPrefix(x, y, color, 1);
	writeOledChar((hour / 10) + '0');
	writeOledChar((hour % 10) + '0');
	writeOledChar(':');
	writeOledChar((minute / 10) + '0');
	writeOledChar((minute % 10) + '0');
	writeOledChar(':');
	writeOledChar((second / 10) + '0');
	writeOledChar((second % 10) + '0');
	writeOledChar(0);  // terminator
	readOledChar();
}

void drawRectangle(uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2, uint32_t color)
{
	writeOledChar(0x72);
	writeOledChar(x1);
	writeOledChar(y1);
	writeOledChar(x2);
	writeOledChar(y2);
	writeColor(color);
	readOledChar();
}

void initDisplay(void)
{
	oled_reset_Write(0);
	delayMs(1);
	oled_reset_Write(1);
	delayMs(1000);

	// send OLED auto baud character
	writeOledChar(0x55);
	delayMs(100);
	clearOledReceiveBuffer();
	delayMs(100);

	// clear screen
	writeOledChar(0x45);
	readOledChar();
	
	// set opaque-mode for text
	writeOledChar(0x4f);
	writeOledChar(1);
	readOledChar();
	
	// pen size 0 for solid-mode
	writeOledChar(0x70);
	writeOledChar(0);
	readOledChar();
}
