#include <stdint.h>
#include <device.h>

#define SE95_I2C_ADDRESS 0x48

static uint8_t g_startButton = 0;
static uint8_t g_stopButton = 0;

void writeOledChar(uint8_t c)
{
	oled_uart_PutChar(c);
}

uint8_t readOledChar(void)
{
	while (oled_uart_GetRxBufferSize() == 0) {}
	return oled_uart_GetByte() & 0xff;
}

void clearOledReceiveBuffer(void)
{
	while (oled_uart_GetRxBufferSize()) {
		oled_uart_GetByte();
	}
}

void initHardware(void)
{
	CYGlobalIntEnable;
	divider_mux_Start();
	input_mux_Start();
	VDAC8_1_Start();
	//USBFS_1_Start(0, USBFS_1_3V_OPERATION);
	rs232_Start();
	i2c_Start();
	i2c_EnableInt();
	oled_uart_Start();
	ADC_DelSig_1_Start();
	ADC_DelSig_1_StartConvert();
	sdcard_spi_Start();
	CapSense_1_Start();
    CapSense_1_InitializeAllBaselines();
    CapSense_1_ScanEnabledWidgets();
	clock24_Start();
	millisecondTimer_Start();
	onMillisecond_Start();
}

void delayMs(uint16_t ms)
{
	CyDelay(ms);
}

void selectDivider(uint8_t position)
{
	position++;
	divider_mux_DisconnectAll();
	divider_mux_Connect(position * 2);
	divider_mux_Connect(position * 2 + 1);
}

void selectChannel(uint8_t channel)
{
	input_mux_Select(channel);
}

int32_t getSample()
{
	return ADC_DelSig_1_GetResult32();
}

void sdCardSelect()
{
	sdcard_chipselect_Write(0);
	delayMs(1);
}

void sdCardDeselect()
{
	sdcard_chipselect_Write(1);
	delayMs(1);
}

uint8_t sdCardTransmit(uint8_t byte)
{
	sdcard_spi_WriteTxData(byte);
	while ((sdcard_spi_ReadTxStatus() & spi_STS_BYTE_COMPLETE) == 0) { }
	uint8_t received = 0;
	while (sdcard_spi_GetRxBufferSize()) {
		received = sdcard_spi_ReadRxData();
	}
	return received;
}

void updateCapSense()
{
	if (!CapSense_1_IsBusy()) {
		// update baseline for all sensors and start new scan
		CapSense_1_UpdateEnabledBaselines();
		CapSense_1_ScanEnabledWidgets();
	
		// test widgets
		g_startButton = CapSense_1_CheckIsWidgetActive(CapSense_1_BUTTON2__BTN);
		g_stopButton = CapSense_1_CheckIsWidgetActive(CapSense_1_BUTTON1__BTN);
	}
}

uint8_t getStartButton()
{
	return g_startButton;
}

uint8_t getStopButton()
{
	return g_stopButton;
}

float getTemperature()
{
	// get sensor data
	i2c_MasterSendStart(SE95_I2C_ADDRESS, 0);
	i2c_MasterWriteByte(0);
	i2c_MasterSendRestart(SE95_I2C_ADDRESS, 1);
	uint8_t rx0 = i2c_MasterReadByte(1);
	uint8_t rx1 = i2c_MasterReadByte(0);
	i2c_MasterSendStop();
	
	// calculate temperature
	int data = (rx0 << 5) | (rx1 >> 3);
	const float resolution = 0.03125;
	const int bits = 13;
	const int msb = 1 << (bits - 1);
	const int max = 2*msb;
	if (data >= max || data < 0) return 0;
	if (data & msb) data = data - max;
	return ((float) data) * resolution;
}
