/*
All microcontroller specific functions. For porting to another microcontroller,
only these functions needs to be ported.
*/

#ifndef HARDWARE_H
#define HARDWARE_H

#include <stdint.h>

//
// OLED
//

// wait until the last character is sent and then start sending c
void writeOledChar(uint8_t c);

// wait until a character was receiced and return this character
uint8_t readOledChar(void);

// clear input buffer
void clearOledReceiveBuffer(void);

//
// general
//

// init hardware
void initHardware(void);

// wait the specified number of milliseconds (max: 6.5 seconds)
void delayMs(uint16_t ms);


//
// AD converter
//

// select input divider
void selectDivider(uint8_t position);

// select input channel
void selectChannel(uint8_t channel);

// read current channel
int32_t getSample();


//
// SD card
//

// sets chipselect to 0 and waits a bit
void sdCardSelect();

// sets chipselect to 1 and waits a bit
void sdCardDeselect();

// send and receive a byte (waits until the byte was sent and received)
uint8_t sdCardTransmit(uint8_t byte);


//
// CapSense
//

// update CapSense variables
void updateCapSense();

// get last start button state (1=pressed)
uint8_t getStartButton();

// get last stop button state (1=pressed)
uint8_t getStopButton();


//
// I2C SE95 temperature sensor
//
float getTemperature();

#endif
